10 REM Test case conflict detection
20 TargetAngle = 45
30 PRINT "First use: TargetAngle ="; TargetAngle
40 targetangle = 90
50 PRINT "Second use: targetangle ="; targetangle
60 PRINT "Are they the same?"; TargetAngle = targetangle
70 END
