                                                                                 RIUlpi ELECTRI1L ENGENEERING2 DESIGN ****"



PR1PnO.ilF Gnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn6C(W.i'C
*
 
td  =R6 uCT t T=0aned uNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN9D ndr
somewhHof a str              tF: 
tdUoCc:ttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt/2 by S. Kluger"
    PRINT;T-ei =Od"t"IyCI"M >Nsn
pi constFX
10 PmT "To sPu sMHofhe progrNs just type itU
PR"IG
    PRINT "and hH'iE2R;v9eFdE7r allt ***********************************************************************************pToor ET5E/lH=o Nh
" WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW*
 Ntd  =20 PRINT "Sel
lvrom the fola T 2a o5ines (0 toCc .) :"
R6 uX XAO2t6law (DC)"
    PRIN"   hlFM0r stailizeo
2 supWv*
 
tdU;y
HDC s
pro2CCCCCC" GEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEn"
    PRINT "      4. Low pass  OT8P
Butterworth filter"
    PRINT                                                      . T22222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222resonant frequency circuFT
 
 
"rR u X^HPaE t
TWr A<Tci
6
p     PRIN"   R333333333333333333333333333333333Go l
Dat GEwbCNn Dta=T=E lUIsf )iT
 
 
"rR uX XoOHLong ire anS W(: 
 
"rR uX XyOcoooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooole or halfTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTe antenna"
R6 uX f"t TiT=D ))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))Icssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssss 2EIsf HeN     PRINT "     117aWIE2De of wire"



PR1PyA2. CrystaMRpc.tr.)Ppquenc ca=Usssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssss E*
 
td  =uu* ieilRfo5(
do you wisI
aC T                                                                       N;lE "FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
      IF SELEHO6N
AND SELECTINIt"I
FcL 30







IF SELECTION=0  EN 99999
    PRINTPlease answer witr UNber fommmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmma1
GOne
30 ON SELECTION GO TO 1T6r Te,t0,300,e0,500,e0,700o6
F>SR 
WHN1200

      REM PAR1 (Te)

(
HPmT
     PRINT "           **** O
's AW cC)  
(((((((((((((((((((((((((((((((((d T="rR 
N      PmT " ENTER valuafor 2 (two) known"
     PmT " ENTER 0 (zero) fnWS"Ha "WtsssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssfiMabe calculated
 fPR1      INPUT "PoSIasoCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCColts;E
     INPUT "CuITHflow in amptfUN=tN        IF E0 AorXR
THEN 1111
     INPUT "ResistW=ToCPa4Ns";
 > .T3e
ss7
R
 aE=0 THEN 120
       IF E>0 AND R>0
ss5HTHEN 130
     INPUT "Powe/w4oPReN  NIFNNe AND I=0 AND R=0  EN 141
       IF I>0 AND E=0 AND R=eToTGt9=       IF R>0
sss P1ND I=0 THEN"tOFi R=EI
     GOTO I0
boc3eN(: eOeTG6>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>e I===============================================================================(((((((((((((((((((((((((((((((((etes"
tNyOTO 150
141 I=PE
R=(b
oWeN      GOTO 150
142 E000000000000000000000000000000000tNyccT.N      GOTO 1e
143 E=(P*R)^.5
     I=E/RTb
HR6 
N      PmT "PoSIasN ;E;" voliT
 fR6 uCvwRpnt flow = ";I;" amperes
 fPR1PeefEl lPP
= ";=>a4NeN  EeRT Ra h 
 oN
>Bs"
     PRINT
IN "5rtn1LCULATIONS?NnESNO)";ANS$
       Id Nyt="YnXFcL GOTFA0 ELSE GOTO 20

 t.m cHoNO
2    (200)

Te PR1      PRINT "       *1T.E o STABILIZED CIl "pcoa.m
****"
?e  PR1      INPUT "Voltage rating of zener diode";A
     INPUT "Wattage rW"W   oIne(FAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAde"uN      INPUT "MaxiUDIo8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888"
of p h nWo2CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCqX
     R=((B-A)^2)/W;y vMlomM bOr





REM in Nperes
     PmT "Fos2PiScs RHcoIFRPanvor EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEET hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhha"OT10000;"s.EWh0reeN  EeRT raT0R;"4Ns ";W;" watt resi)PG
     PRINT
PRINTWillhe load" icer=D=use have la  er thWe




PRINW;"waDui
0RGllllllllllllllllllllllllllllllllllllllllllllllllll1 eN      INPUT "(YES/NO)"1$
Td- PRr Ta=22N IN "2ieil8EI*,3EtRUN wattage of the dooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooe yoT T  =     X=((B-A)^2)/((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((TVe;
 fPRIN"Use;X; "ohms;W+C;" wataresisthT
 fPRINT "WA$
 Z
(FAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAdeT WITTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTably burn Pl8 the load"
     PRINT "          shPHA^TNmoved an=E"n=D t                                                                         opZ*
 fPRINT"b tNWet I E lcuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuu  )))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))dsTRO
 R  Nyt
       IF AN M "YESTHEN Gy(
ELSE GOTO 2N "b
HPo )=oNO
2" N PRINT                                                                                        TA=WER SUPPLYEKR=***********************************
     PR1      INPUT "What is LINd"HvoW ge suppli S2T  tty";A"bdP6LPeP2WI
E.raios3Ner's primary rating (orap)";rRHINPUT "What is  YIo8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888 ge of sesM1LP T 2NT 2a A9= Eo
(e ; 222222222REM  D i6Et.r
S
     P                                                     et=HRE;Nol"Ti$ HlcAX
     
P+(P/4)  oliREt.RoeGTidTC56 INPUT "What ishe needed (de R-DIo8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888"1O;" -F wpFO U 
EN 267
       IOXz0To"Ceeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee:  "dUnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnil8EISp volt  e rating of REGLF.en*
 fI0We
 9Hused with the power suppfm;.        IF ((Z+2.5)neI t  
N(1 =269






IFneIpOt5)neI tt))<O THEN 271
bceR6e
Ntf UNing that you use fHWN0ife, will the recIovvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv  bridge"
IN "ui
l l"au:
	 U  "EM
















































































































































































deMsWc"W
Pter p se
  SN        IF                                                      Itd1
eTo"CR" =     PR1gUNtPR So  hN0VI C(FnNUSt/ GEW. W^LN"eR6 s
GOTO 2I R0 IF F=eToTM .75
       IF F=0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP)T4R9=                                   =c-S)*1.=t6Na)h; WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWHEiCa                                                                                                               IE9eNyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyydO)I3"o molLlIepl
 fINPUT "Wil8EISp EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEI
abe used in amperes? (ifS" RHaW.ypeT
R  

       IF HT0TN                                                                                   >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>R1 I=(H*83)/R*100
     I=I+( d "
      R6 
N      PmT "Lin= ";A;"Dv"2 (max).Transformer primary llllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
P:mq)
df
vL"2
 fPR1PeosM ry = ";D;v
vir
S. Peak sec.vol ge
mo0                                                 R6 uC"Fqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqe0O;"Dv=2 use rectifing bridge o0F
     PRINT "diodarated at ";
 olts Ra2a6oeR
c nd ";4
; "ampM6a2Ie=eN      PR1P2T t 6
M tW citnW GDrP S5Hrated ";I;" mo2/sP" n2 2a6m)"




PRIN"and;G; o8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888D=M6a2TZ "
. Woa6. TNlIepH= ";Ruuuuuuuuuuuvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
 fPRIN
 fPR1PRrpEgan oh<ET.o calculate bleederresistoT
 fINPUT "More cs=Usssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssss ly ans2 iF nW0conL8nES/N                                  
ddX
       IF AN M "YESTHEN 252
     INPUT "MIT=tacr.ionc nl8Spr tr))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))sRT2 n.ap)";ANS
       IF R )0ds1ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPOeIF^A ELSE GOTO 20
C2e PR1PR HDw1D( svWCNT 2
piEvOirurTRWIsgc n* WN PRINTpower*Slo"I"R0nt":PRINT:GOTC52
268 PRINTYour secondar winding has a TtuuuuuuuuuuulcAHrati   fn.his"
     PRINT "poweRpquiremen= UNtda3*O 252
269 PRINT "Power PGGWvoHvoltage must be mITISWribo8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888UeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeheeN  EeRT      than oltage of REGULAt31
 UNtda "3."b2eN 271 PR1PR HDw1r"GWIo8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888"
is erly high and will cauHthe rAPWiMe(: fPRINTto overheat. Red P
your vol geo ";Z+4uuuuuuuuuuuvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
 fPRIN"One way to sISW is to )P
OP
lhNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN/ GEWO *RWIsCa "
     PRINT "whipN0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000l be printedtCc  "m  ch suc" uSHreducin tT*
 fPRINT "suGWvo
tuuuuuuuuuuulcAHy"TIo8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888i
.woWfNhoPI"YP
1.4 v)
 fPR1PR
CFui1ISW voltage to WAPWiMUWP "CFuU
a h n 2a  Q.";yUNtde4pIb(((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((( 7 INPUT "How many TA  OSS7 reulatIENI
Wp used")
 fINPUT "          K-type rAPWiMW R   .(: fIN "R yI 
Ws SNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN ampers)";Y
H=T+(2)4Rptds
GOTO 2 >>>>>>>>>>>>>> REM    PIl4
ne.*
N 
300 PRINT "           
PItN1SS FILTER ****"




PRIN"This 2s:2i8bU on OLTIOTPP 2o-lPTluE  FRY*
a"rR urP u
od  1 O6Y&hNl eme & Tobey,u eRWN06666666666666666666666666666666662Se1."
     PRINT
315NPePl""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""y ITSlND (il*3C                                                                               An4C5NPeu "EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEed pass-band ain 
)";N PRINTPeaking factor: 0C0ro)c nlP( sR91MIpoHButt9 I"eN      uu* NiH**************c.Ovalufor nonstandard filter";A
     IF 
0 THEN A=2^.5
     IF 
/A)>100  EN 3e
     PR1P5pi 0 of C2 ineTM6 UTWNl ds)"




I0WeR i7: MbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbT(:e.TANWH RHF      ";C
     R=A/(4*pi$f" 
WXe;
 fPRIN
 fPR1PnI)t tO.                 C1 =;(4*(1+H)2)/(A^2)




PRIN" y.O:                 C2 = A9= EeRT           X R2lNeTN  ";R/H
     PRINT "                                                                                     cO0l
 fPR1PyNFcv:     R3 - o             R3 eR/(H+1)
PRINT-XN--:--XXXXXXX-:----o  e                                                 R6 uX H: 
aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaeNyNtdU;ttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt                                                                                                        o----------------"
     PRINT "           T=t6 t
s=fo"
     PRINT "           :              o  o" 
     PRINT "           :           :  o            E-oT
 fPRINT "                         "
     PmT "-----------:------------O  eN      INPUT "AnotheuooCot *:2il " 8 Nny3M R  Nyt
Td Nyt="YES" THENze
IN "R other                                                                                                             tM D FoooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooourationNnESNO)";B$
       IF B="YES" THEN GOTO 310aNnEhIpIFne"..e PRINT"0causoperW"aWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWohnaviers are non-id l, pas p(: fPRIN"band ain GDrP S5HchUI
ae f EpU/Te whet7aking"
PRINTfactor H*pg= 0-1"
PRINTGain of 10>eI"Tidng f=MUFcc cc"lllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllTy ane(: fR6 uCuU$7akin gain 0 dc"WC-p
TIIE.
9"a *
D FT p(: fR6 u* il  1(:  "d  =     GIC0

       R
 1 oNO
4 (e0)

400 PRINT
PRINT                                                                                        TATlL5a HRht( 8 mR Ta0Mn CIRP5)lpi"
410 PRINT
IN "RzductW=ToCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 (M
WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWenrys)";
     uu* lllllllllllllllllllllllllllllllllllllllllllDsE2De inF ( no-Farads)"2
PRINT;yUNtdT6
lhocNC rDU frhuenc is ";\
            10000/(6.....................................................FoRte7*((L*C)^0.
T
                                                                  IC z (Iua(Oh1=
 EeRT 























































: this 5)z 0ovolU
iHafT ed by rEnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn nToCCCCCCCC2Hcircuit"




PRIN
 fINPUT "More calUIsf ))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))R   fTRO
 R  dX
       IF ANS$="EYXFcL 410
     GOTO 20






RE=oNO
5 (500 =
50
"r
N  EeRT       **** PASO2WiANDPASn4LTEDnO"N *1*
a"rR 
N      PRINT"    TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT program is based on  ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo(rz1 ENGINEEReX6FT
 fPRINT "CIRCUITosgFtm
by Skilling, Willey, 161.";yUNtd;TAOHwill calculate ides
D"
i
IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIalues for 2FT
 fPRINTT-sel  WM1=rd0ctiWviltersc; t
TF1, RE2 R4A0 PR1      INPUT "What is F1, low cutoff frequency (in HeC                                                                               o NN      INPUT "What is F2, high cutoff frequency (in HeC                                                                               A 
       IF L>H THEN 560




I0Wel  tWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW im  e impedance in                                                                                                     -freqTl in2Pa4Ns)"0N        IF L<0 THE581
       IF H<0 THEN 581
       IF R<0 THEN 581
     X= lN
Y=12.5663706TL*H
     Z=pi
5TrRPePR.s2o
want T-section dee 'T'";T$
Te--t
ee >1 E550
     PRINT
PRINT2Ca=";X/Y*R*2, Cb=;f" t","  R=";R;yUNtdor  dMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM m"  Lb=";R>S      R6 
N      PmT "     2g Er9rc9 h ";yUNtdNglv!!-----mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm 
t g

 6i----!!-......"
     PRINT "                      :      :                     :"




PRIN" Rs;="====================================================================================
"
     PRINT "                   R(: X"= Lb R;9 eN      PmT "                                                                                                                                                         X";yUNtd;"7a c9a cCe1(:  "dUNglCe=   l9a   lOtttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt*4r
HPRINT
IN "R.s2
D=waHPI-sectaW.ype 'P'" T
 > .T
Tt<>"PTHEN 52
PRINT;yUNtdoPP 0000000000000000000000000000000000000000000000
m"  2Lb=";2*R*X/Y, RR  =     PRINT "CPR  >i  FTR Vr2=";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;1(T RX
     PmT
     PRINT "                  La        U:a"rR uF:-----:-m dHd2SdHXg  lv:.............."
     PmT "         :     :                    :     : =  eN      PRINT "         m                                                                                             
     m
X"
     PmT "     2b




Vr2         Rl" =     m 2Lb     R X"
     PmT "         m E
                    :     m           "
     PR1PI2u=====:                    :                   "
     PmT "o--------:-----:--------------------:-----:...........:"
     PRINT




I0Wed HiF2(TiaEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEe filter calculatioMdsTRO
 R -  NIFd)0ds1
FcL GOTO 510 ELSEIpIFne
560mtdUnoW
p=cr
Ioff frequs8o6o l*rT urh n.Uug" p(:  "dU=cr
IoffPpquenc":GOTO  
581 PR1PR
* IoiHLHmust be large.han 0 (zer                                                                                                      4pI9  
iC R6 umTMa h ndNS
nddWvf
GOTO 510T
)=oN 6

600 PRINT "          
 C;WNL COIL DESIGN ****"
PRINT;yUNtd=Nva raIEIIW tions:";yUNtd;I2$MS
lPW=TN  100 microhenriaMAXIMM"
     PRINT "          RTEIT "nTtMHMAIMUM";yUNtd;"7ptg  e MINIMUM"
     PRINT "         (rEnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnns umTsWDRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRo l6p of compE .e type*teTe PRINT
PRINTPROG"( W
"
     PRINT "      1. ss InHelaeN      PRINT "      2. INDUCTIWiNE1CTAlaeN      PRINT
     INPUT " WHICH OaOF THeT .="I.Gnd
ABOWLnOU WANT COMPUTED"; =       IF A=1 TH=650
       IF A>2 THENT(>: > . d.THEN 6" R20 INPUT "WHAT ISHE DESIRED INDUC.pE"ACTANCE IN OH FN=tN      INPUT "ATTNTWREQUENCY IN MHZ";F
     H=I(2*3.14159*F =     PRINT "INDUCTANCE
mA ;" MIC. ENRIES";y .................................Te0HEN 660IrI
"rufRyE
2iRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRitatio8100 microhenriet;G  O a1(: eOeI0TteHIN "2ieil8EI*" GEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEed coil iSc=lPP
in microhenriiNA 
       IF H>100  EN 6e
660 PRINTCoil forms:"
     PRINT "    A = 1/4 WATRESISTOR"




PRIN" +lTf"nn  Rn.nFe(: fPRINT                                                                     ====================================================================================================================1TT RES O(: fPRINT "    D = 2  1 /Z ON*=fPR1PTA= OTHEFORM
 fINPUT " SELEWVu
FO                                                                          O P 2tOWi
d2t,C,D,E)";FORM$
TORM$="ATHEN D=.09






IFOb
$="B" THEDOA4
       IF FO - P2w 
EN D= 6X
       IF F5NI PwEN D= .312;" -F .5NI P >1 EN GOTO 601aNnEhIpIFme2
6TrRPeP2ieiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii the diameter of thcoil in2Dheso :
602 PRINT "What gage ena"H">5Hwill be used:";y 6LPePI-Muoo1H12 to 40)";G
       IpFrP1 =W=.......................................................................        IF G=13 THEN WMG"y
 > .TpF"MFcL W=.R4
       IF G=15 THEN WMbee
       IpF,0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP.051
       IF G=17 THEN                                                                        tt
       IpFoMoPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
.0e
       IF G=1 Ta=W="IteN        IF G=20 THEN W=.3N TpC1 THEN                                                                                                   4        IF 
22 THEN W=.0253
       IpC3 THEN W=.0226
       IF G=24 THEW=.0" :dtTp^P1 EW=.009
TpC6HEN W=" y        IpC7 THEW=.0I2






IFN              FPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
.01R
       IF G=2 Ta=W=" 3
       IF G=30 THEN W=.01






IFN  
 EN W=.0089
       IF G=32 THEN W=.008






IFN I
FPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
.001
Tp4B0El                                                                                                                     0063
       Ip44P1 EW=.0t6
       IF G=30ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
.005;" -F 
37 THEW=.0I5
       IF G=3 Ta=W=Te4
       Ip4t
0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP(
bB
       IF G=40 THEN                                         R." =TpFOHOR G>40HEN 602
     N=((e*H*W)+6RNnH 	 *WeT21 *  
-2rI*D*D*D*****************************************************************************************************************TnsH W*es=eaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa  =     N1=((e*H*W)-SQR ($1 *  eTtFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF  
-2rI*D**D*18*H)SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSepW                                                                                     )
       IF N>N1 THEN2=N ELSE N2=NN N2=(INNRhT10))10
     PRINT:PRINTWire s20 = Am=  ae"
     PmT "Coil                                                                                                  meter =;D;" inchiT
 fR6 um0RRpr"at2ME
m=N=     PRINT "Coil ls-S(:mANtd 
ReT eA00))/100;" inVoN IN "5;Pp calcWil  )))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))dsTR=R  Nyt






IF
dd)0E  Fw 
EGOTOT(
ELSE GOTO 2N ;y
    PaH7 (00)
6
(
PRINT;yUNtd;nha
 
PImG tP 
1E A ****";yUNtd:a"rR u fWTlorD nS WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW more than half wavelength lo  "




PRIN"itWcsssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssR 
S2ng wire' or 'L
isToS
F7nnaeN  EeRT
710 IN "2ieilvrelNFs8o/lIIn (Mega HO2                                                                               M
     INPUT "How many half-waves lW  ";
 fL=492
R  I
be; en
 fPRINT "Le  th = ";L;" Feet"




PRIN"Nou=If thEs2I0nna iv 
/tE
 center H";L/2!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!e                                                 R6 ubcccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccralW=TN0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000l o c
slorrrrrsRttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttTfrequeo9t";yUNtd::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::PUT "More calculatioiAAAAAAAAAAAAAAdsTRO
 R  Nyt
       IF ANS$=nES"HEN 710;y"3*O "(: XNsn
E rt 8 T 0)

800 R6 
N      PmT "       *********************************DItPEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEENnNTPTFs2WLTdNNA ***********************************
     PR1 810 uu* "ITSlNFs8o/lI TIn (Mega (Oh1= SN      =492/F
     PRINT:PRIN"ActiWrTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTwe lenght is ";L;feet"






IFFOIR
Ta=L=L*.95
T<150 THEN L=L*.7;" -F 
F" .9 THEN L=L*.8;yUNtdoRTwcuURpcted toPpe spaTyE
or and toEITs .ance"
     PRINT "of insWiMUWcPR E
d7T
a"rR 
N      C=118/F




E=148/F
     PmT "<-----------o ; ft--------->"




PRIN" I.$mA
2
.
e      PRINT "o-----------o--------o----------------------------------------------------------------------------------------------------------T
 fR6 uX Ft"E
X E
X be(: fPRIN" 
aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa       E = oa                                         :a"rR u ts
o  <- 600 oRooooooooooooooooooooooooooooooooooo(
305 WWhE
PR SSTC> T Rp"
     PmT "               o 
96l/lpacednF"MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMe
 fPR1PI3 o                    6 in spa"Ay RHwire"
     PRINT
     INPUT "More cs=Usssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssss MEMdsTRO
 R  Nyt
       IF AN M "YESTHEN 810
     GOTO TT       R
  
rt 9
I(
PRINT




PRIN" ha
 
Hsi2O AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALCULATIONS  
(: fPRINT
ATe PRINT "NOTE: If you wish to sRl l .ute Farad6C8
IrOoLlli2FuvuTfPRINT "     must TNtaWIE2De in MEG4Ns in orT2I geresuFT
 fR6 uX fWW0conds.
 fINPUT "Wil8EISp fEl lPW
in ohmR  =     INPUT "What is the capacitance in L  2
     PRINT "TNe conW nt = C;"secondeN  imPUTMoreEIE
Usssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssss adi
E  fTt=RTR ;" -F R )0ds1ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPOeIF?(
ELSE GOTO " N   PIlF " =T(/  
 "rR 
N       PmT "           *1"o  F1  2E OF WIRE ****";yseR6 
N 1015NPel *************************************************************************************************************EISp de RANtfstance in ohms";R;yseR6 uuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuui1.W.t(B&





































































ne wire NO. is available?
 X 6PeP"7 
8 unknownnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn7r '0')"sR =        Il ; Ta=10e
        IF WN=1 THEN RW="hR4;I1Os"HTHEN RW=.1593
        IF WN=3 THERW=.2009
        IF ;h(1 EN RW=.25I(: t".Tl ;"leToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPIby4         IF ;IN0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPO"6RfI =        IF ;eEbaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa5080
        Tl ;T (1 ENW=.64t
        IF WN=9  EN RW=.077
IF WNTe TH=RW=1.018
        Tl ;T?0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPFIRfI3 =        IF ;TbP1 =RW=1R19







IF W 13HEN RW=2.042
        IF ;TGMFcL RWIr>: t".Tl ;Tb
 EN RW=3.247
        IF ;TC>1 EN RWI.094;I1OsTGT0To"nc4Id\(: t".Tlllllllllllllllllllllllllllllllll(1 =RW=6.51
        IF ;TC
ENW=8.2N IF WNMHTH=RW=10.3 =        Tl ;"?0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPFrO
b>: t".Tl ;"bP1 ERW=16.46
        Il ;3 THENW=2006
        IF WN=24 TH=RW=26.1
        IF WN=t  EN RW=33;I1Os"C>1 =RW=41.62
        Il ;7HEN RW=52.i(: IF WN=28  EN RW=66"R>: t".TllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllleToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaO"M
        Il ;R
THENW=10t2







IF W 31HEN RW=1320
IF WNOn0ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPF&b:".T4
FcL RW=211
        Tl ;"OTHEN RW=27                                                                                 S=35 THERW=3I IF WNOm0TN D23
        IF WN=37 THERW=5I(: t".Tl ;"..............FcL RW=672.6
        IF ;"OeToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPW.................................................................................A







IF W 40HEN RW=106
1I0 IN "3ts>2t 1TERIAL is thwITmY
TWL51L$
      M)t=LE
IT5;FE Nt1L$,3)





TEW12ma)TP5 uIRy2o. HTiW"Sh
 t".Tt;F  M "CNXFcL RW2222222222222222222222222222222222222222222222222222222222222222222222222222222222222N IF MAT="ALU" THENW=RW*1.6
        IF 1T$="BRA"HEN RW=RW3 =IF MAT="CAD" THEN RW=RT4.4
        IF 1T$="CHRTHEN RW=RW*1.
        IF MAT$=4lN" THENW=RW*1.4
        IF 1T$="IR>s =RW=====================================================================================5.68
IF MAT="LEATHEN RW=RW*122222222222222222222222222222222222222222: t".Tt;$R-C" THEN RW2222222222222222222222222222222222222222222222222222222222222222222222222222222222222t1







IF MAt="NOeToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaiT =        Tt;F  M "SI"  EN RW=RW*.94
        IF 1T$="STETHEN RW=RW*11;I1O)1T$==============================================================================================================" THEN RW2222222222222222222222222222222222222222222222222222222222222222222222222222222222222t7
        IF MAT$="ZIN" THEN RW=====================================================================================3.4
	IF raPs1Tu1on5;FdOC	P")HEN 10e
      L=10000*R/RW
      PRINT "For ";R;"ohET o0 ";L;feet of No.";WN;1TERIAL$;" wire"
      G 9N "I TrNPel *cnadiW nce in feet"c
      RX=R*T WW= =        IF 
>.1264  EN W=1







IF RX>.1593 THEN W=2
        Tb
Oe09 THEN W=3
        Ib
OrrR..
EN                                                                                IF RX>. 21t THEW=5







IF RX>.402 Ta=W= =        Tb
O080 THEW=7
        IFX.6405 THEN W=8
        IF 
>.8077 THEN W=9
        IF 
>1.018  EN W=10
        IF 
>1.284 THEN W" :".T"t619 THEN                                                                                                IF RX>2.04eToncFrMMMMMMMMIF RX>2.575 THEN W=14
IF RX>3.247 THEW=15
        IF 
>4.04 THEN                                                 N         IFX5.163 THEN W=17
        Tb
t3R9
 EN W=18







IF RX>8.21 THEN W=19
        Tb
Ft35 THEN W=20
        Tb
F.05 THEN W=21
        Tb
F.46 THEW=22;I1Or
C006  EN W=23
        Ib
C6.17 THEN                                               N         IFX33 THEN W69=  31>3 3 THEN                                                 N         IFX52.48 TH=W=2
        IF RX>66.0 THEN Wv=        IFX8t44 THEN W=29
        IF 
>105leTN                                                                          R>: t".Tb
Fr.7 THEN WO >: t".Tb
F&e.3 THEN W=3N IF RX>2T0TN                                                                          4( tF RX>266 TH=W=34;I1Or
444ToPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
3 =        Tb
b(1 EN                                                                                   
        IF RX>5I
FPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
37
        IF RX>62.6 THEN W=38
        Ib
W.................................................................................A THEN W=3
        IF RX>10X
EN                                    
XUNtdU0 CHsmalleHcopper wirec n  N
 4aat distanTNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN0D;" feet
 XUNtPT-Feil
E 6p safely used is NoR ;" A.W.t(B&
 
1090 INPUT "More calculatioiAAAAAAAAAAAAAAdsTRO
 R  Nyt
      IF ANS$=nES"HEN GOTO 1010 ESE .Ft"(>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>=1200     REM  PartrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrtttttttttttttttttttttttttttttttttIT                                                                                                             
U2
iW ls

      PRINT;yseR6 ueiRnEO2Re
6HTRANSMmGRNnH sz1LCULATIONS****  
 XUNtrrA IN "2ieil8EI*NtW
TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTing frequs8A11111111111111111111111111111111122222222222222222222222222222222222222222
z)";R





INPUT "Wil8EISp l nsmittin frhuenc? (ine T
R                                  =      GO Rb
X
12222 INPUT "Wil8ETf l31y ITS(in MHz) of recR  =      INPUT "What is                                                                                                               EO24NGPC
itiAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAider";R
      INPUT "What ieNd Nh*TING 29allllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll,ultelier";= =1230mtd  =      PRINT "For recIing oeR;" M222222222222228TeI;" MHz IF) & ";RD;" divider"
      PRINT	OoaN0(R-IiNu eA0000;"2 z reTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTi   cXEttttttttttttttttttttttttttttttttttttttttttttttttttttttttttto0R6eorransssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssting on ";T;" MHz (trFNit mHl tCEpPR                                                                      uM eN       PRINT "ORDER ";T/T*1000000000000000000000000000000000000000000000000000000000000" KHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHl nsm4a2a  crystal";yseR6 
N       IN "5;Pp crystal freq. calculatioiAAAAAAAAAAAAAAdsTRO
 R  Nyt
        Td Nyt="YES" THENIpIF RbA ELSE GOTO 2N 6MHPRINT "What mA*or A,odel l nsceiver?"
      PRIN"	STANDARD 146A - MOTOROLA 80D - O4CECOMMANDER";;y
6LPeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee iOX
      RcIO$ = LEFT$(RADIO$,3)
        IFADIO$= >1 =1260
        Im1DIO="MOwEN I=5t:RD=   so
2  "3*O 1.e







IF RADIO$="VOI" THEN I=8.7:R=3:TD=:.FtTbr7
      GOTFri
12e  11.7:RD=:o
18:G 30

99999 END
