10 OPEN"O",#1,"SFAVOC.0"
20 FOR X=0 TO 96:READ V$,V:WRITE#1,V$,V:NEXT X:CLOSE#1:END
100 DATA NORT,1,N,1,EAST,2,E,2,SOUT,3,S,3,WEST,4,W,4,UP,5,U,5,DOWN,6,D,6,LOOK,7,HINT,8,HELP,8,INVE,9,JUMP,10,SCOR,11,QUIT,12,SAVE,13,REST,14,ENTE,15,LEAV,16,TAKE,17,GET,17,T,17,OBTA,17,DROP,18,DR,18,WAVE,19,SHOW,20,READ,21,FILL,22
110 DATA LIGH,23,BURN,24,KILL,24,ATTA,24,KICK,25,SMAS,26,BREA,26,THRO,27,TOSS,27,EAT,28,DRIN,29,FEED,30,TURN,31,UNLO,32,CROS,33,SWIM,43,OPEN,35,CLOS,36,OFF,37,PULL,38,EMPT,39
120 DATA DIAM,0,EMER,1,CHAI,2,PLAT,2,APPL,3,GOLD,3,PEAR,4,SPIC,5,DAGG,6,KNIF,6,FIGU,7,LAMP,8,KEY,9,RING,10,ROD,11,STAF,12,INCE,13,HAY,14,STRA,14,CHEE,15,MOUS,16,MATC,17,BOTT,18,IDOL,19,SNAK,20,ABYS,21,CHAS,21,WIZA,22,RIVE,23,HEAD,24,BOOK,25
130 DATA MESS,26,BALL,27,CRYS,27,OIL,28,WATE,29,VAUL,30,CHES,31,DRAW,32,WIND,33,ROPE,34,SIGN,35,GNOM,36
