1 REM CLEAR SCREEN & VERT TAB 10
10  PRINT  TAB( 6)"** PETALS AROUND THE ROSE **"
20  FOR ZZ = 1 TO 3000: NEXT 
30  PRINT : PRINT : PRINT 
40  PRINT "DO YOU WISH INSTRUCTIONS ";
50  INPUT A$
60  IF	LEFT$ (A$,1) = "N" THEN 140
70  PRINT 
80  PRINT "THE NAME OF THE GAME IS 'PETALS AROUND"
90  PRINT "THE ROSE.  THE NAME OF THE GAME IS"
95  PRINT "IMPORTANT.  "
100  PRINT : PRINT "THE COMPUTER WILL ROLL FIVE DICE"
105  PRINT "AND ASK YOU FOR THE SCORE FOR THE"
110  PRINT "ROLL.  THE SCORE WILL ALWAYS BE AN"
115  PRINT "EVEN NUMBER.  GUESS 99 TO STOP PLAYING"
120  PRINT : PRINT "     ** GOOD LUCK **"
125   PRINT  :	PRINT :  PRINT :  PRINT :  INPUT "HIT RETURN TO CONTINUE";X$
140  DIM L(7)
150 H = 0:G = 0:F = 0
155 REM  CLEAR SCREEN & VERT TAB 10
180  FOR K = 1 TO 5
190 A =  INT (12 *  RND (8))
200  GOSUB 720
210 F = 8 * F + C
220 G = 8 * G + D
230 H = H + B
240  NEXT K
250  PRINT : PRINT 
270  FOR K = 1 TO 5
280 L(K) = F - 8 *  INT (F / 8)
290 M = L(K)
300  GOSUB 590
310 F =  INT (F / 8)
320  NEXT K
330  FOR K = 1 TO 5
340 M = G - 8 *  INT (G / 8)
350  GOSUB 590
360 G =  INT (G / 8)
370  NEXT K
380 H = H - 12 *  INT (H / 12)
390  FOR K = 1 TO 5
400  IF (L(K) - 1) * (L(K) - 4) <  > 0 THEN 420
410 L(K) = 5 - L(K)
420 M = L(K)
430  GOSUB 590
440  NEXT K
450  PRINT : PRINT 
470  PRINT "GUESS THE SCORE";
480  INPUT K
490  IF K = 99 THEN 1110
500 H = 2 *  INT (H)
510  IF K = H THEN 570
515  PRINT 
520  PRINT " NO,IT'S ";H;
530  IF K - 2 *  INT (K / 2) = 0 THEN 550
540  PRINT " (THE SCORE IS ALWAYS EVEN) ";
545  FOR ZZ = 1 TO 2000: NEXT 
550  PRINT 
555  FOR ZZ = 1 TO 2000: NEXT 
560  GOTO 150
570  PRINT : PRINT : PRINT  TAB( 16)"...YES..."
575  FOR ZZ = 1 TO 2000: NEXT 
580  GOTO 150
590  FOR N = 0 TO 2
600  IF M > 3 THEN 630
610 PRINT"  ";
620  GOTO 650
630 M = M - 4 *  INT (M / 4)
640  PRINT " O";
650 M = 2 * M
660  NEXT N
670  IF K = 5 THEN 700
680 PRINT"     ";
690  RETURN 
700  PRINT 
710  RETURN 
720 B = 6 +  RND (7) / 6
730 C = 0
740 D = 0
750  IF A > 3 THEN 890
760 B = B + 3
770  IF A > 1 THEN 810
780 D = D + 2
790 B = B + 3
800  RETURN 
810 C = C + 1
820 B = B + 1
830  IF A > 2 THEN 780
840 B = B + 11
850  GOTO 790
860 C = C + 1
870  IF A > 2 THEN 790
880  GOTO 780
890 C = C + 4
900 B = B + 2
910  IF A > 5 THEN 970
920 B = B + 2
930  IF A < 5 THEN 950
940  GOTO 780
950 B = B + 11
960  GOTO 790
970 C = C + 1
980 B = B + 8
990  IF A > 6 THEN 1030
1000 D = D + 3
1010 B = B + 5
1020  GOTO 780
1030  IF A > 7 THEN 1070
1040 B = B + 5
1050 C = C + 1
1060  GOTO 860
1070 B = B + 7
1080  IF A < 10 THEN 780
1090 B = B + 10
1100  GOTO 790
1110  PRINT "  THE SCORE WAS ";2 *  INT (H)
