10 DEPTH=0
20 GOSUB 1000
30 PRINT "Maximum depth reached:", DEPTH
40 END
1000 DEPTH=DEPTH+1
1001 PRINT "Depth:", DEPTH
1002 GOSUB 1010
1003 RETURN
1010 DEPTH=DEPTH+1
1011 PRINT "Depth:", DEPTH
1012 GOSUB 1020
1013 RETURN
1020 DEPTH=DEPTH+1
1021 PRINT "Depth:", DEPTH
1022 GOSUB 1030
1023 RETURN
1030 DEPTH=DEPTH+1
1031 PRINT "Depth:", DEPTH
1032 GOSUB 1040
1033 RETURN
1040 DEPTH=DEPTH+1
1041 PRINT "Depth:", DEPTH
1042 GOSUB 1050
1043 RETURN
1050 DEPTH=DEPTH+1
1051 PRINT "Depth:", DEPTH
1052 GOSUB 1060
1053 RETURN
1060 DEPTH=DEPTH+1
1061 PRINT "Depth:", DEPTH
1062 GOSUB 1070
1063 RETURN
1070 DEPTH=DEPTH+1
1071 PRINT "Depth:", DEPTH
1072 GOSUB 1080
1073 RETURN
1080 DEPTH=DEPTH+1
1081 PRINT "Depth:", DEPTH
1082 GOSUB 1090
1083 RETURN
1090 DEPTH=DEPTH+1
1091 PRINT "Depth:", DEPTH
1092 GOSUB 1100
1093 RETURN
1100 DEPTH=DEPTH+1
1101 PRINT "Depth:", DEPTH
1102 GOSUB 1110
1103 RETURN
1110 DEPTH=DEPTH+1
1111 PRINT "Depth:", DEPTH
1112 GOSUB 1120
1113 RETURN
1120 DEPTH=DEPTH+1
1121 PRINT "Depth:", DEPTH
1122 GOSUB 1130
1123 RETURN
1130 DEPTH=DEPTH+1
1131 PRINT "Depth:", DEPTH
1132 GOSUB 1140
1133 RETURN
1140 DEPTH=DEPTH+1
1141 PRINT "Depth:", DEPTH
1142 GOSUB 1150
1143 RETURN
1150 DEPTH=DEPTH+1
1151 PRINT "Depth:", DEPTH
1152 GOSUB 1160
1153 RETURN
1160 DEPTH=DEPTH+1
1161 PRINT "Depth:", DEPTH
1162 GOSUB 1170
1163 RETURN
1170 DEPTH=DEPTH+1
1171 PRINT "Depth:", DEPTH
1172 GOSUB 1180
1173 RETURN
1180 DEPTH=DEPTH+1
1181 PRINT "Depth:", DEPTH
1182 GOSUB 1190
1183 RETURN
1190 DEPTH=DEPTH+1
1191 PRINT "Depth:", DEPTH
1192 GOSUB 1200
1193 RETURN
1200 DEPTH=DEPTH+1
1201 PRINT "Depth:", DEPTH
1202 GOSUB 1210
1203 RETURN
1210 DEPTH=DEPTH+1
1211 PRINT "Depth:", DEPTH
1212 GOSUB 1220
1213 RETURN
1220 DEPTH=DEPTH+1
1221 PRINT "Depth:", DEPTH
1222 GOSUB 1230
1223 RETURN
1230 DEPTH=DEPTH+1
1231 PRINT "Depth:", DEPTH
1232 GOSUB 1240
1233 RETURN
1240 DEPTH=DEPTH+1
1241 PRINT "Depth:", DEPTH
1242 GOSUB 1250
1243 RETURN
1250 DEPTH=DEPTH+1
1251 PRINT "Depth:", DEPTH
1252 GOSUB 1260
1253 RETURN
1260 DEPTH=DEPTH+1
1261 PRINT "Depth:", DEPTH
1262 GOSUB 1270
1263 RETURN
1270 DEPTH=DEPTH+1
1271 PRINT "Depth:", DEPTH
1272 GOSUB 1280
1273 RETURN
1280 DEPTH=DEPTH+1
1281 PRINT "Depth:", DEPTH
1282 GOSUB 1290
1283 RETURN
1290 DEPTH=DEPTH+1
1291 PRINT "Depth:", DEPTH
1292 GOSUB 1300
1293 RETURN
1300 DEPTH=DEPTH+1
1301 PRINT "Depth:", DEPTH
1302 GOSUB 1310
1303 RETURN
1310 DEPTH=DEPTH+1
1311 PRINT "Depth:", DEPTH
1312 GOSUB 1320
1313 RETURN
1320 DEPTH=DEPTH+1
1321 PRINT "Depth:", DEPTH
1322 GOSUB 1330
1323 RETURN
1330 DEPTH=DEPTH+1
1331 PRINT "Depth:", DEPTH
1332 GOSUB 1340
1333 RETURN
1340 DEPTH=DEPTH+1
1341 PRINT "Depth:", DEPTH
1342 GOSUB 1350
1343 RETURN
1350 DEPTH=DEPTH+1
1351 PRINT "Depth:", DEPTH
1352 GOSUB 1360
1353 RETURN
1360 DEPTH=DEPTH+1
1361 PRINT "Depth:", DEPTH
1362 GOSUB 1370
1363 RETURN
1370 DEPTH=DEPTH+1
1371 PRINT "Depth:", DEPTH
1372 GOSUB 1380
1373 RETURN
1380 DEPTH=DEPTH+1
1381 PRINT "Depth:", DEPTH
1382 GOSUB 1390
1383 RETURN
1390 DEPTH=DEPTH+1
1391 PRINT "Depth:", DEPTH
1392 GOSUB 1400
1393 RETURN
1400 DEPTH=DEPTH+1
1401 PRINT "Depth:", DEPTH
1402 GOSUB 1410
1403 RETURN
1410 DEPTH=DEPTH+1
1411 PRINT "Depth:", DEPTH
1412 GOSUB 1420
1413 RETURN
1420 DEPTH=DEPTH+1
1421 PRINT "Depth:", DEPTH
1422 GOSUB 1430
1423 RETURN
1430 DEPTH=DEPTH+1
1431 PRINT "Depth:", DEPTH
1432 GOSUB 1440
1433 RETURN
1440 DEPTH=DEPTH+1
1441 PRINT "Depth:", DEPTH
1442 GOSUB 1450
1443 RETURN
1450 DEPTH=DEPTH+1
1451 PRINT "Depth:", DEPTH
1452 GOSUB 1460
1453 RETURN
1460 DEPTH=DEPTH+1
1461 PRINT "Depth:", DEPTH
1462 GOSUB 1470
1463 RETURN
1470 DEPTH=DEPTH+1
1471 PRINT "Depth:", DEPTH
1472 GOSUB 1480
1473 RETURN
1480 DEPTH=DEPTH+1
1481 PRINT "Depth:", DEPTH
1482 GOSUB 1490
1483 RETURN
1490 DEPTH=DEPTH+1
1491 PRINT "Depth:", DEPTH
1493 RETURN