90 PRINT CH0$26):       'P=6AO CuJ09ar screen code h
d 
(I100 8
ET TABA USN:N DED PRECIE2TW
 TU)
0OR":8
ET
11 7,120E7E0E 002EB
NU  2TA1E = TDON":PRINT
10E844 Sun Valley Road
:0E1 Birmingham, F 35215I
C('
160 ' CoACuserve 7441A
B=K1+E1
F)PLIE DB= 0;1OCdified  C3 -u=:N30N)eEEoE. Sandel"
10EAdded ld   00C8E JJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJ
 R9 fudmetal operatt RACrint3r88TE1 Corrected obviN(00drroBC91
 R9 added initial instructions
 R 0RINIPLIE
IPLIE
IPIE
I,1S"E7E0iLegal cTX 6
 R9s are:0TN 4UB, MUL, & DIV  C6 6NC8 
<EUR
1NC :t R0
194 PRINT:P1I(
-BT3r1 
lTF RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRrRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRegiter v"
195 PRINT " PA f
):
>nt mECA for Cler AM18MT"E7E
T"I("XZ0E<1 ExcGRP= G,6
 R9 mEMAB for Move A into B:  ";
197 PRINT " similar for C8  R
=
dgisters":PRINT
 H nPFIE0iZAP f
=UH0Tc(B:          AE-0m(MF+- Q fornmia"on.":PRNNA8fPLIE
IPIE0iWarning !!!! 100 place divisions take a XE)MTC):":PRINT:PRINTTBBiINT TAB(30);:INP("Eter 1N$CP=A==060






















































00) precisio desire "SZ$

CtA-' SIZE = MAXU) EA1NGS PRECD  N
206 PRINT CHR0O 1):           ClearAl
R9n AGn8:A0)00Ac
1I(A-Z ET;5;
0;7F=0
sETL0O=$2RT0E2h= Rr    fhETL0or04ETsr  F: IF SL600 NTTO0,S03BRS28 EOBAT;v' 
a9N= 0
I0 OFk"U
 IiSE7ENA0+S;8
E L;9=0: Tp6sNR0TITT r 
C(DIMD)AENE rSED0L  
ECAENESEAN0EZE): ' REGDF8 0FER0E I "RHE0r++++ ' **** Command Loop
1010 PRINA

Ce )OOB 80000:PRINT
O00EE7N
EP("E IU MrSIGiCOMMST(
1sIoOMrST(7uLEN EI T 0E CdIA2 ="Q""N
N A1A
(EF IoOMMST(="QUIT" H4ETTFED
10(IF COMMAND$="E080HEN GOSUB 30H7TOTO 10000
1050F COMMAND$="SUB" NTT9  OAmIH7TOT10000
X0 IF COMMAND$="OL" THEN GOSZ $F::GOTO 10000
1070 IF COMMAT(=E7V" THEN GOSUB 60H7TOTO 10000
1200 IF 6eO
ED$="DMP" THEN GOSUBTTTT:)=  1000000000000000000000000000000000r8BF IoO
 A2 ="EA" THEN GOSUB 8100:GOT10000
) fEE
U 
 A2 ="A)4ETT9 )OOB 81:GOTO 10H,122NE
U MMAN(="P:E
NTT9 )OOB s
0OTO0000
1S0EL COMMAND$="EB" NTT9  O1)s
 )=  10000
1231 IFOMMAND$="B"  THEN G==0')s
ITOO10000
   
T IF COMMAND$="0
80HEN GOSZ 00:GOTO0000
1 sEL COMMAT(= ,80HEGOSU19l4
0OO10000
  
t0EL COMMAN(="C"  THEN GOSUBRs
IFU 10H,126NE
U MMAN(="PRTHEN GOSZ  +0:G 260000I 10EL 6eO
ED$="XAB" NTT9  O19+
 )=  10000
1280 IF COMMAT(=1ACE
NTTOSUB 80
ITOO10000
   GLOMMAND$="XBC" THEN GOSUB
00
ITOTO 10000
1300 IF COMMAT(=EEHRTHEN GOSUB 90H7TOTO 10000
1310F COMMAND$="MABE
NTTOSUB 9BHTOTO 10000
1320 IF COMMAT(= 2
4L9I9 )OOB 90
ITOO10000
 EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEF IodIA2 ="CA"HEN )OOB 93:GOTO 10H,1340 NW 
 A2 ="MBA" THEN GOSc8"B"9 ) 1
7,1 sEL COMMAT(= B=4L9I9 )OOB 9B"9 )=T 7,1360 IF COMMAND$="0E
NTT9 )OOB 9600:GOT10000
 70 NW 
 A2 ="MCA" THEN GOSUB 9700:)=  1000000000000000000000000000000000rM 80 IF COMrST(Os
80HEN GOSc7 T0:G 260000I T0EL 6eO
ED$="CC" THEN GOSUB +
0OTO0000
100RIN"Invalid Command"
 R+ GOO10000
 0000 PRINT:P1I(;l(A ":PRNNA)00EL E1<E2HEN<  -':GOSUB 72
300IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII<E1 THEN SC6-E2:GOSUB 7400
 030 IF E7<EE
NTTE 31
3100 F  I=0EX S"5oI,3110 RS0TE 300 I)EA(9A 
8s    IF BF07TE
NTT300 I-E 300 t  :01:EB(I)=EB(I)-10
313EE0
314g3 OB 
BEA 1le )OOB  TrE690 RE RN
=EE7E
IPLIE0i B = B - A "PLIE1
T10F E1<E2 THEN SC=E2-"9 )OOB sr
T20 IF ElF9IDC=E1-E2:GOSUB0:0NA0: EBE
INCf4E E7=E6TH000000000000000000000000000000000 R I=E6 TO 1 STE-X
8T0C
8 00 I)sTE-0 I)
410C
7EEB(ECE0E
NTT300 I-1)=EBE-83oI8 0N S00ET"(+
H EBA3c1

0 GOSUB 
BEA0HBe  O1:E0N

e0 N  N:x0"E7E
IPIE0i C = B 2,>:PRINT:QBe )OOB 90NAR$ 00FS FI
5030  R I=E6 TO STEP -1:bG" E )3(FTO 0 STEP -1
5050      EC(K)=EC((:0B3
0"2 E)E R4
(10      IF =: ED0L0E
NTT1CT,r+C
2
OHEN E K+1)9
rE0C NC 
sEE$
sEE$:01:EC(901)=EC(K+1oTNAR$G0C
2
OEND
5100                                                                      E0
5110    FOR L=EE 2B3N I-6
510C
2I<)F+1)<T " X0C
a36T :0 0)=0
51((((E8=E8+1
5150 NEXT
510FS6+E7 EO37  NARX70 )OOB 79
5190F0UI,60000 PRINT:P1I(tU=0
NC1i:PRINT
T  I31=0HEN PRINT "Divide b3Zero":N  N'00OSUB 90NA +3n
"h9 3 

9)E TE7:E0FC 00 I):NEXT
6040 IF E2<E1 THEN SC6-E2:GOSUB 7400
T
C(IFI<E6 THEN E7=E6
T =

 3t6+1 :E8=1
6090  T
6B- 
  ZF=0
'=F:I=0:WHILE )EC(31,N$E)E TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTE 
IH7EG 7=TSr1120    IE
sssssssssssssssssssssssssssssssssssssssssssssssssssssss SIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII(I)EA(1E
NTTOSpI s
ITOTO690' 0              sFS TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT(E8)+1
6140                                                                        R=E6 TO 1 STEP 7,615FTD 00 E 300 E-
F09116FT4EE
S00ETECE0E
N BF oSEB(I-E-78 00 I)sT"(+
6170"0.7c1 G0ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo r1200 NFSCc  THEN E8=E,O+ TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT:E2=E4:FOR=0 TO E7:EB(I)=EH(I):NIc11
(GOSUB 79
6+F0UI,6500 ZF=1
 X0 FOR I=1 TO E0 7,652F:IF EB(I)<>0 TH=NEE0;,6530 RS0
t  TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT(I)
6540 NEXT
 CF IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII<SL
NTTFS8+1 ELSNEE0X'G09F0URN
70GE1Tet Shift Digits
70)1I TNnter num09r of digits tCB S"ft: "SC
1 )
I9D N+0 '  S P0EC
rCI0EC
0E=3digit)
'E  R=0 TO E6-SAH12F:E)E TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT"B  R4I130 NEXT
7140 FOR                                                       -SC+1 TO1
7150 R
NTE B 4I160EXT:I






















































=E6-ShSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS-SC
7190 RE RN
s vShift A right (SC digits)
7210  R I=E6 TO3N I-6
7220              N0E: ! 3D)EAH230 CIc"N  
T FOR I=0 TOWNAH2((((EA(IlH260 NEXT
7270 E6=E6+SC:EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE+SC
OG0I=)EAH300 '  3 PC
0
s9ft (SdTO:0  RNE60 FOR I=0O 
C  4I32F:E)E TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT"B  R4I30ZCIcK"T)SETTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTOd0TO E7
7350" S00ET0
736EE0
737IN FI  > S222222222222222222222222222222222222222222222222222-6AH390 RE RN
"B)6A3 P0EC
righ!=9igits)
7410 FOETTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT O0 STEP -1
740C
8 00 I+SC)sT9AHEBA7c"N
0:000000000000000000000000000000000 R I=0O OoI,7450    EB(I)=0
7460 NEXT
"I0 E7=E7+SC:EC B  XAHG09F0URN
7500 '  Shift C left (SC
P0
30  R4I510 F  I=0O EtOXAH 00C3lF0EC(I+SC)
7530 NEXT
 ,T  R I=E8-S(f=  E8
7550    EC(I)EAH50ZCIc:X+FS FSO> O3E-E=6AH590 RE RN
+ vShift C right OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO )S0):'10 F  I=EEs0E-X
8s    EC(I+SE 3lF09AH60ZCIc'(FOR I=0O OoI,7650" 
sETE B 4I660 NEXT
E170 E8190SC:U3EE=6AH69MN ORN
7700   Normalize A
771CeHLE ( iE1) AND (EA(E6)=08 1=E6-1:WEN 4I720 IF   BF9T38lHFU 7790
7730 N3D2<0 THEN SC=1:GOSUB0BB0OTO 7794I740 X:WHILE ECZ  1SIEA(E ( I=I+1:WEND
77(IF I>1 THEN SC=I-1:)OO1I00NAH79MN ORN
7800   Normalize B
781CeHLE (
:S21,EV 00 TE ( PFI=EoI5OA1AHsF E7=0HEN E2=0:)=  7890
7830 IF B$ =0IEN SC=1:GO=0'T:0GOTO 7890
7840=1:HILEE
;O  5
N$E)E T$ PETFG 75OEND
 RsEL :f4ETTE=I-1:GO=0'hB:4BeF0URN
7900 ' ormalize C
7910 HILE (E"E3,N$E E8)=PFS FS-75OEND
ER 00EL El7EN E3=0:GOTO 79NAH90E EC(0)<>0HEN<:GOSZN100:G 21InB 4I"(I=1:WHEN (I<E3) AIV lF ( PETFG 75OEND
7 sEL :f4ETTE=I-1:GO=0':lcInBeFeD 4C
f6 Dumpd :Bo R
l),8Be  O1(00NL(GOSZ 00
8009 )ON1)NART90F0UI,81 ' Extract EA from string
A + GO=0
RE)71I:OT "Enter "EN$38888888888888888888888888888888888888888888888888888888888888888888888NN0
0OR 
(FOR I=1 TO LEN(VeAR
X$=NN 0$x4NA
OR4S8"((((NC
0O 
F9IDSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS:)=  8180
I C
7
6$<"5 R (>"9" THEN PRI0iError in 4J6E9N
"i;I
A 10    E6=E6+1:r70              N031)=VAL(X$,I NEX:GOSZ
I00
A G ETURAR0( ' PRINTM" +E7E0igR08RU$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$AR02B)
'=0 THEN P1I( :Bn U4
8230 F  I=TO E6
8240"NL I=101 THEN P1I(3>; :CC=CC1
8250    PRI0C3N79M2i;E)E S
CC=CC+1
O10 IF I<>ETHEIF ABSE-')MI6CF9ID:E7i "
88TW$We01:NWO"0ENN PRINT:PRINT "    ";:((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((S  12 IF OBF9IDiE7E0i  0PW$A" 0r+ZCI4
P INT
829MN ORN
8300 T36TRACT EB FRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRD9E79NAR+ )OOB 96 :INPU"Enteli,ENi3  T(EN$)
832E  R=1 TO LEN(EN$)
8330                                                       $=MID$(EN$,I,1)
83((((IC
0Oi." THEN E2=E7TOO8380
O'lt"NL X$"0"R Xi"9" TH)PLIE0iError in B, cGT78

 4SEX0    E7=:01
8370                                                                                    00FI)=VAL(X$,'ZCI(:GOSUB  T4SEeMN ORN
8400  ' PRINT B
841P8
ET "B: 08RU$ 4SsF E2=0HEN PRINT "008R0,M" 0s)SEf=  E,9
T"NL I=
(f4ETT"E7i."; :(We01
"
BtPRINT USI0 "#0Is0ETEB U$e01:B8T0CEL I<>EE
NTTICE08N-S22AE=0 TH)PLIE0i ";:(We01
911"NL CC70 THEN PRINT:PRINT "    ";:(((((((((((((((((((((((((((((((((((EL E2=0HEN PRINT "  ":CCAR0P10ZT:PRNNA

009 OI,8500 ' $-T70T
 X33333333333333333333333333333333333333333333333333 T5d Ost"ng
8510 GOSUBe00 :
R)("Ent
=>0i,EN$  EOEuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuu " RU0000000000000000000000000000000000 R I=1 TO LEN(VeARRCt" 0O16TT((EN$,I,1)
854F:IF X$:EC:E
NT EOFnITOTO 8580
8550                                                                               E
6$<"0" OR X$>":E
NTT"E7E0iE
-0"n C, char"I
8560    E81901
8570 R
sFS T<U
 T0C
9ARR0 NE0 :GOSUB 7900
8590 RE RN
+ f:
>nt C
8T0"E0 "C: 08RU$ 4SB)EE3=0 THEN PRI0i0"; O$AR  M E  R=1 TO E8
8640 HEEL0000000000000000000000000000000000000000000000000000+1 THEN PRINT "."; :CC=CC+1
O7 sC
PFIE0C3N7 "#";EC(I); :CC=CC+1
OMT0C
7EEL "E3HENF ABS(I-E3)MODUBF9T"E7ER";
866666CC=CC+1:IF CC>70 THEN PRI
IPLIE0i R:BM"  MS(RU$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$EL E3)4ETT"I("  ";:C,)
10ZCI4
P INT
O8+ RE RN

B)6  Exchange ;4nE+ IF E"E7HENSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS ELSE J=E7
8720  R I=0 TO J:UAP EAE 
EB(I):NEXT
8730 SAP  AN7:SAP C1S
8790 RE RN
 T mE
(J6E9
TOG,o:9r0 IF  iE8 THEN J=EF I  TCE=E8
8820 FOR s  J:SWAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA(I),EC(I):NEXT
880E AP1,E8:SWAP5
E, 
9F0SI,8900 '  =AXE9
 P= B C 
8910 IF E"E8HENSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS ELSE J=E8
8920  R I=0 TO J:UAP EBE 
EC("T.7c" 
 EB3 4FI,E8:SWAP E2,E3
AnBeF0URN
 F: '  0 H0TfBl rTO0NA
0 + )OOe300
9020 GOScMc1G )TO=0
RG0NA
0 G09F0URN
9100 '  tT=9 AL7'10 IF  iE7 THEN J=EF I  TCE=E7
9120  R I=0 OJ:EB(IC  Ia7c1RM 0I=E6:E2=E1
9190 RETURN
9200 ' =d 0,o "
9210 IF E"E8HENSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS ELSE J=E8
9220  R I=0 TO J:0 I)=EA(I):CIc1=S0FS 31:E3=E1
9290 RCeD rREB( ' Clear A
9320  R I=0 TO E6:EA(I)=0:NEXT
9330 El6=0
9390 RCeD rR
)6  MoCgp
9410 IF E"E7HENSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS ELSE J=E7
9420 FOR I=0 TOI8 D)E TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT(I):NEXT
94301=E7:E1=NA

009F0URN
 s0E1 =  e t rH00IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII>E8 THEN J=E7 I CE=E8II U0000000000000000000000000000000000 R s  J:E IC  Ia7c1H C 0 E8=E8 EO3A

00I=)EA
 100  ' 0 H0TgENA
 120 FOR I=0 TOI:EB(Il 
NA
30 E7=0    B rR190 RETURN
9700 ' =d 0tC,N+ N31E8 THEN J=E6 ELSE =E8
9720 F  I=0O J:EA(I)=EC(I):NEXT
9730 E6=E8:E1=E3
9790 RETURN
9800 ' =d 0tl
I 0E E7>E8 THEN J=E7 ESE J=E8
982E  R=0 TO J:EB(I)=ECE PZCIc1H  S0FI=E8    3EEASG09F0URN
99 '  Clear C
992E  R=0 TO E8:EC(E BG.7c1R 0 E8=0:E3=0
E0 RCeD rN-00 I)=E Ia7c1H  S0FI=E8:E2=E3
989MN ORN
9900   Clear C
9920 FOR s  E8 lF0E BG.7c1RREBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB=0:UB rRF:  =oUA BT
8710 IF E