10 REM INSTRUCTIONS FOR "SUPER STARTREK"  MAR 5, 1978
20 FOR I=1 TO 12:PRINT:NEXT I
21 PRINT TAB(10);"*************************************"
22 PRINT TAB(10);"*                                   *"
23 PRINT TAB(10);"*                                   *"
30 PRINT TAB(10);"*      * * SUPER STAR TREK * *      *"
31 PRINT TAB(10);"*                                   *"
32 PRINT TAB(10);"*                                   *"
35 PRINT TAB(10);"*************************************"
36 FOR I=1 TO 8:PRINT:NEXT I
40 INPUT "DO YOU NEED INSTRUCTIONS (Y/N)";K$:IF K$="N" THEN 2000
44 PRINT
45 REM PRINT "TURN THE TTY ON-LINE AND HIT ANY KEY EXCEPT RETURN"
46 REM IF INP(1)=13 THEN 46
50 REM POKE 1229,2:POKE 1237,3:NULL 1
90 PRINT"      INSTRUCTIONS FOR 'SUPER STAR TREK'"
100 PRINT
110 PRINT"1. WHEN YOU SEE \COMMAND ?\ PRINTED, ENTER ONE OF THE LEGAL"
120 PRINT"     COMMAND S (NAV,SRS,LRS,PHA,TOR,SHE,DAM,COM, OR XXX)."
130 PRINT"2. IF YOU SHOULD TYPE IN AN ILLEGAL COMMAND, YOU'LL GET A SHORT"
140 PRINT"     LIST OF THE LEGAL COMMAND S PRINTED OUT."
150 PRINT"3. SOME COMMAND S REQUIRE YOU TO ENTER DATA (FOR EXAMPLE, THE"
160 PRINT"     'NAV' COMMAND COMES BACK WITH 'COURSE (1-9) ?'.)  IF YOU"
170 PRINT"     TYPE IN ILLEGAL DATA (LIKE NEGATIVE NUMBERS), THAN COMMAND"
180 PRINT"     WILL BE AB OR TED"
190 PRINT
270 PRINT"     THE GALAXY IS DIVIDED INTO AN 8 X 8 QUADRANT GRID,"
280 PRINT"AND EACH QUADRANT IS FURTHER DIVIDED INTO AN 8 X 8 SECTOR GRID."
290 PRINT
300 PRINT"     YOU WILL BE ASSIGNED A STARTING POINT SOMEWHERE IN THE"
310 PRINT"GALAXY TO BEGIN A TOUR OF DUTY AS COM AND ER OF THE STARSHIP"
320 PRINT"\ENTERPRISE\; YOUR MISSION: TO SEEK AND DESTROY THE FLEET OF"
330 PRINT"KLINGON WARWHIPS WHICH ARE MENACING THE UNITED FEDERATION OF"
340 PRINT"PLANETS."
360 PRINT
370 PRINT"     YOU HAVE THE FOLLOWING COMMAND S AVAILABLE TO YOU AS CAPTAIN"
380 PRINT"OF THE STARSHIP ENTERPRISE:"
385 PRINT
390 PRINT"\NAV\ COMMAND = WARP ENGINE CONTROL --"
400 PRINT"     COURSE IS IN A CIRCULAR NUMERICAL      4  3  2"
410 PRINT"     VECTOR ARRANGEMENT AS SHOWN             . . ."
420 PRINT"     INTEGER AND REAL VALUES MAY BE           ..."
430 PRINT"     USED.  (THUS COURSE 1.5 IS HALF-     5 ---*--- 1"
440 PRINT"     WAY BETWEEN 1 AND 2                      ..."
450 PRINT"                                             . . ."
460 PRINT"     VALUES MAY APPROACH 9.0, WHICH         6  7  8"
470 PRINT"     ITSELF IS EQUIVALENT TO 1.0"         
480 PRINT"                                            COURSE"
490 PRINT"     ONE WARP FACTOR IS THE SIZE OF "
500 PRINT"     ONE QUADTANT.  THEREFOR E, TO GET"
510 PRINT"     FROM QUADRANT 6,5 TO 5,5, YOU WOULD"
520 PRINT"     USE COURSE 3, WARP FACTOR 1."
530 PRINT
540 PRINT"\SRS\ COMMAND = SHORT RANGE SENSOR SCAN"
550 PRINT"     SHOWS YOU A SCAN OF YOUR PRESENT QUADRANT."
555 PRINT
560 PRINT"     SYMBOLOGY ON YOUR SENSOR SCREEN IS AS FOLLOWS:"
570 PRINT"        <*> = YOUR STARSHIP'S POSITION"
580 PRINT"        +K+ = KLINGON BATTLE CRUISER"
590 PRINT"        >!< = FEDERATION STARBASE (REFUEL/REPAIR/RE-ARM HERE!)"
600 PRINT"         *  = STAR"
605 PRINT
610 PRINT"     A CONDENSED 'STATUS REPORT' WILL ALSO BE PRESENTED."
620 PRINT
640 PRINT"\LRS\ COMMAND = LONG RANGE SENSOR SCAN"
650 PRINT"     SHOWS CONDITIONS IN SPACE FOR ONE QUADRANT ON EACH SIDE"
660 PRINT"     OF THE ENTERPRISE (WHICH IS IN THE MIDDLE OF THE SCAN)"
670 PRINT"     THE SCAN IS CODED IN THE FOR M \###\, WHERE TH UNITS DIGIT"
680 PRINT"     IS THE NUMBER OF STARS, THE TENS DIGIT IS THE NUMBER OF"
690 PRINT"     STARBASES, AND THE HUNDRESDS DIGIT IS THE NUMBER OF"
700 PRINT"     KLINGONS."
705 PRINT
706 PRINT"     EXAMPLE - 207 = 2 KLINGONS, NO STARBASES, & 7 STARS."
710 PRINT
720 PRINT"\PHA\ COMMAND = PHASER CONTROL."
730 PRINT"     ALLOWS YOU TO DESTROY THE KLINGON BATTLE CRUISERS BY "
740 PRINT"     ZAPPING THEM WITH SUITABLY LARGE UNITS OF ENERGY TO"
750 PRINT"     DEPLETE THEIR SHIELD POWER.  (REMBER, KLINGONS HAVE"
760 PRINT"     PHASERS TOO!)"
770 PRINT
780 PRINT"\TOR\ COMMAND = PHOTON T OR PEDO CONTROL"
790 PRINT"     T OR PEDO COURSE IS THE SAME AS USED IN WARP ENGINE CONTROL"
800 PRINT"     IF YOU HIT THE KLINGON VESSEL, HE IS DESTROYED AND"
810 PRINT"     CANNOT FIRE BACK AT YOU.  IF YOU MISS, YOU ARE SUBJECT TO"
820 PRINT"     HIS PHASER FIRE.  IN EITHER CASE, YOU ARE ALSO SUBJECT TO "
825 PRINT"     THE PHASER FIRE OF ALL OTHER KLINGONS IN THE QUADRANT."
830 PRINT
835 PRINT"     THE LIBRARY-COMPUTER (\COM\ COMMAND) HAS AN OPTION TO "
840 PRINT"     COMPUTE T OR PEDO TRAJECT OR Y FOR YOU (OPTION 2)"
850 PRINT
860 PRINT"\SHE\ COMMAND = SHIELD CONTROL"
870 PRINT"     DEFINES THE NUMBER OF ENERGY UNITS TO BE ASSIGNED TO THE"
880 PRINT"     SHIELDS.  ENERGY IS TAKEN FROM TOTAL SHIP'S ENERGY.  NOTE"
890 PRINT"     THAN THE STATUS DISPLAY TOTAL ENERGY INCLUDES SHIELD ENERGY"
900 PRINT
910 PRINT"\DAM\ COMMAND = DAMMAGE CONTROL REPORT"
920 PRINT"     GIVES THE STATE OF REPAIR OF ALL DEVICES.  WHERE A NEGATIVE"
930 PRINT"     'STATE OF REPAIR' SHOWS THAT THE DEVICE IS TEMP OR ARILY"
940 PRINT"     DAMAGED."
950 PRINT
960 PRINT"\COM\ COMMAND = LIBRARY-COMPUTER"
970 PRINT"     THE LIBRARY-COMPUTER CONTAINS SIX OPTIONS:"
980 PRINT"     OPTION 0 = CUMULATIVE GALACTIC REC OR D"
990 PRINT"        THIS OPTION SHOWES COMPUTER MEM OR Y OF THE RESULTS OF ALL"
1000 PRINT"        PREVIOUS SHORT AND LONG RANGE SENSOR SCANS"
1010 PRINT"     OPTION 1 = STATUS REPORT"
1020 PRINT"        THIS OPTION SHOWS THE NUMBER OF KLINGONS, STARDATES,"
1030 PRINT"        AND STARBASES REMAINING IN THE GAME."
1040 PRINT"     OPTION 2 = PHOTON T OR PEDO DATA"
1050 PRINT"        WHICH GIVES DIRECTIONS AND DISTANCE FROM THE ENTERPRISE"
1060 PRINT"        TO ALL KLINGONS IN YOUR QUADRANT"
1070 PRINT"     OPTION 3 = STARBASE NAV DATA"
1080 PRINT"        THIS OPTION GIVES DIRECTION AND DISTANCE TO ANY "
1090 PRINT"        STARBASE WITHIN YOUR QUADRANT"
1100 PRINT"     OPTION 4 = DIRECTION/DISTANCE CALCULATOR"
1110 PRINT"        THIS OPTION ALLOWS YOU TO ENTER CO OR DINATES FOR"
1120 PRINT"        DIRECTION/DISTANCE CALCULATIONS"
1130 PRINT"     OPTION 5 = GALACTIC /REGION NAME/ MAP"
1140 PRINT"        THIS OPTION PRINTS THE NAMES OF THE SIXTEEN MAJOR "
1150 PRINT"        GALACTIC REGIONS REFERRED TO IN THE GAME."
1990 REM POKE 1229,0:POKE 1237,1:NULL 0
2000 REM PRINT:PRINT:PRINT
2010 REM PRINT "TURN CASSETTE PLAYER ON AND HIT ANY KEY EXCEPT RETURN"
2020 REM IF INP(1)=13 THEN 2020
2030 REM PRINT
2040 REM PRINT "TURN CASSETTE PLAYER OFF AND "
2050 REM PRINT "TYPE 'RUN' WHEN COMPUTER PRINTS 'OK'"
