	REM	TELEPHONE LIST
	INPUT "FILENAME: ";FILENAME$
	INPUT "ENTER AREA CODE YOU WANT OR 'ALL':";B$
	PRINT
	IF B$="ALL" THEN PRINT "TELEPHONES FOR ALL AREA CODES"
	IF B$<>"ALL" THEN PRINT "TELEPHONES FOR AREA (";B$;")"
100	REM
	FILE	FILENAME$
 
10	REM
 
	READ #1; LAST$, FIRST$, ADDRESS$, CITY$,ZIP$,AREA$,TEL$
	IF LAST$="END" THEN 20
	COUNTER=COUNTER+1
	IF TEL$="=" OR TEL$="==" OR TEL$="= =" THEN 10
	IF B$<>"ALL" THEN 15
	PRINT LAST$;"-";FIRST$;TAB(26);"(";AREA$;") ";TEL$
	GOTO 10

15	REM   TEL FOR SECIFIC AREA CODE
	IF B$=AREA$ THEN PRINT LAST$;"-";FIRST$;TAB(26);TEL$
	GOTO 10

20	REM
	PRINT
	PRINT "END OF LIST"
	END
