100 'TEST PROGRAM FOR CP/M COMMAND LINE FETCHING MODULE
110 '***** CAUTION ****** THIS WILL ONLY RUN PROPERLY WHEN COMPILED *****
120 '
130 'By Bill Bolton, Software Tools, P.O. Box 80, Newport Beach, NSW 2106
140 '26/Jan/1981
150 '
160 B$="ANYTHING"
170 PRINT
180 INPUT "Please type a short message : ";ASK$
190 LET A$=STRING$(15,32)
200 CALL CMD(A$)
210 PRINT
220 PRINT "*** THE NEXT LINE IS THE CP/M COMMAND LINE ***" 
230 PRINT
240 PRINT A$
250 COPY$=A$
260 PRINT
270 PRINT "*** THE NEXT LINE IS A FIXED STRING ***"
280 PRINT 
290 PRINT B$
300 PRINT
310 PRINT "*** THE NEXT LINE IS THE SHORT MESSAGE ***"
320 PRINT
330 PRINT ASK$
340 A$="SHORT STRING"
350 PRINT
360 PRINT "*** THE NEXT LINE IS THE ORGINAL COMMMAND LINE STRING REASSIGNED ***"
370 PRINT
380 PRINT A$
390 PRINT
400 PRINT "*** THE NEXT LINE IS A COPY STRING OF THE COMMAND LINE ***"
410 PRINT
420 PRINT COPY$
430 END
