10 :REMMMMMMMMMMMMMMMMMMMMMM MDNEDIT.BAS *************************
20 :REM		AL 	%DEA T0YD81NM-
 	AU( A DATA ENTRYND ED)1G SUBROUTI7U*0M SIC 5.X
40 :REM* FOR TER1ALRM H	EH,MITHOUT CURSORH
T1"10= B 	AUT$NM$:
T  NN+INE$F.TGETSG OR ED)1G DATA WITH HFED
60 :RE1
MH000000000000000000000000000000000L
GTN FORI(PAU,SSG OR RANDOM ACCESS T$01C$:N 	AN,= A 	UM2.1EDIT.B:.TR C 
 TDFILO)H
 )
8:REM* 
-
 	AU((((((((((((((((  1OF THE BASEDIT FUNCTION                    
12DIP((((((((((((((((((((((((((((((((((((((((((((((((( DATA NMNGN = ,12345,10

:AT X P
ER 2 = ,1234567890,'NMAT X NUMBER 3 = ,AMAO DEU  140 FOR X=TO 3
150 READ M 	
MMERLENGTH
160 GOSN 10000
	 
S$.$WU0N80G.E(

80 PRINT AN1RN),ANS$(2)BS$( 1B
:T
D
1
	 : 	REMN1
 GET DATA AND EDIT FUNCT1DR
1010 : 	RURI0
:MO=U2M:+CAT107
10:NMRA7C1-R $:RH
UF8 BAM$="
M8 +R08O AD H$C2N=
	
10 BMRA7RN
PRI$26
 IO
LLOWS
1 EMR		'ENT
UTR MODIFICATION OF M AE
D
100 	REM	
SHOWG$
RTIGM
MH:11(5L0 	M I$0O:RH T8LUTMMAO2ONU CAO M(
:
: OM
($SINAICCURSER RIGHT..	>