10 '  EX7F6N 6eBAS, version 1.1
20 ' 'ut2,L)))04w users toPen:aH$Im
 nFbAFore logging ofs)o'g  X
As4by Br 
K(4L)OTE=kip Hans(X)/81 (?)
40 ' HS()OTkeeHVegrTbCk

,0l,
ARne	+ta system stuff added
50 '             by Ben Br') 1(11/81
F)o      NEa0e this isCe Et to. comN C"  
AS2,0led "BYE.II6a(01R0e
7'      threal asC6b0y-languagee 0Is   o(010E:4is0
g62tACe9 is
80 ' giv(  41er naa )1e	7)0aH)Clr  y(Fa, HN(5CLst way toN(kfN6)0dD
lT1Ts i0+gA):=Es-'to ass6b0e a dummy file likthe follow4 EE")o             7RY	BYEX
92 '             BYEX 
HRCaXFT
2
93 ' 	RET
94 ' where '0FC$e)
CO1a  eRsSCR3,N hiH)81e reasN(Fl Es. hen you
)5 ' just inX$7alaH)ClnL 01=================================E L80 to 4ad the BYE.REL file pro-
96 '      ducesFmsEd es   HS)s BYE.BAS:  'L80 BYE,BYEX,BE/N/E'
7 '  
100	 L8
I)0ine for users to leaN(E
)eCents before lsging off
cT)o
130 DEFd)ewZ
oDIM H(6),H8 "E

3=DcF(4g
y G 
9+"e)iG9
P0INE"I",1,"A:e3iCNTU::"X)H 1,N$,ksSA+
=LeT 3cH$NT0 PRI$Dcso RPT "W4L0+HC
a  
 eaE
)eCentsYN)? P:C=N2OSUB00:
tcHT uRs :#lSn 0
e H4Bd ssTtlSn 0
e H4S"w=1HRSstc$TT)  r:#lSB$,1)<>(6)+(tH lSB$,1)<>+3 =1HSl
210 PRd2
2'OPEN "R",1,"A:COMMEN
O)65:FI:oH 1,"C"o GHoGET#1,1:RE=VAL(RR$2PN t  5
soIF RE=1 THEN RE=2
1f)=
OOR4m: "+N$3 )7























































































































0G$SLe 3d 0)iPo'1Ts6 Z
y5ReuN
V,81e date in e3iCNT9
r"DT0H$7(NUT#1,RE
6'PRINT "Ente
4mmenF U 6 etur4 o end, (16 Tne A 
8)"
290 PRd2
300 PRI ) 4eH5i)$"reOtCnEs
843l
e6(S1HR<F(H5,, n=RE+1:S$=B$:R P0RN2OSUB 510:PUTHarn
340 GO g)
350 S$=STR$(RE):RL=Tt$"reOt10:"T#1,Nie=E
 NT
OSB 440000
370 P:d(B60ease calldI8
5$ T u00IeL  
6T
0  s6HS)0T1a $Cmy file0P)
= int0+7i1aFy s4BE
395 END
"T 

i)IaE1Htit N3Tng iN4 B$ from console
420 '
s)oGO Rtm5BHo0 B$=SeE
H$ 50s :Q )t2 S0 THERETRN
F)  rT"54THENXEE
T)rRR sR
/R7tHH-0
H$ 80     MID$(B)ZZ,1)iN G 
 S
 E(
 ",Zah))+32*(ASC(MID$(B$,sR)1))T   aE
" uL40 ZZ
500 R  R LHyh0 '
520 '  Fil)(k9l+F  C555555555555555555555555555555555 :D)37CrT)o
540 LS "r 2#lSS$+SPA(
 T0	
 s  (
45P G 1"oCHR$(10)
X0 RETURN
560 C"5NE3
 V$="cCR 'NC$Uy )::" 2 14 aEmtls 
XP
1
7 THSuBHyrsgXP 
S
 THSFRnE
FT rTTNeEIHu4THS6 RPT CHR$0  L
OTO 570
610 SAV$=SAV$+CHR$(NCH): CH
5PeGPEHrRPT CHR$X1 0eHGIF N6
3S1Hs";T CHR$( 0Ds9oGOTO 570
0 IF N6
S1HR6  E=E PRI "O
i$(SAV$,1);: GOTO5BH$l ITTN6
'THE570 ELSPRINT ERS$;
660 CH
5P6(He4SAV$eEFT$(SeE
 "C): GOTmR Ds  IFCH=8HEN 6nE
l I
XP
P-THEN PRIOETURN
 s4IF NCH=21 THEN PRIN" #"08  URF2
700 IF NCH<>  OR CHC=0 THEN 570
PoFORe""HE UR5P4PRINT ERS$;: NEXBCC: GOTm5BH$ 40000 TssssssssssssssKOonTne from HankeE(+fE
,) modified
"10 F5
 L$R5C
 L0me first


1NoC=32)o C=CRCK g ($E=D$Ei)o Notthat this ra ounta4:e  r(,SN5e+
)=oe< ClocY 4,oH(1)=INPM, AND RE/2)=INP(CN ae

=D((
40 H( SIa A0  N
pt1 E "AH;(C+TC
(cSD((
50 H(5)=Ia A9








































cRE/6)=IN)eG ) AND5

1f)IknE


 'P:de1s";T$+" "+O$3F
TlC"'ff at ";
44280F$="#"


N s4FORa1(R75 co4300 P:d) R e;G TF$H(IN
4434IF I=2 THEN PRIN":";
44320s TIH  THEN PRI )6:aE

s),oNEXT I
44340 P:d2
TR54' ow get H1 eM#6 rstoredlC
 EtgFF$RRF (44t yet d;e5C as o 1(11/81)

T0Poo14NEEK0(  i(2)=PEEK(75):HT(3He2  )TaE
 tNoHT(4He2  )T  nPo SPA  )T8):HT("HeeI dT  
44730 '  And c0culate the differendA$H =D() t")  r:4N,<HT(6) THEH(6$E8 MHi1  SH(5)-1
446'IF H(5)<H i , 12Th  SH(5)+6:H(4)=H(4)1
447oIF H(r
10 E T =1HR1 E "$E  $PL24"o1 )-1
44770 IF H(3)<H S , 12Th "oSH(3)+6:H(2)=nE3 1
44780 IF H(2)<HT(2) THEN H("$EnEI
NL24141 " 
EE) s4H N 24N,-HT(6):HD(5)=H(5)-HT(M$ E "$En(h0 E aE

:FT)
)=24"owo"o n1nE3
4EE3 oEEHD(1)=H(1 :i(1)
:0N6 RPT "You were on 1e system for ";
44
0 TF$="#"
44830 FORa1(T5 co4)'PRd) R NG SV
4M 0eH$ 4850 IF I=2 THENOINT "RP
458oIF I=4 THEN PRIN":";
45870 NEXI
BBF(NRIN" (hrs/mins/secs)HNRd2
45890 RETURN
ePIR7h11111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111