10 REM Test KILL, NAME, and FILES statements
20 PRINT "Creating test file..."
30 OPEN "O", 1, "test1.txt"
40 PRINT# 1, "Hello World"
50 CLOSE 1
60 PRINT "File created"
70 PRINT ""
80 PRINT "Listing files:"
90 FILES "test*.txt"
100 PRINT ""
110 PRINT "Renaming test1.txt to test2.txt..."
120 NAME "test1.txt" AS "test2.txt"
130 PRINT "File renamed"
140 PRINT ""
150 PRINT "Listing files again:"
160 FILES "test*.txt"
170 PRINT ""
180 PRINT "Deleting test2.txt..."
190 KILL "test2.txt"
200 PRINT "File deleted"
210 PRINT ""
220 PRINT "Listing files one more time:"
230 FILES "test*.txt"
240 PRINT ""
250 PRINT "Done!"
260 END
