3000	REM	LIST
	PRINT "TURN PRINTER ON !!!!!!!!!!!!!!!!!!!!!"
 	INPUT "FILENAME: ";FILENAME$
	COUNTER=0
3060	FILE	FILENAME$
	LPRINTER
	PRINT FILENAME$
 
3100	REM
	READ #1; CALL$,NAME$,QTH$,FREQ$,\
	DATE$,TIME$,CARD$
	IF CALL$="END" THEN 3200
	COUNTER=COUNTER+1
	PRINT CALL$;" -";TAB(11);NAME$;TAB(30);QTH$;\
		TAB(55);DATE$;"  ";CARD$
	GOTO 3100

3200	CLOSE 1:CONSOLE
	INPUT "New filename? (or 'END')";F$
	IF F$="END" THEN 3300
	FILENAME$=F$:GOTO 3060

3300	REM
	LPRINTER:PRINT:PRINT "END OF LIST"
	PRINT COUNTER, "NAMES":CONSOLE:PRINT
	GOTO 2
