10 RANDOMIZE
15 DIM T$(595),H$(595)
20 REM TO INCREASE DATA (1) ADD DATA (2) CHANGE DIM (3) CHANGE RND
25 REM AND CHANGE LOOPS IN 1800 & 1900
30 INPUT "DO YOU WANT INSTRUCTIONS";Z$
40 Z$=LEFT$(Z$,1)
50 IF Z$="Y" THEN GOSUB 2000
60 PRINT:PRINT "DO YOU WANT TO TRANSLATE:"
70 PRINT "   (1) ENGLISH TO LATIN"
80 PRINT "   (2) LATIN TO ENGLISH"
130 INPUT Z
140 IF Z=1 THEN GOTO 1800
150 IF Z=2 THEN GOTO 1900
160 GOTO 60
260 Y=INT(RND*595)+1
270 PRINT:PRINT H$(Y)
280 PRINT:INPUT A$
290 IF A$="QUIT" THEN GOTO 3000
300 T=T+1
305 IF A$="I GIVE UP" THEN PRINT "THE ANSWER WAS ";T$(Y);".":GOTO 260
310 IF A$=T$(Y) THEN G=0:PRINT "THAT IS CORRECT!":C=C+1:GOTO 260
320 IF A$<>T$(Y) THEN PRINT "SORRY, THAT IS NOT CORRECT."
330 G=G+1
340 IF G<3 THEN PRINT "TRY AGAIN.":GOTO 280
350 IF G=3 THEN G=0:PRINT "THE CORRECT ANSWER IS ";T$(Y);"."
360 GOTO 260
400 DATA "PERVENIO","I COME THROUGH","PES","FOOT","PERO","I SEEK","PILA","BALL"
410 DATA "PICTURA","PICTURE","PLACO","I CALM","PLANUS","LEVEL","PLICO","I FOLD"
420 DATA "PLEBS","COMMON PEOPLE","POENA","PENALTY","POETA","POET","POMPA"
430 DATA "PARADE","PONO","I PUT","PONS","BRIDGE","PONTIFEX","PRIEST","POPULUS"
435 DATA "PEOPLE","PORTA","GATE","PORTO","I CARRY","PORTUS","HARBOR"
440 DATA "POSSUM","I AM ABLE","POST","BEHIND","POSTEA","AFTERWARDS","POSTQUAM"
445 DATA "AFTER","POTESTAS","POWER","PRAECEPS","STEEP","PRAEDA","LOOT"
450 DATA "PRAEFICIO","I PUT IN CHARGE OF","PRAEMITTO","I SEND AHEAD"
455 DATA "PRAEMIUM","REWARD","PRAESIDIUM","GUARD","PRAESUM","I AM IN CHARGE OF"
460 DATA "PRAETEXTUS","BORDERED","PREMO","I PRESS HARD","PRETIUM","PRICE"
465 DATA "PRIMO","AT FIRST","PRINCEPS","LEADER","PROBO","I APPROVE","PROCEDO"
470 DATA "I ADVANCE","PRODUCO","I LEAD OUT","PROELIUM","BATTLE","PROHIBEO"
475 DATA "I PREVENT","PROPERO","I HASTEN","PROPONO","I PUT FORTH","PROPRIUS"
480 DATA "ONE'S OWN","PROVIDEO","I FORESEE","PROXIMUS","NEAREST","PUBLICUS"
485 DATA "PUBLIC","PUELLA","GIRL","PUER","BOY","PUGNA","BATTLE","PUGNO","FIGHT"
490 DATA "PULCHER","BEAUTIFUL","PUTO","I THINK","QUAM","THAN","QUARTUS","FOURTH"
495 DATA "QUATTUOR","FOUR","QUINDECIM","FIFTEEN","QUINQUE","FIVE","QUINTUS"
500 DATA "FIFTH","QUOD","BECAUSE","RAEDA","CARRIAGE","RAPIO","I CARRY OFF"
505 DATA "RATIO","REASON","RECIPIO","I TAKE BACK","REDDO","I GIVE BACK"
510 DATA "REDIGO","I DRIVE BACK","REDUCO","I LEAD BACK","REGINA","QUEEN"
515 DATA "REGIO","REGION","REGNUM","KINGDOM","REGO","I RULE","RELINQUO"
520 DATA "I LEAVE BEHIND","RELIQUUS","REMAINING","REMANEO","I REMAIN"
525 DATA "REMITTO","I RELAX","REMOVEO","I REMOVE","REPELLO","I DRIVE BACK"
530 DATA "RES","THING","RESPONDEO","I ANSWER","RESTO","I REMAIN","RETINEO"
535 DATA "I HOLD BACK","REVERTO","I RETURN","REX","KING","RIDEO","I LAUGH"
540 DATA "ROGO","I ASK","RUINA","RUIN","SACCUS","SACK","SACER","SACRED"
545 DATA "SAEPE","OFTEN","SALUS","HEALTH","SAPIENTIA","WISDOM","SATIS"
550 DATA "ENOUGH","SAXUM","ROCK","SCIO","I KNOW","SCRIBO","I WRITE","SED","BUT"
555 DATA "SECUNDUS","SECOND","SEDEO","I SIT","SEMPER","ALWAYS","SENTENTIA"
560 DATA "FEELING","SENTIO","I FEEL","SEPTEM","SEVEN","SEPULCHRUM","TOMB"
565 DATA "SERMO","I TALK","SERVO","I SAVE","SERVUS","SLAVE","SEX","SIX"
570 DATA "SI","IF","SIGNUM","SIGN","SILVA","FOREST","SIMILIS","LIKE","SINE"
575 DATA "WITHOUT","SINGULI","ONE AT A TIME","SINISTER","LEFT","SOL","SUN"
580 DATA "SOCIUS","COMRADE","SOLUS","ALONE","SOLVO","I LOOSEN","SOMNUS","SLEEP"
585 DATA "SOROR","SISTER","SORDIDUS","DIRTY","SPATIUM","SPACE","SPECIES"
590 DATA "APPEARANCE","SPECTO","I LOOK AT","SPERO","I HOPE","SPES","HOPE"
595 DATA "SPIRO","I BREATHE","STATUA","STATUE","STATUO","I ESTABLISH","STO"
600 DATA "I STAND","STUDIUM","EAGERNESS","SUBIGO","I SUBDUE","SUM","I AM"
603 DATA "SUBMITTO","I LET DOWN","SUI","OF ONESELF","SUMMUS","HIGHEST"
606 DATA "SUMO","I TAKE","SUPERBIA","PRIDE","SUPERBUS","HAUGHTY","SUPERO"
610 DATA "I OVERCOME","SUPERSUM","I AM LEFT OVER","SUPERUS","ABOVE","TAMEN"
613 DATA "NEVERTHELESS","SUPPLICIUM","PUNISHMENT","SUSCIPIO","I UNDERTAKE"
616 DATA "SUSTINEO","I ENDURE","TANDEM","AT LAST","TANGO","I TOUCH","TARDE"
620 DATA "SLOWLY","TARDUS","LATE","TELUM","WEAPON","TEMPLUM","TEMPLE"
623 DATA "TEMPUS","TIME","TENDO","I STRETCH","TENEO","I HOLD","TERRA","EARTH"
626 DATA "TERMINUS","END","TERREO","I FRIGHTEN","TERTIUS","THIRD","TEXO"
630 DATA "I WEAVE","TIMEO","I AM AFRAID","TIMIDUS","TIMID","TOTUS","WHOLE"
633 DATA "TRADO","I HAND OVER","TRADUCO","I LEAD ACROSS","TRAHO","I DRAG"
636 DATA "TRANO","I SWIM ACROSS","TRANSPORTO","I TRANSPORT","TRES","THREE"
640 DATA "TRIBUO","I GRANT","TRIGINTA","THIRTY","TRIUMPHO","I TRIUMPH"
643 DATA "TUM","THEN","UBI","WHERE","ULLUS","ANY","ULTIMUS","LAST"
646 DATA "ULTERIOR","FARTHER","UNDA","WAVE","URBS","CITY","UNUS","ONE"
650 DATA "UTILIS","USEFUL","UXOR","WIFE","VALEO","I AM STRONG","VALLUM","WALL"
653 DATA "VARIE","VARIOUSLY","VASTO","I LAY WASTE","VENIO","I COME","VENTUS"
656 DATA "WIND","VER","SPRING","VERBERO","I BEAT","VERBUM","WORD","VERUS"
660 DATA "TRUE","VERTO","I TURN","VESTIS","GARMENT","VIA","WAY","VIDEO","I SEE"
663 DATA "VIGILIA","WATCHFULNESS","VIGINTI","TWENTY","VILLA","COUNTRY HOME"
666 DATA "VINCO","I CONQUER","VINUM","WINE","VIR","MAN","VIRGO","VIRGIN"
670 DATA "VIRTUS","COURAGE","VIS","FORCE","VITA","LIFE","VIVO","I LIVE"
673 DATA "VIVUS","ALIVE","VIX","SCARCELY","VOCO","I CALL","VOX","VOICE"
676 DATA "VULNUS","WOUND","VULNERO","I WOUND"
710 DATA "PERMUTATIO","EXCHANGE","PERPETUUS","CONSTANT","PERTINEO","I PERTAIN TO"
720 DATA "PERICULUM","DANGER","PERMITTO","I ALLOW","PERMOVEO","I MOVE"
730 DATA "PECUNIA","MONEY","PELLO","I DRIVE","PERFICIO","I FINISH"
740 DATA "PARO","I GET READY","PATRIA","NATIVE LAND","PERVENIO","I COME THROUGH"
750 DATA "OSTENDO","I SHOW","OTIUM","LEISURE","PARATUS","PREPARED","PARS","PART"
760 DATA "OPUS","WORK","ORATIO","SPEECH","ORDO","ORDER","ORNAMENTUM","JEWEL"
770 DATA "OMNIS","ALL","OPPIDUM","TOWN","OPPRIMO","I OVERCOME","PAREO","I OBEY"
780 DATA "OCCUPO","I SEIZE","OCULUS","EYE","OFFICIUM","DUTY","PAR","EQUAL"
790 DATA "NUNQUAM","NEVER","OBTINEO","I HOLD","OCCIDO","I KILL","OCTO","EIGHT"
800 DATA "NUMERUS","NUMBER","NUNTIO","I REPORT","NOX","NIGHT","OLIM","ONCE"
810 DATA "NOTUS","KNOWN","NOVEM","NINE","NOVUS","NEW","NUNTIUS","MESSENGER"
820 DATA "NOBILIS","NOBLE","NOCEO","I HARM","NOSCO","I LEARN","NULLUS","NONE"
830 DATA "NEGOTIUM","BUSINESS","NEMO","NO ONE","NIHIL","NOTHING","NOMEN","NAME"
840 DATA "NAUTA","SAILOR","NAVIGO","I SAIL","NEGLEGENTIA","NEGLIGENCE"
850 DATA "MUNUS","DUTY","MUTO","I CHANGE","NATURA","NATURE","NAVIS","SHIP"
860 DATA "MOVEO","I MOVE","MULIER","WOMAN","MULTUS","MUCH","MUNIOR","I FORTIFY"
870 DATA "MONSTRO","I POINT OUT","MORS","DEATH","MOS","CUSTOM","MOX","SOON"
880 DATA "MILES","SOLDIER","MILLE","THOUSAND","MISER","UNHAPPY","MITTO"
890 DATA "I SEND","MODUS","MANNER","MONEO","I REMIND","MONS","MOUNTAIN"
900 DATA "MENSIS","MONTH","MEREO","I DESERVE","META","GOAL","MIGRO","I DEPART"
910 DATA "MEDIUS","MIDDLE","MEL","HONEY","MEMORIA","MEMORY","MENSA","TABLE"
920 DATA "MATRIMONIUM","MARRIAGE","MATURO","I HASTEN","MEDICUS","DOCTOR"
930 DATA "LIBERTAS","FREEDOM","LIGO","I BIND","LINGUA","TONGUE","LITTERA"
940 DATA "LETTER","LOCUS","PLACE","LONGUS","LONG","LUDO","I PLAY","LUDUS"
950 DATA "GAME","LUX","LIGHT","MAGISTER","TEACHER","MAGNUS","LARGE","MALUS"
960 DATA "BAD","MANDO","I ENTRUST","MANEO","I REMAIN","MANUS","HAND","MARE"
970 DATA "SEA","MARITUS","HUSBAND","MATER","MOTHER","MATERIA","MATTER"
980 DATA "LEX","LAW","LIBER","BOOK","LIBERI","CHILDREN","LIBERO","I FREE"
990 DATA "LAVO","I WASH","LEGATUS","ENVOY","LEGO","I GATHER","LEVIS","LIGHT"
1000 DATA "ABSUM","I AM AWAY","ACCEDO","I APPROACH","ACCIDO","I BEFALL","ACER"
1010 DATA "SHARP","ACCUSO","I BLAME","ADDUCO","I LEAD TO","ADSUM","I AM NEAR"
1020 DATA "AEQUE","JUSTLY","AESTAS","SUMMER","AETAS","AGE","AFFICIO","I AFFECT"
1030 DATA "AGER","FIELD","AGO","I DRIVE","AGRICOLA","FARMER","ALA","WING"
1040 DATA "ALBUS","WHITE","ALIENUS","ANOTHER'S","ALTUS","HIGH","AMICITIA"
1050 DATA "FRIENDSHIP","AMICUS","FRIEND","AMITTO","I LET GO","AMO","I LOVE"
1060 DATA "AMOR","LOVE","ANIMUS","MIND","ANNUS","YEAR","ANTECEDO","I GO BEFORE"
1070 DATA "ANTIQUUS","ANCIENT","APPELLO","I CALL","APTUS","FIT","AQUA","WATER"
1080 DATA "ARCUS","ARCH","ARGENTUM","SILVER","ARMA","ARMS","ASCENDO","I CLIMB"
1090 DATA "ATTINGO","I TOUCH","AUCTOR","MAKER","AUCTORITAS","AUTHORITY"
1100 DATA "AUDACIA","BOLDNESS","AUDIO","I HEAR","AUGEO","I INCREASE","AURUM"
1110 DATA "GOLD","AURORA","DAWN","AUTEM","HOWEVER","AVUS","GRANDFATHER"
1120 DATA "AXIS","AXLE","AUXILIUM","REINFORCEMENTS","AVERTO","I TURN FROM"
1130 DATA "BELLUM","WAR","BENE","WELL","BONUS","GOOD","BENEFICIUM","KINDNESS"
1140 DATA "CADO","I FALL","CAELUM","SKY","CANIS","DOG","CANO","I SING","CAPIO"
1150 DATA "I TAKE","CAPTIVUS","PRISONER","CAPUT","HEAD","CARMEN","SONG","CARRUS"
1160 DATA "WAGON","CARUS","DEAR","CASTRA","CAMP","CASUS","ACCIDENT","CAUSA"
1170 DATA "CAUSE","CEDO","I MOVE","CELER","SWIFT","CELERITAS","SWIFTNESS"
1180 DATA "CENA","DINNER","CENTUM","HUNDRED","CERA","WAX","CERNO","I SEPARATE"
1190 DATA "CERTE","CERTAINLY","CERTUS","FIXED","CIBUS","FOOD","CIRCUS","CIRCLE"
1200 DATA "CIVIS","CITIZEN","CIVITAS","CITIZENSHIP","CLAMO","I SHOUT"
1210 DATA "CLARUS","FAMOUS","CLAMOR","SHOUT","CLAUDO","I CLOSE","COGNOMEN"
1220 DATA "SURNAME","COGNOSCO","I LEARN","COGO","I DRIVE TOGETHER","COLO"
1230 DATA "I TILL","COLONUS","SETTLER","COMMITTO","I JOIN TOGETHER","COMMODUS"
1240 DATA "SUITABLE","COMMOVEO","I DISTURB","COMMUNIS","COMMON","CONCORDIA"
1250 DATA "HARMONY","CONDICIO","CONDITION","CONFICIO","I COMPLETE","CONFIRMO"
1260 DATA "I MAKE FIRM","CONSERVO","I SAVE","CONSILIUM","PLAN","CONSISTO"
1270 DATA "I STAND STILL","CONSPICIO","I CATCH SIGHT OF","CONSULO","I CONSULT"
1280 DATA "CONTENDO","I STRUGGLE","CONTINEO","I HOLD TOGETHER","CONVENIO"
1290 DATA "I COME TOGETHER","CONVOCO","I CALL TOGETHER","COPIA","SUPPLY"
1300 DATA "COQUO","I COOK","COR","HEART","CORONA","CROWN","CORPUS","BODY"
1310 DATA "COQUUS","COOK","CREDO","I BELIEVE","CUPIDITAS","DESIRE","CUPIO"
1320 DATA "I DESIRE","CUR","WHY","CURA","CARE","CURRO","I RUN","CURRUS"
1330 DATA "CHARIOT","DEA","GODDESS","DEBEO","I OWE","DECEM","TEN","DEFENDO"
1340 DATA "I DEFEND","DELIGO","I SELECT","DEMONSTRO","I SHOW","DEPONO"
1350 DATA "I PUT ASIDE","DESCENDO","I DESCEND","DESERO","I DESERT","DESILIO"
1360 DATA "I JUMP DOWN","DESPICIO","I LOOK DOWN ON","DEUS","GOD","DEVORO"
1370 DATA "I SWALLOW","DEXTER","RIGHT","DICO","I SAY","DICTUM","WORD"
1380 DATA "DIFFICILIS","DIFFICULT","DIGITUS","FINGER","DILIGENTIA"
1390 DATA "DILIGENCE","DIMITTO","I LET GO","DISCEDO","I DEPART","DISCIPULUS"
1400 DATA "LEARNER","DISSIMILIS","UNLIKE","DIVIDO","I DIVIDE","DO","I GIVE"
1410 DATA "DOCEO","I TEACH","DOMINUS","MASTER","DOMUS","HOUSE","DONO","I GIVE"
1420 DATA "DONUM","GIFT","DUBITO","I HESITATE","DUCO","I LEAD","DULCIS","SWEET"
1430 DATA "DUO","TWO","DUODECIM","TWELVE","DURUS","HARD","DUX","LEADER"
1440 DATA "EDO","I EAT","EDUCO","I LEAD OUT","EFFICIO","I BRING ABOUT","EGO"
1450 DATA "I","EGREGIUS","DISTINGUISHED","EICIO","I THROW OUT","EM","TAKE THAT"
1460 DATA "EMO","I BUY","EPISTULA","LETTER","EQUUS","HORSE","ETIAM","ALSO"
1470 DATA "ERUMPO","I BURST FORTH","EVADO","I ESCAPE","EVOCO","I SUMMON"
1480 DATA "EXCEDO","I DEPART","EXEMPLUM","EXAMPLE","EXERCEO","I KEEP BUSY"
1490 DATA "EXERCITUS","ARMY","EXISTIMO","I THINK","EXPEDIO","I SET FREE"
1500 DATA "EXPELLO","I DRIVE OUT","EXPLICO","I UNFOLD","EXPLORO","I INVESTIGATE"
1510 DATA "EXPUGNO","I CAPTURE BY ASSAULT","EXSPECTO","I LOOK OUT FOR"
1520 DATA "EXSTINGUO","I EXTINGUISH","EXTREMUS","FARTHEST","FABULA","STORY"
1530 DATA "FACILE","EASILY","FACILIS","EASY","FACIO","I DO","FACTUM","DEED"
1540 DATA "FALLO","I DECEIVE","FAMA","REPORT","FAMILIA","FAMILY","FATUM","FATE"
1550 DATA "FERRUM","IRON","FILIA","DAUGHTER","FILIUS","SON","FINIS","END"
1560 DATA "FIRMUS","STRONG","FINITIMUS","NEIGHBOR","FLEO","I WEEP","FLUMEN"
1570 DATA "RIVER","FLUO","I FLOW","FOCUS","HEARTH","FORMA","SHAPE","FORTASSE"
1580 DATA "PERHAPS","FORTIS","STRONG","FORTUNA","FORTUNE","FORUM","MARKET PLACE"
1590 DATA "FRANGO","I BREAK","FRATER","BROTHER","FRONS","FOREHEAD","FRUMENTUM"
1600 DATA "GRAIN","FUGA","FLIGHT","FULMEN","LIGHTNING","GENS","PEOPLE"
1610 DATA "GERO","I CARRY ON","GENUS","BIRTH","GLADIUS","SWORD","GLORIA"
1620 DATA "GLORY","GRATE","GRATEFULLY","GRATIA","GRATITUDE","GRATUS"
1630 DATA "PLEASING","GRAVIS","HEAVY","HABEO","I HAVE","HABITO","I LIVE"
1640 DATA "HAEREO","I STICK","HERBA","GRASS","HIEMS","WINTER","HOMO","MAN"
1650 DATA "HONESTAS","HONOR","HONOR","HONOR","HORA","HOUR","HOSPITA","GUEST"
1660 DATA "HOSTIS","ENEMY","HUMILIS","LOW","IACIO","I THROW","IAM","ALREADY"
1670 DATA "IBI","THERE","IDEM","SAME","IGNIS","FIRE","IMPEDIMENTUM"
1680 DATA "HINDRANCE","IMPEDIO","I HINDER","IMPERIUM","POWER","IMPERO"
1690 DATA "I COMMAND","IMPETUS","ATTACK","INCERTUS","UNCERTAIN","INCIPIO"
1700 DATA "I TAKE TO","INCITO","I URGE ON","INCOLO","I INHABIT","INFERIOR"
1710 DATA "LOWER","INIMICUS","ENEMY","INIURIA","WRONG","INSTO","I THREATEN"
1720 DATA "INSTRUO","I ARRANGE","INSULA","ISLAND","INTEGER","UNTOUCHED"
1730 DATA "INTELLEGO","I UNDERSTAND","INTERCIPIO","I INTERCEPT","INTERCLUDO"
1740 DATA "I CUT OFF","INTERFICIO","I KILL","INTERIM","MEANWHILE","INTERMITTO"
1750 DATA "I LET GO","INVENIO","I COME UPON","IO","HURRAH","IRA","ANGER"
1760 DATA "ITER","JOURNEY","ITERUM","AGAIN","IUBEO","I ORDER","IUDICIO"
1770 DATA "I JUDGE","IUNGO","I JOIN TO","IUS","RIGHT","IUSTUS","JUST"
1780 DATA "LABOR","WORK","LABORO","I WORK","LACRIMA","TEAR","LASSITUDO"
1790 DATA "WEARINESS","LATE","WIDELY","LATUS","WIDE","LAUDO","I PRAISE"
1800 FOR X=1 TO 595
1810 READ T$(X),H$(X)
1820 NEXT X
1830 GOTO 260
1900 FOR X=1 TO 595
1910 READ H$(X),T$(X)
1920 NEXT X
1930 GOTO 260
2000 PRINT:PRINT "THIS PROGRAM DRILLS YOU IN LATIN VOCABULARY, EITHER IN"
2010  PRINT "TRANSLATING INTO LATIN OR IN TRANSLATING BACK INTO ENGLISH."
2020 PRINT:PRINT "THE COMPUTER PICKS THE WORD AT RANDOM OUT OF THE VOCABULARY"
2030 PRINT "BUILT INTO IT.  IF YOU MISS, YOU GET TWO MORE GUESSES."
2042 PRINT:PRINT "IF YOU HAVE NO IDEA WHAT THE WORD IS, AND WANT TO MINIMIZE ITS"
2044 PRINT "EFFECT ON YOUR SCORE, TYPE 'I GIVE UP' AS YOUR ANSWER."
2050 PRINT:PRINT "TO END THE SESSION, TYPE 'QUIT' WHEN THE COMPUTER ASKS FOR"
2060 PRINT "YOUR TRANSLATION.  IT WILL THEN TELL YOU HOW MANY YOU GOT"
2070 PRINT "RIGHT AND THE PERCENTAGE RIGHT."
2080 PRINT:PRINT "GOOD LUCK!"
2090 RETURN
3000 PRINT:PRINT "IN THIS SESSION, YOU MADE";T;"GUESSES, AND GOT";C;"RIGHT ANSWERS."
3010 P=C/T*100
3020 PRINT "YOUR PERCENTAGE CORRECT WAS";P
3030 IF P>90 THEN PRINT "CONGRATULATIONS!  YOU'RE READY TO RUN FOR THE ROMAN SENATE.":GOTO 3099
3040 IF P>80 THEN PRINT "GOOD WORK -- KEEP STUDYING.":GOTO 3099
3050 IF P>70 THEN PRINT "YOU'RE DOING OK BUT NEED TO IMPROVE.":GOTO 3099
3060 IF P>60 THEN PRINT "YOU DIDN'T DO SO HOT.  STUDY A LOT MORE.":GOTO 3099
3070 IF P>30 THEN PRINT "DON'T STRIKE UP ANY CONVERSATIONS WITH CAESAR.":GOTO 3099
3080 PRINT "MAYBE YOU'D BETTER TRY STUDYING ANOTHER LANGUAGE?"
3099 PRINT:PRINT:SYSTEM
ONVERSATIONS WITH CAESAR.":GOTO 3099
3080 PRINT "MAYBE YOU'D BETTER TRY STUDYING ANOTHER LANGUA