10	REM                                      

	* CAT-REFBAS
R)$<O
$on J. Ewins
R) +dIember 1, 198>%	$%	  Tis progHmI=kes th 

T.CAT file

	* created bETCAT3
IIC"$* d provides prieed

	* crBs-reference by:
R)1$NDisk #$C=KB
I	1IiP STNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN1I%	Nilename

	                        File extension

	*

	 ThB program is writtenI
 run on n

	* Osborne-1. CPNITPA CM=
AoJ for chr$ etc. L* to locate OsborneS
PNIific code.

	******************************************B
300 1"2.)980
40	DIM;(103%O$ eB0H7SHS$
	2" C"yOR$T-LPRINTCatalogue Cros1.Herene":

	PRINT STRING$(B e	1iII(I.%AT "by)sI
$s
E eNins": P2":

	V" "Portions of omT$ls; 	Tersion (c)
  MicrBoft"
60	PRINT$
	2" "MENU:COLP2" "=====================================================-

:	2" "1. Print by Dik Number">%eV" "2. Print by Fld $Uy
1I=lTAabetical)COLP2" "3. Prin by  lJ 3Gnion":LPRINT4. End (3EOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOLiled th   reu  s toG/M)"
70	PRINT$
	2" "Mo)$:$P$$TScT' disk in d 2I$
X$OLPRINT "and ENTEyo)r%INoice :";:

	SELECTION$ = INPUT4
$COLIO
pEOT= 7< "1" OR SELECTION$ > 
T

	CNTHENIR )50
8> B 2rI$2
pECT0 $CORN SEON%T C*A END
9E0  p GOPL 















































































1
97)0%6r=0	GOTO 50
X=	RR D IA & D FILE SUBROUTIN-----


9K%eV": REC%=0: OP  TI",1TB:M	CITTX6
%0 "TIT(1) THEN 160                                                  9(
OR"E33 T
                                                                                "dTAN%)
HSTN%L2Oo$TRX1:I % U000000000000000000000000000000000000000000000000000000009N$%=%L$r"NF1T



















































STNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN$E) ERRi0ANDLIN::::::::::::::::::::


% I.%ATFILE NONOUND ERRG"CC%eVneV" "Remount 'NST.CAT' in drive 5eo
T

9Ri%	2"O 203- NEXT I%: GOTO 50
200	V" "DISK I/O ERNEOXA9SUc % 6
S
09NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN$ED) PRINTER OPTION0t
ER3%"$EM%B>G =H9C
	2": PR nTSend to T1 7 ter ";: INPUTFS$
24	6 2FS$="Y" OR ANSNE<nCA 245 %
E

	GOTO 250 =EU9hPUT "Serial or Parallel G=C: TANS$
 R%0 ORE	PFE	T ORFS$="s" T A IOBYTE=12


	GO OKG =E$ 	IF ANSNRM  2TOREH"c" T A IOBYTE=12


	GO OKG =ETUc % =BP HS%0 ORE	PFRr  AiTNSNR  C*A IOBNE=F .I(=:% EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEA0K2.R )22222222222222222222222222222222222222222222222222222222222222222222222222222222222222222A
K%eV" STR1:B0H7e	1i)$04$0E

YTE: FURN

28NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN$ED) AR yO"$TISK NUMBER ------------B
290	GOSUB 120: GOSU =H $u1
9S1 2TOV"O REC%:LIF LEFT$PTT$(I%), <>"+" THEN 320
310	EXT$(O%O	&F$(CAT$(I%),3)>Se%=J%+1: NEXT I%$N=Uc	GL" 06'30	LONG  NOR I%=1 TO J%-1:

	PRINT NIS"
 T;EXT$(I%):
C
	CneVCOLLI%=L$T/.HEITOR K%=TO REC%:

	IF RIGHTAdT$9Hi(T$
"$(I%) TH O0o
39	EuINSTR(CAT$(K% IR%$COLB(2OAR(C y1SO ,"."II(	2GOS(0P$N	
T$=LE NdT$(K%),A%- :

	PU21$(A$,B%- :

	xIN$(X	DR
P0iII(

$
$+S%AG$(8-LEN(B$),32NRP:

6 2Fr *2 wn("
39	6 TL2RraE410
380	ITLor0N" A PRINT $(
( "";: GO %0
390	IF C%
 "HEN P2" TAoA
% T";: GO %0
4006 TLT
K)	OneNT: LI%=L$TR'10	PRINTId2 eEGO"=90"PrSO.E0	P2": PRINT "	2$(50,34):	VBCT		.E%6
%0 $S1RS
=T"HEN P2" CHR4		 : LI%=1
450	N)8RIGO"	I.%AT CHR$(12):cTfER	N X eV": 	OS.4	I.%ATPress < R> for menu...... ";
 OA$=INKEY8RN A$="" THEN 48.S9NNFURN

1H2
TNi4+nOINR yO"1OpENAME (ALPHABETICAn$COB
510	G2J)K6X1O=t)=HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH-=9(
1u1: Ai1u1%"N%L-

	C%=Po07S
530	IF C%=1 TH 1 01L19N C7AF"HEN P2" TAMNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN"": G )55555555555555555555555555555555555555555555555f
%0 "LoY N"HEN PRINTNB(41)"";: GOTO 570
560	IF C

=a  eV": LI%	I%+1
570	A%=INSTRPTT$(I%),I")>ST$	EF
NdT$(I%),A%-1II( gT$+STRINyT LEN(A$)+$TRP"CCOLB0IID$(C y%	%O IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIHiII(A=RI=T$(CAT$(O HiP1;O	
 oT6"$(B$, ="," TH $H"    "
590	IF LI
06rEN PR 8$HR$00i)o%																																																																																									0K9ChT eELPN E
"C$;
N9SF)8RIG 0O0POTO 460

630	RE :::::::::::::::::::::::::::::::::O"8<4"PrT2R2nR%U4 ::::::::::

640	GOSUB 120: GOSU =H:650	J%=1: Ai1u1%"N%L-

	CAT$=CA
	-

	A%=INSTR(CA
%CO 1:
NdT$=MID$(CA
%,3)
69RiT89u1 TO J%>S1TX
R	IiTT$ THEN 690
670	NEXT K%
680	ET$(J =CAT$: JG:IAP 01	NEXT I%
E9SUc	GL" 06E)9SI%=COLFi1u1 TO J%-1:

	A89u1 TO REC%:

	A%=INSTAdT$9T.")+1:

	CAT$=MI$(CAT$9N%,3P 
O0RN CAT$<>EXT$(O =EN9KG =9NL2GOS(0): 
0	IF u1 THEN 77777777777777777777777777777777777777777777777777777777777777777777777777777777777777777
UKS TLoENF"HEN PRINT TAB(21)"";: GOTO 780 
0	IF CME N"HENI%AhB E"";:IR )780

KS1T C%>50 THEN PRINT:	VBCTR'$ 8	EuI2T0AdT$(K%),"."II( g	E yT"$(Ii 3O$):

	A$=A$+STRINyT LEN(A$)+$TRP"CCOLB0IID$(C y1SO ,A%+1,3):LC$=Se0 yTdT$(K%),3) 
0	IF  0B5I:%( ="," THEN BNn("" 	
1T LI%>F"HEN PRINT3I BE9%$8
u1
9S$
	2" ATpPN
";CTS
820	NET K%
 xS$
	2": PRINTo%	2B%		5 FEXT I%
 
	GOTO 460B
850	REM ( SR%A"ER3%AE FOR EXT$ --------

860	N
s%=O$r'T (%
WITCH%(. O 2
FUMI0NUMB%-.S9RiT89u1 TNUMB%
9S%0Pr 1SOI0EXT$9CTR
  C*A foA		 (U*"$(IiP 		0STPr BR	Ii*e i
R	IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII
930	EXT$(IAR0TEMP$ 	0	S.xu1
950	N)n0	S
96	6 OstFCI01 THEN 87X4	ANFURN

 	0	REM ------ NENrT%5cNG -------------------

 	0	IF NiFU C*A RESUME 180
20IS1T ERR = 57 THEN REyO"OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO9T		I.%ATERROR #";E5M(A2S
