5 OPEN"R",#1,"SFARESP.0"
10 FIELD#1,128 AS R$
20 FOR X=1 TO 102:READ RE$:LSET R$=RE$:PUT#1,X:NEXT:CLOSE#1:END
100 DATA Cannot go in that direction.,I do not understand you.,OK,I do not see it here.,You are not carrying it.,Nothing happens.,You are already carrying it.,In a blaze of glory - you find yourself in a land far away.,It's too heavy for you to carry.
110 DATA OUCH! - every bone in your foot just broke.,YECHH! your hands just turned into a bloody mess.,You don't have any matches.,You cannot light an empty lamp.,You have no keys.
120 DATA There is insufficient light to see by.,You had better hurry. Time is running out.,Your lamp is getting dim.,The mouse is frightened by you.,The only edible thing here is you!,The mouse was used for carcinogen testing - the snake is dead.
130 DATA The snake severs your hand. You have been poisoned.,The ring glows brightly. A lightning bolt strikes the wizard.,The God is incensed by your activity. With a blink of His eye you fall to the ground - dead.,An emerald eye falls to the ground.
140 DATA A platinum chain lies before you.,A golden apple hangs by an apple tree.,You cannot cross the river.,Holy Moses - The river divided in two!. A dry path leads to the other side.,A loud noise surrounds you as the river closes again.
150 DATA You did not jump far enough and fell into the river.,A school a phiranas devours you.,Fish from the Amazon.,Frodo lives.,Merlin was here.,A crystal bridge now spans the chasm.,The bridge has disappeared just as suddenly.
160 DATA The Great ALAMAZAR wishes you well. You will encounter many trials and so He sends you a gift.
170 DATA It came to pass on the 23rd day of the 37th year that the Earth opened for the glory of the people who had laboured.
180 DATA The chest is empty.,Whew! that's strong stuff.,Yuck! The mouse was used for toxic testing - you are dead.,The abyss is too wide to cross.,You fell to your death in the chasm.,A small axe flies in through the window and strikes you dead.
190 DATA The wizard raises one hand - you become too hot. Above you is a stone idol - you are offered in sacrifice.
200 DATA A wall of fire encircles you - you pass out. When you wake up you find that...,A small wall of fire just surrounds you. You regain conciousness to find that...
210 DATA That jump would have won a gold medal except you landed on your head in some rocks.,You have now been killed 3 times - the game is therefore suspended.
220 DATA You obviously have no idea what is happening in this game.,You are obviously a rank novice in this game.,You may now consider yourself of intermediate skill.,You are now an experiencd adventurer.
230 DATA All honour to thee - Grand Master Adventurer!,A loud voice from behind says `TIME GROWS SHORT - MORTAL - BEFORE WE FEAST AGAIN'.,YECHH! What lousy tasting water.,There is no water within reach.
240 DATA You cannot enter anything from here.,You cannot leave from here.,You have no container to put it in.,The snake blocks your way.,Your container is full.,You do not have a lamp.,The wizard blocks your way.
250 DATA Incompetent fool - you forgot to close the river and the countryside has flooded.,The mouse runs away.,Disgression prevents transgression.
260 DATA It is already open.,It is already closed.,A giant ogre grabs you and throws you into a pit.,There is no sign of any oil here.,A panel slides open revealing a passage to the North.
270 DATA A sudden wind from behind scatters the spices to the 4 corners of the Earth.
280 DATA The Heavens part as the Gods prepare for their next meal - you! Almazar cannot protect you. May you rest in Peace!
290 DATA The delicate figurine breaks on hitting the ground.,A string of pearls is lying in the drawer.,Yuo are not carrying a bottle.,There is nothing to fill it with.
300 DATA A trapdoor opens beneath you. The fall knocks you out. When you awaken you find that...,The cheese was stale but you managed to consume the whole box.
310 DATA The Gnome is too fast for you.,The lamp is already lit.,You have too much to carry.,The bottle breaks on impact.,The panel closes and seals the passage.
320 DATA It's locked.,You have managed to unlock the vault.,The vault is locked.,That combination is wrong.,Your bottle contains nothing.,You have to open the vault to get inside it.,Your lamp is already off.,The wizard wont let you.
330 DATA Hay is soft.,The figurine is extremly delicate.,Snakes love rodents.,Only a power stronger than his own can defeat the Wizard.,Complete your task and return here and...,The hungry are always restless.
340 DATA Gods are unhappy creatures with many needs.,The river flows towards the Red Sea.,No help can be had.
