10 PRINT CHR$(11) : REM SCREEN CLEAR051DIM A(E),C"P3AP1PRINT "THISROGRAM ISPSINED TO SEECT THE"
40RINT "PRO0O:ALUESF RESISTAN 0E>ER530R7"
50 PRINTCITANCE FOR 5 PROPE 5ERATION OF THER"A0 PRINT567 HE 07ICI
70 PRINT
80 PRINTEPR T T PSIRED0PQUENCY OFPERATIO(F90 INPUT 3A 00 CNT CN.2 E
110RINT
120 S=1
130 F1;F   1RA 40 READ A(I)
150 NEXT I
00RINT
17ER. "TH
OLLOWING VALUEE
10PSISTLERA 80 PRIOTAND CAPACITLOETERMINE TH
RE-"
19ER. "QUEN^
";F;"HZ"05O E2
 =A( 
OR J=2 O5
2P10PT2
D 13
2E1R(A)=A(I)10 ^ J
240 A=A+1
250 NEXT I
H00 NEXT J
27
OR A=1 T66
30 C==FC5*I=A
1IF (10^(-9) THEN90
EO RR H=1 O3AF
I2R  HHEH3A2 81ETM 1I-N 340

E1IF D<10 THOR50
I -T H
350 FOR=1 TO 6
3E 81
7*A(I)>D THOR8F370 IF D<1.TDA(I)NEN 4100HR0 NEXT I
39-T A
406OT500
 0 PRI2
420 PRINT
430 PRINTSET";ST:"
440 PRINT 4 =";R(A)TOHMS"
45ER. "C1 =";1E+06*CTUF"
460 S=S+1
470 PRI2
486OT390T I
1DATA 5.0,1S,1.0,2.2,3.3,4.7,I)O- .8CN"E.6,6.2,"2
1O 0T*
8R0
EMI(3=R=SR)NN<PPC*N=2HR08RE
T05E3DV)
$R,04N3= =03" 2O1.I OA8RTEN<IT:)
^R80) 4S5TH)5 0;ORTR