10 DEPTH=0
20 GOSUB 1000
30 PRINT "Maximum depth reached:", DEPTH
40 END
1000 DEPTH=DEPTH+1
1001 PRINT "Depth:", DEPTH
1002 GOSUB 1010
1003 RETURN
1010 DEPTH=DEPTH+1
1011 PRINT "Depth:", DEPTH
1012 GOSUB 1020
1013 RETURN
1020 DEPTH=DEPTH+1
1021 PRINT "Depth:", DEPTH
1022 GOSUB 1030
1023 RETURN
1030 DEPTH=DEPTH+1
1031 PRINT "Depth:", DEPTH
1032 GOSUB 1040
1033 RETURN
1040 DEPTH=DEPTH+1
1041 PRINT "Depth:", DEPTH
1042 GOSUB 1050
1043 RETURN
1050 DEPTH=DEPTH+1
1051 PRINT "Depth:", DEPTH
1052 GOSUB 1060
1053 RETURN
1060 DEPTH=DEPTH+1
1061 PRINT "Depth:", DEPTH
1062 GOSUB 1070
1063 RETURN
1070 DEPTH=DEPTH+1
1071 PRINT "Depth:", DEPTH
1072 GOSUB 1080
1073 RETURN
1080 DEPTH=DEPTH+1
1081 PRINT "Depth:", DEPTH
1082 GOSUB 1090
1083 RETURN
1090 DEPTH=DEPTH+1
1091 PRINT "Depth:", DEPTH
1092 GOSUB 1100
1093 RETURN
1100 DEPTH=DEPTH+1
1101 PRINT "Depth:", DEPTH
1102 GOSUB 1110
1103 RETURN
1110 DEPTH=DEPTH+1
1111 PRINT "Depth:", DEPTH
1112 GOSUB 1120
1113 RETURN
1120 DEPTH=DEPTH+1
1121 PRINT "Depth:", DEPTH
1122 GOSUB 1130
1123 RETURN
1130 DEPTH=DEPTH+1
1131 PRINT "Depth:", DEPTH
1132 GOSUB 1140
1133 RETURN
1140 DEPTH=DEPTH+1
1141 PRINT "Depth:", DEPTH
1142 GOSUB 1150
1143 RETURN
1150 DEPTH=DEPTH+1
1151 PRINT "Depth:", DEPTH
1152 GOSUB 1160
1153 RETURN
1160 DEPTH=DEPTH+1
1161 PRINT "Depth:", DEPTH
1162 GOSUB 1170
1163 RETURN
1170 DEPTH=DEPTH+1
1171 PRINT "Depth:", DEPTH
1172 GOSUB 1180
1173 RETURN
1180 DEPTH=DEPTH+1
1181 PRINT "Depth:", DEPTH
1182 GOSUB 1190
1183 RETURN
1190 DEPTH=DEPTH+1
1191 PRINT "Depth:", DEPTH
1192 GOSUB 1200
1193 RETURN
1200 DEPTH=DEPTH+1
1201 PRINT "Depth:", DEPTH
1202 GOSUB 1210
1203 RETURN
1210 DEPTH=DEPTH+1
1211 PRINT "Depth:", DEPTH
1212 GOSUB 1220
1213 RETURN
1220 DEPTH=DEPTH+1
1221 PRINT "Depth:", DEPTH
1222 GOSUB 1230
1223 RETURN
1230 DEPTH=DEPTH+1
1231 PRINT "Depth:", DEPTH
1232 GOSUB 1240
1233 RETURN
1240 DEPTH=DEPTH+1
1241 PRINT "Depth:", DEPTH
1242 GOSUB 1250
1243 RETURN
1250 DEPTH=DEPTH+1
1251 PRINT "Depth:", DEPTH
1252 GOSUB 1260
1253 RETURN
1260 DEPTH=DEPTH+1
1261 PRINT "Depth:", DEPTH
1262 GOSUB 1270
1263 RETURN
1270 DEPTH=DEPTH+1
1271 PRINT "Depth:", DEPTH
1272 GOSUB 1280
1273 RETURN
1280 DEPTH=DEPTH+1
1281 PRINT "Depth:", DEPTH
1282 GOSUB 1290
1283 RETURN
1290 DEPTH=DEPTH+1
1291 PRINT "Depth:", DEPTH
1292 GOSUB 1300
1293 RETURN
1300 DEPTH=DEPTH+1
1301 PRINT "Depth:", DEPTH
1302 GOSUB 1310
1303 RETURN
1310 DEPTH=DEPTH+1
1311 PRINT "Depth:", DEPTH
1312 GOSUB 1320
1313 RETURN
1320 DEPTH=DEPTH+1
1321 PRINT "Depth:", DEPTH
1322 GOSUB 1330
1323 RETURN
1330 DEPTH=DEPTH+1
1331 PRINT "Depth:", DEPTH
1332 GOSUB 1340
1333 RETURN
1340 DEPTH=DEPTH+1
1341 PRINT "Depth:", DEPTH
1342 GOSUB 1350
1343 RETURN
1350 DEPTH=DEPTH+1
1351 PRINT "Depth:", DEPTH
1352 GOSUB 1360
1353 RETURN
1360 DEPTH=DEPTH+1
1361 PRINT "Depth:", DEPTH
1362 GOSUB 1370
1363 RETURN
1370 DEPTH=DEPTH+1
1371 PRINT "Depth:", DEPTH
1372 GOSUB 1380
1373 RETURN
1380 DEPTH=DEPTH+1
1381 PRINT "Depth:", DEPTH
1382 GOSUB 1390
1383 RETURN
1390 DEPTH=DEPTH+1
1391 PRINT "Depth:", DEPTH
1392 GOSUB 1400
1393 RETURN
1400 DEPTH=DEPTH+1
1401 PRINT "Depth:", DEPTH
1402 GOSUB 1410
1403 RETURN
1410 DEPTH=DEPTH+1
1411 PRINT "Depth:", DEPTH
1412 GOSUB 1420
1413 RETURN
1420 DEPTH=DEPTH+1
1421 PRINT "Depth:", DEPTH
1422 GOSUB 1430
1423 RETURN
1430 DEPTH=DEPTH+1
1431 PRINT "Depth:", DEPTH
1432 GOSUB 1440
1433 RETURN
1440 DEPTH=DEPTH+1
1441 PRINT "Depth:", DEPTH
1442 GOSUB 1450
1443 RETURN
1450 DEPTH=DEPTH+1
1451 PRINT "Depth:", DEPTH
1452 GOSUB 1460
1453 RETURN
1460 DEPTH=DEPTH+1
1461 PRINT "Depth:", DEPTH
1462 GOSUB 1470
1463 RETURN
1470 DEPTH=DEPTH+1
1471 PRINT "Depth:", DEPTH
1472 GOSUB 1480
1473 RETURN
1480 DEPTH=DEPTH+1
1481 PRINT "Depth:", DEPTH
1482 GOSUB 1490
1483 RETURN
1490 DEPTH=DEPTH+1
1491 PRINT "Depth:", DEPTH
1492 GOSUB 1500
1493 RETURN
1500 DEPTH=DEPTH+1
1501 PRINT "Depth:", DEPTH
1502 GOSUB 1510
1503 RETURN
1510 DEPTH=DEPTH+1
1511 PRINT "Depth:", DEPTH
1512 GOSUB 1520
1513 RETURN
1520 DEPTH=DEPTH+1
1521 PRINT "Depth:", DEPTH
1522 GOSUB 1530
1523 RETURN
1530 DEPTH=DEPTH+1
1531 PRINT "Depth:", DEPTH
1532 GOSUB 1540
1533 RETURN
1540 DEPTH=DEPTH+1
1541 PRINT "Depth:", DEPTH
1542 GOSUB 1550
1543 RETURN
1550 DEPTH=DEPTH+1
1551 PRINT "Depth:", DEPTH
1552 GOSUB 1560
1553 RETURN
1560 DEPTH=DEPTH+1
1561 PRINT "Depth:", DEPTH
1562 GOSUB 1570
1563 RETURN
1570 DEPTH=DEPTH+1
1571 PRINT "Depth:", DEPTH
1572 GOSUB 1580
1573 RETURN
1580 DEPTH=DEPTH+1
1581 PRINT "Depth:", DEPTH
1582 GOSUB 1590
1583 RETURN
1590 DEPTH=DEPTH+1
1591 PRINT "Depth:", DEPTH
1592 GOSUB 1600
1593 RETURN
1600 DEPTH=DEPTH+1
1601 PRINT "Depth:", DEPTH
1602 GOSUB 1610
1603 RETURN
1610 DEPTH=DEPTH+1
1611 PRINT "Depth:", DEPTH
1612 GOSUB 1620
1613 RETURN
1620 DEPTH=DEPTH+1
1621 PRINT "Depth:", DEPTH
1622 GOSUB 1630
1623 RETURN
1630 DEPTH=DEPTH+1
1631 PRINT "Depth:", DEPTH
1632 GOSUB 1640
1633 RETURN
1640 DEPTH=DEPTH+1
1641 PRINT "Depth:", DEPTH
1642 GOSUB 1650
1643 RETURN
1650 DEPTH=DEPTH+1
1651 PRINT "Depth:", DEPTH
1652 GOSUB 1660
1653 RETURN
1660 DEPTH=DEPTH+1
1661 PRINT "Depth:", DEPTH
1662 GOSUB 1670
1663 RETURN
1670 DEPTH=DEPTH+1
1671 PRINT "Depth:", DEPTH
1672 GOSUB 1680
1673 RETURN
1680 DEPTH=DEPTH+1
1681 PRINT "Depth:", DEPTH
1682 GOSUB 1690
1683 RETURN
1690 DEPTH=DEPTH+1
1691 PRINT "Depth:", DEPTH
1692 GOSUB 1700
1693 RETURN
1700 DEPTH=DEPTH+1
1701 PRINT "Depth:", DEPTH
1702 GOSUB 1710
1703 RETURN
1710 DEPTH=DEPTH+1
1711 PRINT "Depth:", DEPTH
1712 GOSUB 1720
1713 RETURN
1720 DEPTH=DEPTH+1
1721 PRINT "Depth:", DEPTH
1722 GOSUB 1730
1723 RETURN
1730 DEPTH=DEPTH+1
1731 PRINT "Depth:", DEPTH
1732 GOSUB 1740
1733 RETURN
1740 DEPTH=DEPTH+1
1741 PRINT "Depth:", DEPTH
1742 GOSUB 1750
1743 RETURN
1750 DEPTH=DEPTH+1
1751 PRINT "Depth:", DEPTH
1752 GOSUB 1760
1753 RETURN
1760 DEPTH=DEPTH+1
1761 PRINT "Depth:", DEPTH
1762 GOSUB 1770
1763 RETURN
1770 DEPTH=DEPTH+1
1771 PRINT "Depth:", DEPTH
1772 GOSUB 1780
1773 RETURN
1780 DEPTH=DEPTH+1
1781 PRINT "Depth:", DEPTH
1782 GOSUB 1790
1783 RETURN
1790 DEPTH=DEPTH+1
1791 PRINT "Depth:", DEPTH
1792 GOSUB 1800
1793 RETURN
1800 DEPTH=DEPTH+1
1801 PRINT "Depth:", DEPTH
1802 GOSUB 1810
1803 RETURN
1810 DEPTH=DEPTH+1
1811 PRINT "Depth:", DEPTH
1812 GOSUB 1820
1813 RETURN
1820 DEPTH=DEPTH+1
1821 PRINT "Depth:", DEPTH
1822 GOSUB 1830
1823 RETURN
1830 DEPTH=DEPTH+1
1831 PRINT "Depth:", DEPTH
1832 GOSUB 1840
1833 RETURN
1840 DEPTH=DEPTH+1
1841 PRINT "Depth:", DEPTH
1842 GOSUB 1850
1843 RETURN
1850 DEPTH=DEPTH+1
1851 PRINT "Depth:", DEPTH
1852 GOSUB 1860
1853 RETURN
1860 DEPTH=DEPTH+1
1861 PRINT "Depth:", DEPTH
1862 GOSUB 1870
1863 RETURN
1870 DEPTH=DEPTH+1
1871 PRINT "Depth:", DEPTH
1872 GOSUB 1880
1873 RETURN
1880 DEPTH=DEPTH+1
1881 PRINT "Depth:", DEPTH
1882 GOSUB 1890
1883 RETURN
1890 DEPTH=DEPTH+1
1891 PRINT "Depth:", DEPTH
1892 GOSUB 1900
1893 RETURN
1900 DEPTH=DEPTH+1
1901 PRINT "Depth:", DEPTH
1902 GOSUB 1910
1903 RETURN
1910 DEPTH=DEPTH+1
1911 PRINT "Depth:", DEPTH
1912 GOSUB 1920
1913 RETURN
1920 DEPTH=DEPTH+1
1921 PRINT "Depth:", DEPTH
1922 GOSUB 1930
1923 RETURN
1930 DEPTH=DEPTH+1
1931 PRINT "Depth:", DEPTH
1932 GOSUB 1940
1933 RETURN
1940 DEPTH=DEPTH+1
1941 PRINT "Depth:", DEPTH
1942 GOSUB 1950
1943 RETURN
1950 DEPTH=DEPTH+1
1951 PRINT "Depth:", DEPTH
1952 GOSUB 1960
1953 RETURN
1960 DEPTH=DEPTH+1
1961 PRINT "Depth:", DEPTH
1962 GOSUB 1970
1963 RETURN
1970 DEPTH=DEPTH+1
1971 PRINT "Depth:", DEPTH
1972 GOSUB 1980
1973 RETURN
1980 DEPTH=DEPTH+1
1981 PRINT "Depth:", DEPTH
1982 GOSUB 1990
1983 RETURN
1990 DEPTH=DEPTH+1
1991 PRINT "Depth:", DEPTH
1992 GOSUB 2000
1993 RETURN
2000 DEPTH=DEPTH+1
2001 PRINT "Depth:", DEPTH
2002 GOSUB 2010
2003 RETURN
2010 DEPTH=DEPTH+1
2011 PRINT "Depth:", DEPTH
2012 GOSUB 2020
2013 RETURN
2020 DEPTH=DEPTH+1
2021 PRINT "Depth:", DEPTH
2022 GOSUB 2030
2023 RETURN
2030 DEPTH=DEPTH+1
2031 PRINT "Depth:", DEPTH
2032 GOSUB 2040
2033 RETURN
2040 DEPTH=DEPTH+1
2041 PRINT "Depth:", DEPTH
2042 GOSUB 2050
2043 RETURN
2050 DEPTH=DEPTH+1
2051 PRINT "Depth:", DEPTH
2052 GOSUB 2060
2053 RETURN
2060 DEPTH=DEPTH+1
2061 PRINT "Depth:", DEPTH
2062 GOSUB 2070
2063 RETURN
2070 DEPTH=DEPTH+1
2071 PRINT "Depth:", DEPTH
2072 GOSUB 2080
2073 RETURN
2080 DEPTH=DEPTH+1
2081 PRINT "Depth:", DEPTH
2082 GOSUB 2090
2083 RETURN
2090 DEPTH=DEPTH+1
2091 PRINT "Depth:", DEPTH
2092 GOSUB 2100
2093 RETURN
2100 DEPTH=DEPTH+1
2101 PRINT "Depth:", DEPTH
2102 GOSUB 2110
2103 RETURN
2110 DEPTH=DEPTH+1
2111 PRINT "Depth:", DEPTH
2112 GOSUB 2120
2113 RETURN
2120 DEPTH=DEPTH+1
2121 PRINT "Depth:", DEPTH
2122 GOSUB 2130
2123 RETURN
2130 DEPTH=DEPTH+1
2131 PRINT "Depth:", DEPTH
2132 GOSUB 2140
2133 RETURN
2140 DEPTH=DEPTH+1
2141 PRINT "Depth:", DEPTH
2142 GOSUB 2150
2143 RETURN
2150 DEPTH=DEPTH+1
2151 PRINT "Depth:", DEPTH
2152 GOSUB 2160
2153 RETURN
2160 DEPTH=DEPTH+1
2161 PRINT "Depth:", DEPTH
2162 GOSUB 2170
2163 RETURN
2170 DEPTH=DEPTH+1
2171 PRINT "Depth:", DEPTH
2172 GOSUB 2180
2173 RETURN
2180 DEPTH=DEPTH+1
2181 PRINT "Depth:", DEPTH
2182 GOSUB 2190
2183 RETURN
2190 DEPTH=DEPTH+1
2191 PRINT "Depth:", DEPTH
2192 GOSUB 2200
2193 RETURN
2200 DEPTH=DEPTH+1
2201 PRINT "Depth:", DEPTH
2202 GOSUB 2210
2203 RETURN
2210 DEPTH=DEPTH+1
2211 PRINT "Depth:", DEPTH
2212 GOSUB 2220
2213 RETURN
2220 DEPTH=DEPTH+1
2221 PRINT "Depth:", DEPTH
2222 GOSUB 2230
2223 RETURN
2230 DEPTH=DEPTH+1
2231 PRINT "Depth:", DEPTH
2232 GOSUB 2240
2233 RETURN
2240 DEPTH=DEPTH+1
2241 PRINT "Depth:", DEPTH
2242 GOSUB 2250
2243 RETURN
2250 DEPTH=DEPTH+1
2251 PRINT "Depth:", DEPTH
2252 GOSUB 2260
2253 RETURN
2260 DEPTH=DEPTH+1
2261 PRINT "Depth:", DEPTH
2262 GOSUB 2270
2263 RETURN
2270 DEPTH=DEPTH+1
2271 PRINT "Depth:", DEPTH
2272 GOSUB 2280
2273 RETURN
2280 DEPTH=DEPTH+1
2281 PRINT "Depth:", DEPTH
2282 GOSUB 2290
2283 RETURN
2290 DEPTH=DEPTH+1
2291 PRINT "Depth:", DEPTH
2292 GOSUB 2300
2293 RETURN
2300 DEPTH=DEPTH+1
2301 PRINT "Depth:", DEPTH
2302 GOSUB 2310
2303 RETURN
2310 DEPTH=DEPTH+1
2311 PRINT "Depth:", DEPTH
2312 GOSUB 2320
2313 RETURN
2320 DEPTH=DEPTH+1
2321 PRINT "Depth:", DEPTH
2322 GOSUB 2330
2323 RETURN
2330 DEPTH=DEPTH+1
2331 PRINT "Depth:", DEPTH
2332 GOSUB 2340
2333 RETURN
2340 DEPTH=DEPTH+1
2341 PRINT "Depth:", DEPTH
2342 GOSUB 2350
2343 RETURN
2350 DEPTH=DEPTH+1
2351 PRINT "Depth:", DEPTH
2352 GOSUB 2360
2353 RETURN
2360 DEPTH=DEPTH+1
2361 PRINT "Depth:", DEPTH
2362 GOSUB 2370
2363 RETURN
2370 DEPTH=DEPTH+1
2371 PRINT "Depth:", DEPTH
2372 GOSUB 2380
2373 RETURN
2380 DEPTH=DEPTH+1
2381 PRINT "Depth:", DEPTH
2382 GOSUB 2390
2383 RETURN
2390 DEPTH=DEPTH+1
2391 PRINT "Depth:", DEPTH
2392 GOSUB 2400
2393 RETURN
2400 DEPTH=DEPTH+1
2401 PRINT "Depth:", DEPTH
2402 GOSUB 2410
2403 RETURN
2410 DEPTH=DEPTH+1
2411 PRINT "Depth:", DEPTH
2412 GOSUB 2420
2413 RETURN
2420 DEPTH=DEPTH+1
2421 PRINT "Depth:", DEPTH
2422 GOSUB 2430
2423 RETURN
2430 DEPTH=DEPTH+1
2431 PRINT "Depth:", DEPTH
2432 GOSUB 2440
2433 RETURN
2440 DEPTH=DEPTH+1
2441 PRINT "Depth:", DEPTH
2442 GOSUB 2450
2443 RETURN
2450 DEPTH=DEPTH+1
2451 PRINT "Depth:", DEPTH
2452 GOSUB 2460
2453 RETURN
2460 DEPTH=DEPTH+1
2461 PRINT "Depth:", DEPTH
2462 GOSUB 2470
2463 RETURN
2470 DEPTH=DEPTH+1
2471 PRINT "Depth:", DEPTH
2472 GOSUB 2480
2473 RETURN
2480 DEPTH=DEPTH+1
2481 PRINT "Depth:", DEPTH
2482 GOSUB 2490
2483 RETURN
2490 DEPTH=DEPTH+1
2491 PRINT "Depth:", DEPTH
2492 GOSUB 2500
2493 RETURN
2500 DEPTH=DEPTH+1
2501 PRINT "Depth:", DEPTH
2502 GOSUB 2510
2503 RETURN
2510 DEPTH=DEPTH+1
2511 PRINT "Depth:", DEPTH
2512 GOSUB 2520
2513 RETURN
2520 DEPTH=DEPTH+1
2521 PRINT "Depth:", DEPTH
2522 GOSUB 2530
2523 RETURN
2530 DEPTH=DEPTH+1
2531 PRINT "Depth:", DEPTH
2532 GOSUB 2540
2533 RETURN
2540 DEPTH=DEPTH+1
2541 PRINT "Depth:", DEPTH
2542 GOSUB 2550
2543 RETURN
2550 DEPTH=DEPTH+1
2551 PRINT "Depth:", DEPTH
2552 GOSUB 2560
2553 RETURN
2560 DEPTH=DEPTH+1
2561 PRINT "Depth:", DEPTH
2562 GOSUB 2570
2563 RETURN
2570 DEPTH=DEPTH+1
2571 PRINT "Depth:", DEPTH
2572 GOSUB 2580
2573 RETURN
2580 DEPTH=DEPTH+1
2581 PRINT "Depth:", DEPTH
2582 GOSUB 2590
2583 RETURN
2590 DEPTH=DEPTH+1
2591 PRINT "Depth:", DEPTH
2592 GOSUB 2600
2593 RETURN
2600 DEPTH=DEPTH+1
2601 PRINT "Depth:", DEPTH
2602 GOSUB 2610
2603 RETURN
2610 DEPTH=DEPTH+1
2611 PRINT "Depth:", DEPTH
2612 GOSUB 2620
2613 RETURN
2620 DEPTH=DEPTH+1
2621 PRINT "Depth:", DEPTH
2622 GOSUB 2630
2623 RETURN
2630 DEPTH=DEPTH+1
2631 PRINT "Depth:", DEPTH
2632 GOSUB 2640
2633 RETURN
2640 DEPTH=DEPTH+1
2641 PRINT "Depth:", DEPTH
2642 GOSUB 2650
2643 RETURN
2650 DEPTH=DEPTH+1
2651 PRINT "Depth:", DEPTH
2652 GOSUB 2660
2653 RETURN
2660 DEPTH=DEPTH+1
2661 PRINT "Depth:", DEPTH
2662 GOSUB 2670
2663 RETURN
2670 DEPTH=DEPTH+1
2671 PRINT "Depth:", DEPTH
2672 GOSUB 2680
2673 RETURN
2680 DEPTH=DEPTH+1
2681 PRINT "Depth:", DEPTH
2682 GOSUB 2690
2683 RETURN
2690 DEPTH=DEPTH+1
2691 PRINT "Depth:", DEPTH
2692 GOSUB 2700
2693 RETURN
2700 DEPTH=DEPTH+1
2701 PRINT "Depth:", DEPTH
2702 GOSUB 2710
2703 RETURN
2710 DEPTH=DEPTH+1
2711 PRINT "Depth:", DEPTH
2712 GOSUB 2720
2713 RETURN
2720 DEPTH=DEPTH+1
2721 PRINT "Depth:", DEPTH
2722 GOSUB 2730
2723 RETURN
2730 DEPTH=DEPTH+1
2731 PRINT "Depth:", DEPTH
2732 GOSUB 2740
2733 RETURN
2740 DEPTH=DEPTH+1
2741 PRINT "Depth:", DEPTH
2742 GOSUB 2750
2743 RETURN
2750 DEPTH=DEPTH+1
2751 PRINT "Depth:", DEPTH
2752 GOSUB 2760
2753 RETURN
2760 DEPTH=DEPTH+1
2761 PRINT "Depth:", DEPTH
2762 GOSUB 2770
2763 RETURN
2770 DEPTH=DEPTH+1
2771 PRINT "Depth:", DEPTH
2772 GOSUB 2780
2773 RETURN
2780 DEPTH=DEPTH+1
2781 PRINT "Depth:", DEPTH
2782 GOSUB 2790
2783 RETURN
2790 DEPTH=DEPTH+1
2791 PRINT "Depth:", DEPTH
2792 GOSUB 2800
2793 RETURN
2800 DEPTH=DEPTH+1
2801 PRINT "Depth:", DEPTH
2802 GOSUB 2810
2803 RETURN
2810 DEPTH=DEPTH+1
2811 PRINT "Depth:", DEPTH
2812 GOSUB 2820
2813 RETURN
2820 DEPTH=DEPTH+1
2821 PRINT "Depth:", DEPTH
2822 GOSUB 2830
2823 RETURN
2830 DEPTH=DEPTH+1
2831 PRINT "Depth:", DEPTH
2832 GOSUB 2840
2833 RETURN
2840 DEPTH=DEPTH+1
2841 PRINT "Depth:", DEPTH
2842 GOSUB 2850
2843 RETURN
2850 DEPTH=DEPTH+1
2851 PRINT "Depth:", DEPTH
2852 GOSUB 2860
2853 RETURN
2860 DEPTH=DEPTH+1
2861 PRINT "Depth:", DEPTH
2862 GOSUB 2870
2863 RETURN
2870 DEPTH=DEPTH+1
2871 PRINT "Depth:", DEPTH
2872 GOSUB 2880
2873 RETURN
2880 DEPTH=DEPTH+1
2881 PRINT "Depth:", DEPTH
2882 GOSUB 2890
2883 RETURN
2890 DEPTH=DEPTH+1
2891 PRINT "Depth:", DEPTH
2892 GOSUB 2900
2893 RETURN
2900 DEPTH=DEPTH+1
2901 PRINT "Depth:", DEPTH
2902 GOSUB 2910
2903 RETURN
2910 DEPTH=DEPTH+1
2911 PRINT "Depth:", DEPTH
2912 GOSUB 2920
2913 RETURN
2920 DEPTH=DEPTH+1
2921 PRINT "Depth:", DEPTH
2922 GOSUB 2930
2923 RETURN
2930 DEPTH=DEPTH+1
2931 PRINT "Depth:", DEPTH
2932 GOSUB 2940
2933 RETURN
2940 DEPTH=DEPTH+1
2941 PRINT "Depth:", DEPTH
2942 GOSUB 2950
2943 RETURN
2950 DEPTH=DEPTH+1
2951 PRINT "Depth:", DEPTH
2952 GOSUB 2960
2953 RETURN
2960 DEPTH=DEPTH+1
2961 PRINT "Depth:", DEPTH
2962 GOSUB 2970
2963 RETURN
2970 DEPTH=DEPTH+1
2971 PRINT "Depth:", DEPTH
2972 GOSUB 2980
2973 RETURN
2980 DEPTH=DEPTH+1
2981 PRINT "Depth:", DEPTH
2982 GOSUB 2990
2983 RETURN
2990 DEPTH=DEPTH+1
2991 PRINT "Depth:", DEPTH
2993 RETURN