100	'  0 T	$BS.BASG :rG
T 1.4
120   Routi'to allow usersCt Iei3)o0
N
(2(i0fo0 eH(mlat((m)D(TS i*I(DT,P O $r
n KTtorh, OUS

nsen9)$S
,GBmRRa)C GG 		e(2)o3(T(
 k(ie ca ,()	Td timeon-system stuff ad0d
180	'             by Ben Bronson,0/11)$a
200	'      Note that tis  lTo0	Tt toO'compile	
nd ca OMH$YE.CsiC1a)   Modified for Macro DG-10-18-81 -CAF
2(TS aio eH3 Y: for us=t to leave comments b(C#0 logging (R"241  ---------------------------------------------------------
242	' 15/Jun/82 Adde	0&0HHHHHHHHHHHC2"
/	(om0T6BS 
	
llow exit
243	' tie of cal0r to be 0corded. Caller staLt  d0FCeB0CAd(o nDR 44  and reco )2 2CALLH H ng wi+ e d	ime. TWit staLt allers
2$nS2R
T't get a chance to leaGt0No)F''sWP/H	taLt ayO'entered
22nSH5 =0S
= in ENTRBBSfe
lTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTf e
 (iS2a ptsword util	y OH
o	C
)  TIL that2user has tri d	o b0ak into. SYSOP bypasse		e
HInSC
T d	ime recording as he never makes it in
  HO
((M26	edTfN$r)R	' Td "exit" t 4: ENTS enterieH	o you can te (02e)	Td FCIDB 50	' they were en8R0dMINIRBBS enters "Mini") Bi (olton
251	'                                                                     R 52	' R/Aug/82 AddeC"aTm	(o e 7U8	)P
  		o give time on'  NI=C1	Y( ill Bolton
254	' ---------------------------------------------------------
U( RsC	
r/83 FixedB
g in elapsed ETo"30H3 Y: 3(s gave :ird
	$+TSoCRT M'SOH 	 0a1G6R8(2CiO2C3$	I(F		. Bill e MDn.= P	'----------------------------------------------------------
25nS,4MGO=s)v	 +NAd G6 OP logot r0N# 2Y
1 G6RE1O
3H O O,DDR 59	' Version 1.3 - O M7/mNo	 =a) ----------------------------------------------------------
22TS:tC	
y/83 Added err+2N1
p wheo0( "
a1H	ystem with nC1 3   p0-exist)H2DIRmG  oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooIf 	( I IJeD0. afte	
 gen=(bDR 6nSRSI  purge and system maintenance). Mus	T0H7 O'compil a
264  with /X swith Vers
T messae a )R
l1:rsion D
 - B Ab"'CT.= 65	'----------------------------------------------------------
279	'
E(=Ee)UT2A-Z
300	DIM H(6),HT(6),HD(6),TO1$oE
B5o6(xi0l#ROR GOTO 4 B)Dn 3aO=
RCO 
O)+2r M
i"	I52
CPS:$o= "SUPER"
340	OPE2E3c	,"A:-DMHTHi0

	INPT 
He,O$,7
IGU	24TOSET a(9INo6BG1IF F$ = W
60Ie)	pmI
H$"P5	DUT24mE V=tioRCOHiCT $ '
OT
No6,I
(9INT0,)s t2OoD
i()	 		0
NT''S
m/Nc$ iG(1g

	GOSUB200:

TC$UDG1IFOenO$$,1)="H 2LEFT$(BNRoHHTnHEN

		720
	"(8)2EFT$
7Z8T=i
3"
MLEF" $$,1T=X$ ((0Ie)	2T 0I$DD('pnNnH
i7EN=",1,"A:C"+CHR$(&HCF) 0 ENTS. "+CO 
lRN),65T1n8F
ER1,65 A	6I)w:	G8R1,1:
	OrN)))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))(RRo RGU	R	

n	:CTe	I DIg n:F
		R1"CT4 0	
R"
CY: "+N$+" "+O$ sCp
22:(DNi0

	GOSUB 15$m:D(p)r
HEDn41PRINT "Enter comments, <return> toT(	, (16 lines max)"
580	PRINT
600	PRINT "-->";
620	GOSUB 1200
DC
O)2ii	f7 THEN

	iG1
66	Or=E+1:R2iB$:

	RL=65:Ri)o,,,,,,,,,,5EG(1PUT#1i7C11Eai)YI :
700	S$=STR$(RE):
	))R65T1RU$ B 1500T1) IIgH4G	24TOSCNH"(DTI 5 	H$ $)e

	GOT5 	CiG4
73O)2A6l"S7 T:F
		GOT5 R,,,,:

	TIT
6,		'oNe
222"IT0 off or 
+i7
740	OPA"R"RNil
CSM$(&HCr	HTER
tCSM
i"H 
,lL=85a	FIELD#(	kM2  1DG(1G3r
HD)"60		 AL(RtsS	)0

	RL = 60
7808miR1,RET1)U'IN8R1,S$
800T+INT	
 i 0":") THENR 8INT		p2	TS$," 
1):) i<R 'INTER = E.	 B)
820																																																																													EFT$(S$ 0)TO	S dy2 2s	o " + TI$ + " 6 	
$  7rE"	 0POI8
2+n4
8(DTCcS15$mI=a(O)T #1,RET124TO$GH)CTI
) 
920	PRINT
930TI o,,,,,,,,,,,,,,40000
R40pM2I :SUPER.COM"
960	rIoHI
)
10000$O:dHf0Z0"eD"+CHR$(&HC9)+"RmtCSM
i"H 
,lLc
5a	FIELD#1.-1D
)	ReE6(w	
1020Et1 4B 
'I	sS	)a	R	1Co4
Io1G3r
HEe

	I IN8R1 B
1060	IF INSTR(S$,0")HEN

		POm1	1iT
 nR(S$,":G(1ELSE

	,E
mE= H8eg i 5oREa2i	 
E0nO 
 i 0POINTE+ 2)  + " to " + TI$ 	H	2 $ +i=E 
 i 0POm1	S	t5	100	GOSUB 15$m61H
(o2#1,RE:

	CLOSGH)C=R.a	OU
oD61H:	'
 "(TS M)O8T/HNl
a1 GD2B$ ro console
1C
)
1260	GOSUB620=		Eaii	fC V$
T (8)2H8e$$)=0 THEN

		RETURN
13
O)m	=80F
		1400
1340R# ZZ=1 TO LEN(B$)
1=a ORE P
,1C201	M
HM2 . 7rE" $$,ZH4	
r	t"
ASC(#E P
7,1C201)))R6$mn 0I
)80+4 
1400	R5F,a
eG1'
1"(T	
ill Td store diskCeo0
2)C=)0D(T"CB=aH'T O	1
E0nO 
 i	 PACE$()d2),RL2)+CHR$(13  7	O	0)
U	RETURN
1600	'
1 0" moI<R2C V$=""
1DC
)""6$	  4D
e IN8 
	))=	t	IF NCHR 7 80F
1800
1EaO NCH<32 THEN
 =)m,
170O)2(oHn SnHE)	2'
OT 
i"CH5  :R 8TO 16Bm)"20	S4O	fC VSM
iNCH):

	CHC=C
d)0

9m"	OM7	$ HoRMIo1IF CHC=55 THEN

	9m"	OP);
1760	GO/1DC$)"80	'
18
O)7R0 THEN
 =	DC<R





































































T	PRmEiRTO 
 C IH4	$ iG( i)YI	nEDBmn,	I MPTCs=8T12=	DC<ROFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFT12'
OT H SHoR)EC
 7 mRP e 6U C V$=L
T$ AV$,CHC5a	GOTO 16BmnY,	
 7O THEN

		1820
1880	IF NCH=13HEN

		PRINTT121OU

,a
190O)2M
1t2nHEN
 '
OT
3 P EGtGOTR	tH$mR=20	IF 7G9F"1 I1 MPT T:F
		1DBmR=(T=lbR1 TO P5<RPRINERS$;T1n0(n Mea	GO/1tH$mR=6'
20000 ' Date getting subroutine
H
H
iCO7ORT = &H5o	HIo1sO RT = BASEIutS	)Br"LH
-HHIt1 .tO 0r
tS	)C1HeIsP
                                                           
21sP
 		REAnHE DATE DIGI 				Ho		R '***********************************************************
	)D(T=#EiOT2= 12 TO  STEP -1
	RRa UCMDPO),H96 	O4eYC1	nE(oE
gi$:Y" 2M
s1iT0 0	Od5 POR$rdH:80(n DeY4
2222G)ES2(D
gB'* 
sS	oE
g
)
2C
C EoR, = DOY(3o	 dkD ONTS	1	oE
fd$r)I
bTR, = DOY(1)
25
RI Y11	oE
gF$rtt"P
                                                           
 $e '*		FO"d360$))4H n DAT2	Ti
4rt*
 T	P
i5o		"O0	d84B="         "
2400	#E 
i-84B,1,1) = 
r
8 	Ti"AY
0Z5o1"(ORE 
i-84B,2,1) = RIGHT$(STR$(DAY1),1)
2440	#E 
i-84B,3,1) = "2$r"H
CD$(DATE1$,4R(6EiRTO 
 	THC Eo60),$r"w:	MID$E nE1$$01= RIGH"	 nR"l:TR=	1)
25
Ci=E I TE1$,6,1) = "/"
2520	#E 
i-84B,7,2) =IGHT$(SO 
mEARho		:D(Z$ =$	84B
4RaRUA6l)T)7	Od8405)
2O0	DD$ = MID1Od84B,1,2)
2G1DM$ =i=E 
i84B,4 )1 H
	OU

,a
 :0 '
220 ' Timef) T(
 subroutine
2740	FOR DeYt1	$	"(2E" -1
2760		OUT CMDPORT,(&HsS	O4eYT4
278 TD(DIGIT) = I 0ATAPOn4
2800		IF DIGI= 5HEN TOD(DeYTt1	T0	O4eYT"dr 4
28
)80(n DIY4
28("H(6tTIo1$5o		I
 2) = TOD(4)
2880	H(3) = TOD TR 00	H((6tTIotDR 920H)
(6t
0	RBrlC
 
tts1	TIo)
2960	DH$ =  2Ui::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: "  ":

AB = "iC1 
,I
CD$(DH$,Z'	ODT$(Ti" (
	)),1):
Ci=EC,Ph,1) = RIGHT$(STR$(H(20Z85a	MID$E0PZ0s1 D4r
8 
 	TiH(3)),1):

	#E 
i:Ph,1) = RIGHT$(STR$(H(4)),1):

	#E 
i ,1,1) = RIGHT$(STR$(H(5)),1):
Ci=Ei i 02,1) = 
r
8 	Ti"st
0Zm$ $6TO=DD$ $	"+D1di0"+DICT e20	TD$=DH$+":"+DI$+":"+DS$T D(1TURNNoAB6F E)R780 THEN

		RESUME 860
4010	IF ERL=1040 THEN

		RESME 1H$Dh0	ON ERROR GOTO 0
403) No$e 
iC$ $6) 
44020 'TOCK ROUTINECNBe40 '
DLH
(9IN5a	PRINT "2e timeN
N OtHrs:Mins:Secs)..... "(UDDoE(T,)
R"#"
44100	FOR I=1O 6
44120	9mN O)D3)L4S (
$5  
44140		IF I=2HEN 

				PRINTI7;
4416 8)2O6	=80l)	) i NHDT2" $ Ho.
18)80(n I
442
(9INo.
220  	4N	(:t hh/m() l 3C#0d by enterAI	
44240	H	RoCiEI0RD Ie

n(2CiEI(75):R (3)=PEEK(76)
44260	HT	NDE:9D IH8(1HT(5CiEI(78):R (6) EEe9D 0Ro.
2''  And:H eB
l Ns"'diffe0nce....
445
O)2 
1R(G( L)	R(nHEN
 "HR	s1 (
tS "0

	H	 '= H(2) C.T
43
O)
ttE) 
Ttts=80l)	2"H	tH(6 R0

		H(5	(
B5 =(UDiC
O)2 
1$8Tn1$'80l)2
1$N1)
oiG(1	H	N1(

)-1NB
	=aO)2 
D	8T"n(4THEL12"HVo	(

)+10:
 "H6n
Rg2TA=(DuHEah1t8T"n('THEN R 
2T
Rg2T
GU	2s NH	 5 =(UD iG1IF H(2)"n(2) THA

		H(2	(s2R,T12"HR	rg1RB	1
444420	Httrgtt$	HT(O5a	e	$RgB5 "n(5):

	eCn
Rg
)-HT	5o.S0,x 
o1tN16nA"n(3)T12
otRH(2)-HT(EG(1HD(1)=H(1)-H	RBD i TRa(INT "You'G" I
+m3 uCP '  Nd(Cv
A
 ;
444480	TF$="P
44500	FOR I=1O 6
44520		PRI3
AO)D3)
S 90i1$ Ho.
540		IF I=2 THEN 

 $)"RINT ":"(UDw1ktIF I=4 THA

				PRI3 EA 
44O0	NEXT I
i	=1PRINT:

	PRINT
446
	OU

,a
  i 01,1) = RIGHT$(STR$(H(5)),1):
Ci=Ei i 02,1) = 
r
8 	Ti"st
0Zm$ $6TO=DD$ $	"+D1di0"+DICT e20	TD$=DH$+"