1 ::I$T
l1M:"4T146PR =a
6s
-a2 REM NADERENLICHTINGEN BREo  i70=U U0 <
(0203N

OOP NUVE
42a5 F 9DS 05  6 1"(DTH(2I k8HM0O 10000
20 G9=1010
T F 9DS 05  6 1IAURN
 RE0kX
:(1	 2l=T=8"O=51
112F VE> 0Ie=,7E=23
1 NINT CHR$(27);"=";CHR$(VE32)eGS 05G
Udpe"GI30URN
1<
Hi33N3 GYII2 
SPEE(&5In:)-&HF0?WVE=VE*2
122F H N 0$EC 8"O=HO128:VE=E+1
123 VE=E-PEYeCIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII=  0(B7E<0 THEN VE=32+VE
)S:
30URN
200 IN$=INKEY 4ETURN
c153RS267I$IQ211 =0Ie=,:"Sa211 RE+a250 PRINT CHRI7);:nURN
260 RV=RNI1)05LRN
270 F0nT  ):RETO4R n0 SI)**$-Td01 Q7=LEN-):I0)7=0 THV0URN
302 IF RIePIISR$GN H61$EC ,5+
A3 SR$S3N05U0sQ7-1<OTO 301
A4 IF LEFT$(SR$,1),="EN RETURN
32SR:
EG"T$(SR$,Q7-1):GO3 "Td12S1R:IF CG>0 THEN 31Td124=IFU4+.5)53R 6A1lTO30
3 :()RH(E-3) 1Na7SR):Q8=INT(SR)  R3
-2 O
I53OR Q6=1 TO (02 R3I2R+1L Tsd20 Q9=INT)9+.5):SR=Q9:GOSUB 300
322 Q9$=RIGHT$("000000000000000000000"+SI>Q29
324 IF Q8M0ND Q9$EC ,2 (:R 6 S0)8:GOS: T:IF Q5=-1 THEN SR$=""+SRTd28 SR)- 0SEmI2Ra330 IF LEN(SR$)<=CT THEN 330d32 SI:NR(TPII"*********************",CT):GOTO40
334 SR$=RIePII"                     "+SR$oRR UwSR S3SIAURN
350
T
Q
M- 0,RETURN
360 LPRINT:RL4R =R1M0=500:GOT  0
1010 Z=
R
1$ 1lSUB 100:R: ISSEN
:B8HM0O 5020:REM INITIUISATIES
1030EM
:*0EM ** HOOF
ROF
l0R*
1050 REM 
1060  UNR 6IMSI 23TLEG70 GOSUB 
0
3  3
Na*G"2 )+KEUZE
1080 IF Z=1HENND
1090 GOSUB 2320:REM S"RIKKELJAA"ik"PX I2)=MQS
ttttttttttttttttttttttttttttttttttt k":,N
0I 1 TO M:DBeH8u DB+M(T):NEXT
1130 0"H":Bm0k"RN8R T=1 TO 31:A$I2mM0U=t,0
1150F J=LJ THEN 1180
1160 GOSUB520:REM PAASDATUM
117NT2=J
118E)B-"TkH
a J+INT(I/4)-IF(/T)+IF(/
29
12 T-JI  1SUB 2030?cN3-R 20 FOR N=0 TO 0N32I BNEXT N
1A IF  NAHEN 1250
1240 GOS: 9  BREM FEEP=T=I1N0  50F M,():., 0T
128HDRS26h B::I
3
+
=5)RR = 7HDRS =7S(N 0 M";B$(M 1e 1
3RINT
128
RINT+OH
128HDRS26,)SI 2NINTEN
1T F 9RR =(:MT
Q
1
 G9
1320 F 9200
Q

A 1=6I07S(Na1330 GOSUB 4200:REM KEUZE
13OHM0O 10Sa1350 :
2 0170=20R*B$R92:2 SM0IENT +
2010EM **REST VAN DE B"4PTQ 
$0T=2QA Q=INNP"):R-SOBRL4R  040 :
2100 RES0RKERSTDAGEN
2:707a21M0$="K = Kerstmis") =n 05  2m2

e0Q ewA$(26 "uRR  150=24Y:N=753R 6754R    'I2  =
3  5-Y:GRS2 
0Q =0K))=1
52V05LRN
2190 :
A0 REM 4SCHRIKKEJ0R ?
I:70=200Q (U3 BT=J:N=4:GOSUB030
2330 IF R<>0 THEN 2390
2340  1EyI<OSUB030
2350 IF R<>0HEN390) s:MR:I0( 
21lSUB 2030
2370 IF G>0 THEN 23Sa2380 S=a239
30URN
V0TQ"7,
3  0

A43ATUM ?
2510 ::P1O$0I J:NeM HDRS2675Q5OT=R:N2:N=100:GOSUB 2030
2540 B   N1 R:0::N=<OSUB 2030
2550 D   
"a 
3I0O:GOSUB 2030
2560 F=Q:T -
O"I= DRS26754R  570  Q:ZT4A+B-D-G+15:N=30:GOSUB 2030
1F2O"=R:TE  4:GOS: ET
2590 I=Q:K=R:TI04E+E+I+I-H-K:N= 1SUB 2030) MP$a R:NSRUEe422*:N=45153R 6754R  ",WQ:TURL-7*O+114:N=3153R 6754R  :,  T=Q:D R1:RETURN
25O RR  700 REM **BEPALING CARNAVA-TQ :707
4P0S-, HEMELVATS-a2720 REM **OF0)

+RU 3AG IN!R0ET REM **A0a:E*PN0=2TAe0Q 03$0T=2Q60 C(4)=59+S+DA+(M++i 0V0 C(1 C(N-R9:C(2 C(N-R8
2O0 C(3)=C(4)-47EI5 C(N*1
2RT C(6)=C(4)+39:C(7)EI4449
N DEI8 C(N*50
  ='0 a0I 1 TO 3:X=C(T)-DB
28MN(X6:0HEN 28Sa2830 IF X>M(M)TH>l6R U$NP: =":C"
N 8T$=E12Carnaval"
2860EXT T
28,N8R=4 TO 5:X=C(T)-DB
288FIX6"HAHEN 2920
N 0 IF X>M(M)THEN 292R A0 A$()="vTQUI:M0m12P,en"
2:,U=t,0
29Xe"2U*3B
2R0 IF <1 THEN 29Sa2950 IF X>M(MIe= 980
2960 A$(X)=":H"
2970 0"HH Hemelvaar"
2980 FB0=09=TQU RT =IT)DB

  N: HHAH;T40r01FIX0  IM)THEN 304R n20 A$(X)=":P"
3030,11 
 = PinksterT"
3040 NEXT T
3$39
:T REM NIIU
OG IN KOLOMiE 0T=200d120 FOR X=1 TO M(M)
3130 IF A$(X)="  "THEN 3160
3140 XT30+HIEt21SUB 2030r150 K(Q)=1
3160 NEXT :nURN
3170 :
7,
3**SUBR.UITLEG
3210 REM 
3220 PRRES02"H
32MT

1+                           e0d2O
RRES MORoa*)ER          e0d2O
RRES MO0Ra326
RINT"*****************************"
tPRI4R (N  O
RINT:PRIN8 PD>(1damma geeft tSrs"
3290 PRINT:PRIN P C3"
anv3F'"alen3dbadH
A0 PRRBPRINT"CarR R53Pasen, Heelvaart,"r310 F 9200
Q
O
N"stere1
T Ke,tmis wor-"r320 F 9200
Q
ren hie$"Tj aangegevenH
tO
RR4RUwF 9RR ( s<4S27I7Td360 GOSUB 104EM *WIS=Sa3370 P)
13G
t3dst de"
anvN, U 0"
3380 PRINT:PRINPAUe N>"3
om2( RT4IN 
)
1aarna k5
 O9"n volgendea3400 PRRBPRINT"maan$ =P3R GT et een enkele"
3410 F 9200
Q
$
ER$,, te weten:"
O$N0
Q
2UOA P)
2
Q
1
IL BU"v D
"EOAieuwe maand wilt"
T
8
RIBPRINT"'0:U"v           3ug wilt (vorige)"
3450 PRINT0
Q
1
 40:U"XU verder wilt"
346
RINT:PRINT0:*NE8s U wilt stoppen"









































































































 9RR UF2O
RINTr4908SUB 4920
 sTETU4R rc39
3600 REM **P)
0d610 ::P,) FEM=N2I 0
363N8R A=1 TO 7
364 00

200
Q
Xs330)r650EXT A
,:  w4H+N33 "O=4r670 FOR SR=1 TO M(M)
36804H,RMP
3690F VE>PAHEN VE=VE-14:HO=HO+6
37 GOSUB 110: UNR 6I:20INT SA 1T$(ENTd",U=t8-00d720 VE=17&:I<OSUB 110
3730 RETO4R s+0
4 0170=20R*SUBR. UIS1GI2)
4010 REM 
40<8* 6:T:::S)3R)RRYON)
G ==maandnummer,TUe13"U7R0 PRINT
bwPRINT"Dus voor bijv.3K;U O2"
4060 PRINT
VO
RREP0N$e$ "0 :    5,1982"
4080 PRINT
08
RR4R"P70=2UNR8UTINE DATUM INVOER
4110 F 91O01Td, Jaar: ";)0M M,
4$63(NT(M):IF M>2ORO"HAHEN 4  4RS =n J=IN3dUa4140F J>99999 C ,R31RS GwIF J<158THE4350
4160 nURN
4170 :
420
RINT"    N , V , T ,D 1P HDRS  10
4210  UNR 6:T
4220 IN)="T"OR IN$= E"EN 4 0
4230 IN)="V"OR IN$="1
1.
 0
4240 IF IN$="	Q211 ,"THEN 4720
4250 IF 
ImFe aN)b "n"THEN 4 4RS  60 F 9RRS  70 PRREo8UTIEVE INOERi1<RR)M8
)
2
Q
200
Q
RRS n0 G9=4030
4310 F 9200
Q
QE AE8le0 Eoven 99999 worden"
($N0
Q
T
Q
1FFn verwerkt !"
(A FOR T=1 TO 40000:NEXT T
OS$1AO 4020
4350 PRINT:PRINP0Nt 1582 gold de uliaanse"
436
RINT:PRINT =Oender. Schrijf het programma"
4370 PRINT:PRINJe130Nor"
arG"F211N3E
43,N8R=1 TO R12L=t,0
4390 GOTO 4020
44 :U1V,
3  0R*TERUG
451
3  L20 M=M-1
45MN(6A THEN 4140:R:SN
UT )
4540 M=12
4550 J=J-1
,  OHM0O 4140:RESN)0M4FNTL11111111111111D9
460
3  S0 4N"3&
P
4610 REM UX  03 
"TLX n IFO""0HEN 4144EM *IM4F  )
46403 
465
1N2+1
468HM0O e'3 
Q0M4F  )UX 0T :
4700 REM **STVU0LtE V0=2LB8HDR 6:T:REM *WIS=Sa45O
RIN 
)
10C
FX1TNor tppee0Lt*0 F 9200
Q
 
F :CKM0euw beginnenLN' intypen"Ut3$65:G0
3*N
4760 :

00 ::S 1N1e p(NPUTUNT RUa4920 PRINTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT N
30URP iLNT5OHDRS26c 4L4RSUS$39V
:93  0
Q0naRE4TTIES
5010 REM
5020 D:n$(31), E  ),D$(7),C$(8),M(12),K(5)3h
5030 FB0=TO 120"0D B$(T0U=t,0
50400 a0I 1 TO  4EAD D$(T):NEXT T
5050 FOR T=0 3 :READ M(T0U=t,0
5060 GO3  2EsV0 :
3 26 TTA"Januari",IU$"=
"
ri","Ma sI
30010 DAT:0pril","M
10 102uP10 10251
0d0020 DAI:G 5
H$$s 1C
,I"$Hd"e I1111111111111111111111111111111111111111111111111Nber"r0030 TI(T"30G
3"53ecember"
30040 TIl5
;8","D"
30$6 TTA"W","D","Vr 1AEe0d0060 DATA 28,31,00,31,305"$n
30RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRTTA    315"$n,505EEPA080 a300,
 0RRRRRRRRRRRRRRRRRRRRR
30100 REM *                   *
3 =0=20R      KALENDER      *
30$0T7
0E-T0d0170=4  INCL.FEESTDAGEN *
3S V0=20R7e+
30wREM * MAKEE2IENS2*
30160 REM *        DOT)N
 4
E 70=4                   *
A180 REM *********************
EUA REM
3020
3  5::RP0 OnPPLEI
30:70RR n220 REM 4UU0(=6--$2 
30230EM
A240 ::: "0(:7OOR DBEPAINGr02V  2VAN DPAASTTU0Td0260 REM  HEM9I , :0MiNG,
30270 ::)S(L 1973;IET
A280 REM  BOEK VAN J. MEEUS.
A290 REM
M  VADE PAASDATUM:
30260 ::m.NR0=, O00N0F IH70d 0T REM  APRIL 1973; O1CA
3:4*OLGENDE
4610 REM UX  03 
"TLX n IFO""0