1 EIO D0 eG>XOUTINES DOOR H TGEVEIR
NTzIT BtIEN"-7pINGEN BASICODN REM NOS, 5eBYT e
AtAEIUM 
5 PRINT CHR nIS .n IDT no1

10 1"A
>:E1 1"A$1
100 PRINT7dj(26);:RETURN
110 REM
9=P" HO 0UAARE&N5 1 012 IFEN m3$ Tz&D"e2R$5OS LPCN eN 

;"=";CHR$(VE+32);CHR$(HO+3
;
115ETURN
n1 HO=PEEK(&HEF5A):VE=P TG3TM0AN
-&HF0
 0 VE=VE*2
122F HO>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>TH&6 RO-128:VEGE+1 023 VE=E-PEIsP3   6
:IF VE<0 THEN VE=3"VE
124  "t E.10 IN$=INKEY$:RETU E5
S 140 200:IF IN$=0,REN 219:0RETURNnOUS LPT CHR$(7);:RETW
IS7NeRND(1):R 1((((((((((((((((((((((((((((((((((((((((((0X=FRE(2:RETURN 1                                                 eIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII- E50 Q7=LEN(SR$:IF Q7=0 THEN RETU EUP"sXIGHT$SR$,1)<Ew THEN 3UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUl0kN 0eEFT$SR$,Q7-1):GOT31N S0"sCI"IU0R$,1)<>" TRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRETURN
30A N 0eRIGHT$(SRT1=:a0
:GOTO11
310 Q4=SR:IFtn 0 2
REN 3GRlOk2GZIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII10
:140 300:GOTO 3 E&O0 eeSGN(SR):SR=ABS(S
:Q8= "-t0=eSRQ8 308 FOR Q6=1 TO N:Q9=NnI-XT Q6
320 Q9=I  E e9+.5):SR=QaN5:1 e 300
322 Q9$=RIGHT$("000000000000000000000"+SR$,CN)
324 IF :0e0 AN0=9=0 THEN Qe1
326 SR=Q8:GOSU35
 IF Q5=-1 THENTj=""+SRE&=":N 0eSR$"."+Q9$
330 IF LEN(SR$)<=T zN 334
332 S1eLEFT$("*********************",CT):GOTOS5E&3$IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIeRIGHT E
S$"+SR$,CT)
ojI>Q4:RETU E3 0 PRIj$;:RETURN
360 LPGHaEURN
1  A=100:GOTe1
1010 GOTO 
 4zTG"0B-0GR"NEj120 :
103aEz$a Hp VAN HEHOOFD&NB"MR$14aR$150 GOSUB 1:PGKVoed, danEST "beginn2n" 0060 PRINT:tGfffffffffffffffffffffffffffffffffffffffffffffffff070T:PkF556Im ADe "E                                                                                                                       nke0T00e A en 10s"
10
GTwEj190 PRINT"200k 00=v:4 weten =lk et hoogst1N 0100 PRINT";l in het 2Tt1s wVDr u 56E0N 00000 PRINT"willen spelen.":PRINT
1 
LI 7=s dat getal, maximaal 91";
1130 IN0 NS:dj5:1 IF GI<92 AND T $ Tzne1 0150 PGHINRINT"n keuze w 7 ;GI" 2
MRN0O1gt t2Tt7=t" 0160 PGK0DPssen e
n7I0" 0170 PGHINRINT
 080 PR " :B s    o p 00 u w "
1190 FE" 20 TO 20TF:NEXT I
11 1"Al 0
 00 :
ne1DB0:GOS= 81
1230 GOS= 302TzION1D  IN TOT GI
1240 FOR GW=2 TO:2S0WW)=1:NEXT GW:IF GI=91 THEN 1270
1250 FESD>G"1 TOi:GT(GW)=0
1260 NEXT GW
1270 SAtk==0:RIA  NUEa
1280 GOSUB 
a4Po720J:REM PRINT DE STAND 0290 FOR I=1 TO n  I0-
IHT I
 3i
1320 VE=21:HOtS 140 e 110C RP$:PGHAt  =S LPT SP2NN 0330 VE=21:HOtS 140 e 110 0340T:PAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAPD:"HR$(65+B
" kies  ";
 311 GOS= 41
1360 Pe1aL 2
 TE3tHNt0RS=1&,1 R$3
0
5:1 e 5020REIVET KR
1380 IF IN$=" T
5:S5Ej3
s FK:l0REN 1500
 1TR>KR-4I  KR<0 OR K=9 zN 1440 0410 G:i*GI+KN B1 VE=21:H206&1 110:SR=GI:GO0 e 300:PGHA N 0EjS3UO 2N 0N 0:1 TE=TE+1:IF   8d<TF TH&70
 :0 TE=0:52Tt2AEa1:GOSUO5(
1460 PRINT MRU0 Hj ,CS,1:CS=3-CS
1470 TP=TP+CS-1 0480 VE=10N523
 GOSUO5
 PR "S6
L ";:SR=( :0 GOSU35
 PR RR$;" ":GOTO 1 R$O5
TzI0&I1D""B#6lPNEN  1T ah2AEa1:GOS= 110:PRINT" ";
 1p!:Ne0 THE1550
1530 IF GT(GI)=1 THEN 1600
15
4EjO3 SMe22:H2
 GOSUB  (
iJRINT"Jamc CHR E00;TA1:4D:dat getal is O1T2."
15
GTwI0A 



 o p 00 u w ! ! !     ";
 10 FOR I=1 TO 40TF:NEXT I
1
 &,=1
  : 
GT:PT"eA r$gt ";
1610 SR=GI:GOSU35(
1620 PGHA N =z)RGaR$04O!D>GI:GOSUB 7020
16
GTwI0T0N :61N 0 :l0MI=1 TO5*TF:  RT
1670 :
1 0
AEa3:52
 GO0 e 110:PGKAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAPO;:"CHR$(66BE);
1690 >TP:GOSUB 300:PRINT" kr$gt ";SR$;" pt";
1i FOR I=1 TO e 0-
IHT I
17l2Ne9
172  OR GW=TO GI-1
13
0   GTGW)=0HEN 18(((((((((((((( 1 :IF:g1 2Dtg-7  ED  " WW)THEN870
17
4 N"e2:N=0:SR=GW:140 310
17
4P5:1 e 7020:REM3 D0RG

R$
T )4040 e 250:FOR I=1 TO 20
kS4P5:1 e 110:IF 2*IN
I/2)=I THEN 1800
H

- PRINT SR$;:1"A 000
1800 S LPT"  ";
1810 ::UE": 20 TOSR
C dj"=  NT 0Ej"03 T2RN+GW
1840 :VE=23:H206&1 110
111 :SR=
 140 300
1 :S LPT SR$;" pt.";
1870   RTD9999999999999999999999999999999999999999999999999 0
SDt:25:1 e 7020C "KD
1890F BE=0HEN SA:HTS:2k==SB+TP
1900 IF BE=1 THESB=SBGI:TeSTHN
100DB1-BE

:
0l0MJ=2 TO 91:IV
J)=1 TH7I6 i1:GOTUD5 Ej
&1 NEXT J
1940 :

11 :GOSUO10:PRINT" * * *  E I N D$&-
GI=  I,U

-p:PT" ********************************