2000	REM	FIND
2005 	INPUT "FILENAME: ";FILENAME$
	INPUT "What do you want to find";A$
	COUNTER=0
	FILE	FILENAME$
 
2010	REM
	READ #1; CALL$,NAME$,QTH$,FREQ$,\
	DATE$,TIME$,CARD$
	IF CALL$="END" THEN 2020
	IF CALL$=A$ OR NAME$=A$ OR QTH$=A$ OR FREQ$=A$ OR DATE$=A$ \
		OR TIME$=A$ OR CARD$=A$ THEN 2015
	GOTO 2016
2015	  PRINT
	PRINT CALL$;" -";TAB(10);NAME$;TAB(20);QTH$;TAB(42);FREQ$;\
		TAB(55);DATE$;TAB(63);CARD$
	PRINT "          This is ";COUNTER+1;"th name on the list":PRINT
2016	 COUNTER=COUNTER+1
	GOTO 2010

2020	REM
	PRINT:PRINT "END OF LIST"
	PRINT "Total ";COUNTER;" names was searched"
	CLOSE 1
	INPUT "More searching? (Y/N)";A$
	IF A$="Y" THEN 2005
	GOTO 2
