REM ******************** CBASED " =GLGT8RFM *		AL RENDEL 3/1U81RFMS C	R1LE
	8;(TMD$
 OITMR
EE OOIONSRFM	DA0ATA TRY AND EDIRNE TR STRINGS OHNMA
E+AT
REM 
)I/OAR*TS EDIT USING TERMTAN=UP;R WITHOC
RE	CUR$ME"MTROGUECIALLN3333333333333333333333333333333333333333333333333333333333333333333333 OI IRSA  ERY FN\RA	

EORMS OR FO$FNDON ACCESS FI(TSN\
RE	
G CBAM\UI FE(LEEBINAM	
G\
		AL BRDEL"15/81
S RFM ********** SET CONSOLE WIDTH **********
POKENNN(D  ONSOLE

	REM **********ORING"NCTION *************
AM *TYPICAL UW8  M2NRD FN(RLNG$(12,O) REUT$LNT 12 LINE FE8

	DEF FN.SLNG$ )ITH,	0EYE\
ORINGBTS  M TR NU:U$OT(	)ITH
 	RLNG$ = STR$$	N%OEY)=		NEXNUMB
FN.RLNG$=STR$   
TRP=	FEND

	RE	
G
 GEDATA 0 EDIT FE(LE	NDS RF	D$TTMD APIICLON:
AM	NAME$EN.G.DATA$("MSG",T++$		C)2ELD.E
A\
$G	'PRINTS HMTI0 THEN A*TS
AM		'ENTRY M$U ATMDDION OF NAMETI0 RFM	S>TWSFNGTHNFE+AL\
REM		'EDITING COMMANDSMCLUDE8 R K	'ME
EE.I R
MN	HTHE.U\
$GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGNO	EOM,
)AHHHH	< OR BSS

	REM				'DELETE CHARACTER...............................................................................TN\
$GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGG$ RT CHNF(N3 ^
	$GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGM RN TO PROGI
U		CRN\
AFEL>FT.DATA$I($,N
	C)FNGTA\
	NAME$=NAMNIAN.RLNG$(LENGTH-L(NAME1OHLE\
	PRINT MSG$;":6MAMNIAN.RLNG$(LENGTH,8O
		FOR NUM = 1 TO LE1;S  NLUTESM"MCHAR%
		IF ANS%=13 THEGOTO 1.03
	NFTIUSC
CI	"M=1 THEPRINT\ NM.	NR,TLRTNT$(N
	C$;N,1)+GNRU8)SC
 	 ON=NUM-GGOTO
^2
IF ANESC
U.EN NUM=NU(I\
		:GD 1O2
		IF ANS%=62 AND $SMNLTHHEN\
																																																																																					$LNT CHR$S)+MID$(NAME$,NUM
N 
8 N	+CL 88888888888888888888888888888888888888888888888888888888888888888888888888TNRU7);\
				:NUM"M-1:T0 1.02
		IOIUTESCU2 THEN PRI CHR$(8)+\
		MID$(NA	C$;N,CO:GOTTTT2
IF7TESCU0)O NUHOT(.EN PRINT CHR$S)+\
				M2 T+$		C$;N,1)+CL 88888888888888888888888888888888888888888888888888888888888888888888888888TNRU8);8 N	:$SR;N-2	OTO 1.02  A ANS%=60 ANDUM=U.EN PRI\
				CHR$(8)+NTT+$C$;N,1)
HR$(8);\
				:NUM=NUMTWGOTO 1.02
		IF ANS%=9