10 GOTO 100000T0 RE
6T1 GOTw2a00T2 REM COMPUTERSDmaGIT N72  eRBEN
sor eat0tonOCS0orn DEL 20 HEBii0eaeAN:
2BtT d
e i7Gse A
25 OTO 1010
100 PRINCR$(
teTut.z t 
e dDea3REM 10  te 5tnh ehSCHERM  :"iN
102 REM     t1rtWd  : HOME
103enhd
e;tP 

t duuwi7GT
104 REt0R
OP B eNPET : PRINTCHR$(1d
egBa9nn"     OP .....  : 0R

106 :
'0 
je=500:GOTO 2Dea010 GO #0 00
1020an4 atWme  "
$TD e7BETBE$
1050 IF RE$="****"THEbu00p" 7777777777777777777777777777777777777777777777777777BK=1
1070 IF BK>LEN(RE$)TEN 1040
1O3AK=0
1090 AK=AK+1
 73IF BKT
jteWd N(RE$)TEN 1120
11110m0 EeniEeeuedD
uwkoubdaHeIb" 0.zu  30
1120 WO$=MID$(RE,BK,AK)
1130 BK=BK+Li
eev
nrcAT
Ba13IFddjeonEN(W0ted eeRL THEN GOSUB 123Dea150 IF WO$="&"TEN WO$="":GOSUB 123 0 eti   30
1160m0 #ni$<>"#"THEN   30
110 OSUB 1230:IF AR<>THEN 1170
1vdbT cwL3BhadwTui ,N0 d1200 PL=PL+LEN(W0tecAT
Ba23IFdd 
 o"0BTa THEN PRINT" ";
GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGeti 1070
1sdwT4 e1n4 40 AR=AR+n4 D tDaK0 k
 TrrG SHEw ta0
1260 PRNT
1270 PRINT"  VERVOLG: 'TOET45
 oeT;d teoo
120 NPUT SP$
1290 AR=0
1F DOSUB 100
1310 PL=0
1T0 RETRN
1330anSosddbTiSUB 100
2310 PRINT"Hoeveel karakters jd  in  computer"
2320T4 eH 0Dn gel ? ";
o5 ItE4 o"0anSoUT3PRINTP e1nSostDtto" eH  eveeAede AaAEin unn mPiAbwe.e
6T360 PRINTdvhet schermeeseI$I0dF0
 E4 T"p0T380 GOt w7gDTisdWm:r 
6T400 GOTO 1030
o"1:"aT0 
j0r1e"Hallo, damti
i  e weer met deeDRogsTaDATg  & Dit deel geeft een overzitUD3&" n4at3DATA4r0 oDE-2 eTr A. & Zodra de nieuwe le ede
RsTsdGATAn  woe usA- routines zijn u0lzoAn zalDesT"0 DATA"HOBBYSCOOP verder vond a dit proei"it
eleeadn4n nkTA"& Heprotocol dE1at uit eeaantal vaste"
3060 DATA"subroutines waaiABik regel:g
""eC"en4azkTA"10000 zijn geservedg  Daarnaai"Dle"
3080 DATA"prakti w4epks,Adoelom de leesbaarhd"
 00 eT8t0"gRTdl1m103a e#4emAteren. e
RF3eTg  Lui.e1d3d programm03aei  3
fUng"
313DATA" kl ajeln (en dat zijn er ge
lkig (ds"
31dGATA"meer), zullen hun pe
e1m103a sn het pT0ei 0"e
ta3DATuaeTraanpassen. &1"A(erst een overzicht"
3140lTA90"E 
 neoutines. #"
3 FnkTA"OSUB 100 & & " "t4neachtej  bvoorta e
R58FnkTA"T cherm"
310 eTfrn schoon 3nAnt0"u esor links boven"
3180 DA
i Uk hoek Aaatsen. & & n=ede7 d#=B4
330 DATA"w computer dus st
ut
heTt
"E    A e
RPnkTA"-CLS    A ieT4 ehCHR(12)    o &"
3a0 DA
ie1S4ieo .d eeTtdd
ehuTdnanaD"cja, ga zo ma
gBs0ot0r1door. & o  d
kfde rege& ted o  =nc0DDDDDDDDDDDgBs0dos7e1e"volgendeegel wst durd orn03i/0e4a0dGATA"GOt w  7
1naBze opdracht kunt U gee
len om"
3250 DATA"d isorp eegewste pE5 ajg " vw4ee A
a0u DATAr etn. Daar hoo                                                                                                           3nog wabij: &"
3270lTA
i sTs VEO  4eeedA  ) #=Bh snegel 0,""a0dNs7e1e"de volgeA 3regel dMs NT
1B m UnDAse"
3290 DATA"pln op elmeedAl is plaats 0,t"Od tCe
R5 00 DATA"7nenz0i t ain unrd EO  e9met 40 kara e.a"
3 7n1e"perek. &1B boebdU a nu, daUn "
a000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000kTA9w fl  eOEppehCni  elmnkaats in de"
33330 DATA"Orizontee richtin0"u.aor moet komen en"
333DATA"                                                                                                              jkhlle  VE p welke rege bb.eP49ne
gB5 50 DATA"richtinegB5 60 DATA"# Een voe leld: & & VE=2 : HO=4 : GOSB  7
ogB5 70 D "  Hiermee komt de cursor opegel 2 (9"""""""""""ek"
330 eToeel vaboven) en op die regelp plaats 4, dus"
330 DATA"vhet v aA  AAter van die regele
RTFnkTg  Hierna zal het eerste kara e.8snE8 0rpfnRUmFnkTwT4 ehaatatement op die aandAven plaatdn4'0 DATA"techt moeten komen.0e4t"3DATA"OSUB 120 & G
bPmlmu li3ivtu at het"
344DAT=lkede3&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&OBNpbau0o&Un  programmaDeUd Fn1e"deze sueT cl eeft aan-edAd E5EU bb.E""t"60 DATA"en HO de juiste positie vadeiiesoop dat"
3470 D "aent."
3480 DA
g  & " d iunns4DeNof HO iets ope tellen"
330 DATA"A A  tkken en daar5 
C   7Vb"Od e
RstD7nkTg0"5bi de cursor ten opzitV8sn de 4A""ataFnkTA"pE5  eD"
3520lTA2iSUB 200 & & Dit is een sube:One die voor U"
3530 D "eikt of er eetoets3&w4 9TehaenbeEwas"
354DATi Adrukt.1"A"ed k was ingedrukt danDest&FnkTA"Bi  dm Ac ele IN$ aandAven welke toets,"
36DAT3nd.brda i Adrukt dan zal IN$ een lege"
3570 DATA"strin hReln. #"
38DATbTiSB0F
1n4t4E nuti lijkt wat op "
 hadGATA"BneO
 itBe&i  3e..................................................................BiE 
 neoutine"
3600 D "Awac 9T&U"eied 3Teha is ingedrukt"
3610 DA
45n t&itBe&ii Adrukte toets als IN$"
 620 D " eer aanuagRpTvj a  lgeo . #""a
a 0 DATA"GOt '50 &1t
0"t43snrocAan een"
364DAT80oO2mai
eA
e1m3voortaanEg".nul geveeA4a
Da7e1e"& Bij com:d3waar geeluidspre
 aDes
DddGATA"0lbouwd doet deze subroutine natuurlijk niets.""a
n3dGATA"& & M d
bPmlmu lil brd ut9cede worn"
 680lTAlmaakt. De eLho&eid    8t t  eg
 A"
3690 DATA"is niet va$nrlean4E 
 neou li 3a ndeeen"
3700 D "ldoep
N  "ndeijkheid tot een hoor sr"
3710 D "t0
 nr  eeln. #"
3720 DATA"GOSUB 260 & weet aanroep van deze"
330 DATA"
 outr Ngiz0ird 3& m=Ben bik  Ahlle"
3740 D "eV g  In RV Bi& :deijk een rand3getal"
3750 DA
3 lgeleveterT Y Eate gal dadeoutr"
 760lTA" sfleveren is 0, ele afgeleveA h ndeen"
3770 DA
Ecu
 Yre .$ &w & & Dee subroutin9n4aDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDkTA"opgenoE=Cnn                                                                                                              
e dT lA  ei EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEeriw4=TdTs"
3790 DA
gT ni
do wi Alend bi9At te werken. #"
3800 DATA"GOSUB 2701naeteze aaned  orn Ageda" 
R56FnkTEUeingspgeu"oEitBe&iik vartndee  
n4t000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000kTA"es antwoord geg4Ut rok bytes er nog"
330 DATA"0lbruikt zijn. & Tekstpe
e1m103tlunnen"
384DATwirrmee tijdig zien aankoE=nct T dAn"
3850 DA
8 ife
iVoTard 4UTid  
rel eepassdeDe5O3DATA"kding pro4i
Rh'dn4tDoza7e1e2iSUB 300 &1"AB3tkze 
 outr 
9e4
38DAToene: bi de variade "k naam SREe
tDm 0 DATA"(gep3 rc aarde htnd brpo eealls antwoef
RsddATA"geet z  
 neoutin ii0et.d ee
t.ranA
RU5Fn1e"& wbeijkt wat ovenA3D&maN.i a noge wagBUs000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000kTA"va  z.i U t  STR$ funct oooooooooooooooooooooooooooooooooerse"
393DATunvwi l3t3iwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwwweEbrenT itdeEE
TnOa3het"
340 DATA"E5 Vu ijfer, de and nt. & So nd b"Oe
RstDa7e1e"bij posOeve gepken een spatie op  pln gBUs
Da7e1e9  4 9edeen, anreAgirn met heeerste"
3970 DATA"c ar. & &"t4 e
:"Te
 iDE sube:One"
38DATbrenT bmtnOi0T0r1
 U1dsDi"eo oor en niet erna.0e4t t adATA"GOSUB 310 &1vwi 3t  erd w4Ae mor, alth aDe"0000 DATA"v
NeE3sntal computers die dit niet van"
401DATwiu a uikennen: & Het getal n  iiPereeftDe"020 D " on wnduT i Ued iPe$ door de subroutine.""eadGATA"& beeng van SR$ 3naf"0Delijk 
4
404DATia Un 9eoren in CT had opg"Od 45 nd3U  e
R"#a7e1e"CN een gepi
eTH.$ &o9D4ee "Ad dan"
4060 DATA"bevat S0?t0ri 4Enemn
 si:T $ srna nog CN"
4070 DATA"cijfersg  Een voorbeeldje: #""evdGATA"
me123. 8Gti me7 : CN=2  GOSUB 31& &"
4090 DATA"Dit levert als antwoeESR=ia23.46'"
mF0r1& & SR=-1e-3 : CT=7 : CN=3 : GOSUB  7
1nA
R"110 DATA"levert als resultaat SR$=' 2r711
1nA
R"T0 DA
iPe=98765  CT5t  e ra : GOt 93& e
R1 0 DATA"geeft alsea NcTR$='******' & &""e"0 DA
iPe=98765  CT5t  e "doG03Ce 310 & &"
4150 D "Aet es reakr 

n rDj#ozdD g  &"
410 eTEinO mi 6i 3aateeds het tota9awnN m lersDe"170 DATA"in4 =e3 m"st en na de painn  snog
 p"e   3DATA" usAers. Als T  ehuaelijk 3kom er""e a7"e0bEe.euls ehet antw
e 3aat
3in"
420DATu ijfernonOe en netjes afgeronde
Roa0 D "  & wi 3asuurlijk beed o:Nm frd e4eD 000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000kT3eilunnen pro4i
Rh'dn4eD0 eTbTiSBn 
1ntrCRdn 4eoor dat SR$ wordt"nsidn4eDR7nkTA"ope printer.hTR$ kan zijn beppen0 "R4
4250 DATA"d  
 neoutin0Doll 300 of 33maar""e6DATg1tuurl aAAloor Uw eigen programma. &De"270 DA
u0 4 bBcstD3&ue0UtBe&iioj T automatisch"
dT80 D "d inefe nlik print gestuuret"
T90 DA
Gaartoe dient & bTiSBI
1nt3...........................................................................................................k
e ad7"e. 3pkrs doet dane 'car   nmeePNd00M
433DATA" 'linefeed' naNl ecse geven. A
R"320 DATA"Dat wedA 
 outrs. & Deoek regGv"e3A
e tsdGATEcu
 8 r 4su.Ae latere ujeUnG&"
4340 DATA"De functies die deze sube:Ones4eo ullen mogen"
4350lTAt9aDi:eoe  33Ueed3worden gedaan.De"360 DATA"Uw eTe1mma zoup m ans enkeiw4=TdTs"
4370lTAOet gd 
eEil0g 1RASICOUT .At"
4380 DA
g1ast deze sgeT
  ca e
4DAele eisen: #""e a7"eE)nr: & Uw pe
e1m3moet starten op gel"
440DATw20 
"& DlPrbE1at opegel 10e opdrac utdnimFnkTA"OTO 10000. & Op rege  20 
Olan een opdritUdn4e t3DATAE1an als: A=10000 : GOTO dA
R"430lTAoi   d&&gNT Cnede 20 stn  ""
duu3DATA"somml cgA:r3di&UpA3$ttrfeen""etDae1e"CLEAR opdracht wle rmatrineuimte wor e
R"""""""""""""""""""""""""""""""""""""""""""""""""r1vrijgema" 
Tlndere computers hebben dat niet"
4470 DA
gT$i3.w.nd Cn=edAl d3neen maar""eDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDkTA"staan: & OTO 1010. #"
4490lTA0nn EuagRTdl1mmaa gel 13
O3i aD. #3&e
R"00 DA
indeang. We htnd itde enkele aanbevebdAn: &De"510 DATA"& )A pe
e1m103t lginnen meinitialisatie.ogB"20 DATA"Dat kaz 
utsl.Aei DIM opdrachten,7ee"
4530 D " a   flen op een beginwlel zetten," eEAD"
d 7r1e"ar
deei DAcbkeent<ee
b"E3sne""en nkTA"gebrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrEtCOABPe1dn4 I7n1e"Aalzien al deze dingen door htsasalechts"
d t3DATAenEncn sn wekn verdient4 9snbevebdng"
4580 DA
3nAzepdrachten aan heeisjg w4 bBTd :bk
R"590lTAr etn. Op gel 1Fnn  sdan bij U"
4600 DATA"bijvoored d0lf1c iNPi vT0"eae4eI  7nkTEe31A regel 0000 staat de ini  ne 3stie edeDe"620 DA
faatste regel daarvan is dan weer GOTwLananA
R"630 DATA"Op 1020 bebhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhAern van heprogramma dan. & e
R040lTAtd 3m(k advies is, albdeTA-reg3t  eer na de"
4650 D "GialEz.3eb7Tnaeea
ogB"660 DATA"ikrde tip 3om daarzUe....................................................................................................fnodDA""eDt3DATA"REM opdratVU=t proea s uitleg te zetten,"
4680 DA
3 lgesloten met REM's  srinuag1am eadresDe"690 DATA"wsn vermeld8EpEdie het proea s LIST"
4700 DATA"ziet davanzelf de E5 V'0 regels waarigB"710 DATA"juist staat h het programma heet en wie het""eot3eTia &le.w(nT bvwoeTirt 2dn4eD77nkTA"ekijkt U gewoonEa een aantal nieuwe"
474DATgRTdl1mma's""e3Fr1e"o0  idei Arse krijgeet"
duFnkTA"T lot & De bodigde 
 outrs worden U"
4770 DA

































































Bit" bOeuwe ASICODEee3
eA
e j tpkeverde
RFi3DA
g  Hoe dat precies ga E5EU biUR"790 DATA"leeseTe1mma."
4800 DATA"NeUit" buBdnijedig op3&le.w4 i  egidn#TDa7e1e"u0lzoAn, als het opmen niet lukt kaidn4e T0 DA
Ei&k u t"t D&eelistinsane1gen bij &De"830 DATA"& OBBYSCOt1n: mt9taddg
4840 DATA"1200eE  I3eb
a 9e2dn4e vtDa7e1e(((("
50000enhdm"eHOBBYSCOOP
5010 REM     UITd  BA<0jd0g WT0 REt0RmRee7E5aaGEEL)
030enhd
e0 eo"6teckN COYRIGHT
5040 REM           1983"eOBBYSCOtgIta0 ee w39t t nd van h programmgB"590lTAr etn. Op gel 1Fnn  sdan bij U"
4600 DATA"bijvoored d0lf1c