15 DIM T$(368),H$(368)
20 REM TO INCREASE DATA (1) ADD DATA (2) CHANGE DIM (3) CHANGE RND
50 GOSUB 2000
60 PRINT:PRINT "DO YOU WANT TO TRANSLATE:"
70 PRINT "   (1) ENGLISH TO GERMAN"
80 PRINT "   (2) GERMAN TO ENGLISH"
130 INPUT Z
135 PRINT CHR$(26)
140 IF Z=1 THEN GOTO 1800
150 IF Z=2 THEN GOTO 1900
160 GOTO 60
170 REM ADD VOCAB BEGINNING WITH 1335 (ADD 10 TO EACH LINE)
260 Y=INT(RND*368)+1
270 PRINT:PRINT H$(Y)
280 PRINT:INPUT A$
290 IF A$="QUIT" THEN GOTO 3000
300 T=T+1
305 IF A$="I GIVE UP" THEN PRINT "THE ANSWER IS ";T$(Y);".":GOTO 260
310 IF A$=T$(Y) THEN G=0:PRINT "THAT IS CORRECT!":PRINT CHR$(7):C=C+1:GOTO 260
320 IF A$<>T$(Y) THEN PRINT "SORRY, THAT IS NOT CORRECT."
330 G=G+1
340 IF G<3 THEN PRINT "TRY AGAIN.":GOTO 280
350 IF G=3 THEN G=0:PRINT "THE CORRECT ANSWER IS ";T$(Y);"."
360 GOTO 260
1000 DATA "WASSER","WATER","WISSEN","KNOWLEDGE","ICH","I","ONKEL","UNCLE"
1005 DATA "REISELEITER","TOUR CONDUCTOR","ROHES OBST","FRESH FRUIT"
1010 DATA "KRANK","SICK","LIEBEN","TO LOVE","HALTEN","TO STOP","FLUSS","RIVER"
1015 DATA "RUHIG","CALM","RUSSICHE EIER","DEVILED EGGS","SACHE","MATTER"
1020 DATA "FREI","FREE","DUNKEL","DARK","ENTSCHULDIGEN","TO EXCUSE"
1025 DATA "SALAT","SALAD","SAUBER","CLEAN","SCHAUEN","TO LOOK","SCHIFF","SHIP"
1030 DATA "FERNSEHEN","TELEVISION","ANFANG","BEGINNING","ABEND","EVENING"
1035 DATA "SCHIRM","UMBRELLA","SCHINKEN","HAM","SCHLECHT","BAD"
1040 DATA "BAUM","TREE","BAHNHOF","RAILROAD STATION","BERUF","OCCUPATION"
1045 DATA "SCHLUSSEL","KEY","SCHREIBEN","TO WRITE","SCHUH","SHOE"
1050 DATA "RAT","ADVICE","PFUND","POUND","PLATZ","SEAT"
1055 DATA "SCHUPO","POLICEMAN","SCHWARZ","BLACK","SCHWEIZ","SWITZERLAND"
1060 DATA "ABENDESSEN","DINNER","ABER","BUT","ABFAHREN","TO LEAVE"
1065 DATA "SEHENWURDIGKEIT","LANDMARK","SEIFE","SOAP","SICHER","CERTAIN"
1070 DATA "ABFAHRT","DEPARTURE","ABSAGEN","TO CANCEL","ACHTUNG","ATTENTION"
1075 DATA "SITTE","CUSTOM","SOFORT","IMMEDIATELY","SOHN","SON","SPEISE","FOOD"
1080 DATA "ADRESSE","ADDRESS","AFFE","MONKEY","ALLEIN","ALONE","ALLES","ALL"
1085 DATA "SPEISEKARTE","MENU","SPARGEL","ASPARAGUS","SPARSAM","ECONOMICAL"
1090 DATA "ALPEN","ALPS","ALT","OLD","ANDER","OTHER","ANGEBOT","OFFER"
1095 DATA "SPRACHE","LANGUAGE","SPRECHEN","TO SPEAK","STADT","CITY"
1100 DATA "ANGELN","TO FISH","ANGENEHM","PLEASANT","ANGST","FEAR"
1105 DATA "VEREINIGTEN STAATEN","UNITED STATES","STARK","STRONG"
1110 DATA "ANKOMMEN","TO ARRIVE","ANKUNFT","ARRIVAL","ANRUF","TELEPHONE CALL"
1115 DATA "STEHEN","TO STAND","STIEFEL","BOOT","STREICHHOLZ","MATCH"
1120 DATA "ANRUFEN","TO TELEPHONE","ANSPRUCH","CLAIM","ANSTATT","INSTEAD OF"
1125 DATA "STRUMPF","STOCKING","STUHL","CHAIR","SUPPE","SOUP"
1130 DATA "ANSTECKUNG","INFECTION","ANTRAG","OFFER","ANWALT","ATTORNEY"
1135 DATA "SUSSIGKEIT","CANDY","SCHOKOLADE","CHOCOLATE","TAG","DAY"
1140 DATA "ANZUG","SUIT","APFEL","APPLE","APFELSINE","ORANGE"
1145 DATA "TANTE","AUNT","TAL","VALLEY","TASSE","CUP","TEE","TEA"
1150 DATA "APOTHEKE","PHARMACY","ARBEIT","WORK","ARBEITEN","TO WORK"
1155 DATA "TELEFON","TELEPHONE","TELLER","PLATE","TISCH","TABLE"
1160 DATA "ARGER","ANGER","ARZT","DOCTOR","AUCH","TOO","ANTWORTEN","TO ANSWER"
1165 DATA "TOCHTER","DAUGHTER","TOT","DEAD","TOMATE","TOMATO"
1170 DATA "AUFGABE","TASK","AUFMERKSAM","KIND","AUFNAHME","PHOTOGRAPH"
1175 DATA "TRINKGELD","TIP","TUN","TO DO","UBERNACHTEN","TO SPEND THE NIGHT"
1180 DATA "AUFSCHNITT","COLD CUTS","AUSFLUG","EXCURSION","AUSKUNFT","INFORMATION"
1185 DATA "UHR","HOUR","UFER","BANK","UND","AND","UNFALL","ACCIDENT"
1190 DATA "AUSREDE","EXCUSE","AUSSER","BESIDES","AUSWAHL","CHOICE"
1195 DATA "UNTERSCHIED","DIFFERENCE","VATER","FATHER","VERSUCHEN","TO TRY"
1200 DATA "BAD","BATHROOM","BAHN","RAILROAD","BALD","SOON","BAUEN","TO BUILD"
1205 DATA "VERHEIRATET","MARRIED","VIELLEICHT","PERHAPS","VIEL","MUCH"
1210 DATA "BEIDE","BOTH","BEISPIEL","EXAMPLE","BEREIT","READY"
1215 DATA "VISUM","VISA","VOLL","FULL","WAGEN","CAR","WAHR","TRUE"
1220 DATA "BERG","MOUNTAIN","BESONDERS","ESPECIALLY","BESSERUNG","IMPROVEMENT"
1225 DATA "WANN","WHEN","WALD","FOREST","WARUM","WHY","WAS","WHAT"
1230 DATA "BESTURTZ","UPSET","BESUCH","VISIT","BETRAG","AMOUNT"
1235 DATA "WASSER","WATER","WECKER","ALARM CLOCK","WEG","WAY"
1240 DATA "BILD","PICTURE","BILLIG","CHEAP","BIRNE","PEAR","BISHER","UNTIL NOW"
1245 DATA "WELCHER","WHICH","WELT","WORLD","WEN","WHO","WEM","WHOM"
1250 DATA "BITTE","PLEASE","BLEIBEN","TO STAY","BLUME","FLOWER","BOSE","EVIL"
1255 DATA "WENIG","LITTLE","WENN","WHEN","WERT","VALUE","WERK","WORK"
1260 DATA "BRATEN","TO ROAST","BRATKARTOFFEL","FRIED POTATO","BRAUCHEN","TO NEED"
1265 DATA "WETTER","WEATHER","WIEDER","AGAIN","WILLKOMMEN","WELCOME"
1270 DATA "BREIT","WIDE","BRIEF","LETTER","BRIEFMARKE","STAMP"
1275 DATA "WIRKLICH","REALLY","WO","WHERE","WOCHE","WEEK","WOLLE","WOOL"
1280 DATA "BROT","BREAD","BRUDER","BROTHER","BUCH","BOOK","BUTTERBROT","SANDWICH"
1285 DATA "WORT","WORD","WORTERBUCH","DICTIONARY","WURST","SAUSAGE"
1290 DATA "BUCHHANDLUNG","BOOKSTORE","CREMESCHNITTCHEN","BUTTERCREAM PASTRY"
1295 DATA "WURSTGESCHAFT","DELICATESSEN","ZEIT","TIME","ZAHN","TOOTH"
1300 DATA "DABEI","AT THE SAME TIME","DA","THERE","DAHEIM","HOME"
1305 DATA "ZAHNARZT","DENTIST","ZEITUNG","NEWSPAPER","ZIMMER","ROOM"
1310 DATA "DANACH","LATER","DANKEN","TO THANK","DENKEN","TO THINK"
1315 DATA "ZUG","TRAIN","ZUCKER","SUGAR","ZUSAMMEN","TOGETHER"
1320 DATA "DENKMAL","MONUMENT","DICHT","THICK","DICK","FAT","DING","THING"
1325 DATA "ZWISCHEN","BETWEEN","ZUVIEL","TOO MUCH","ZWECK","GOAL"
1330 DATA "DOM","CATHEDRAL","DORF","VILLAGE","DRAUSSEN","OUTSIDE"
1340 DATA "DURCH","THROUGH","DURST","THIRST","DURSTIG","THIRSTY"
1350 DATA "EIGEN","OWN","EI","EGG","EINIGE","FEW","EINKAUF","PURCHASE"
1360 DATA "EINSAM","LONESOME","EISTEE","ICED TEA","ENG","NARROW"
1370 DATA "ENTGEGEN","TOWARD","ENTLANG","ALONG","ERDBEERE","STRAWBERRY"
1380 DATA "ERKLARUNG","EXPLANATION","ERST","FIRST","ESSEN","TO EAT"
1390 DATA "FAHRGELD","FARE","FAHRT","TRIP","FANGEN","TO CATCH"
1400 DATA "FAST","ALMOST","FEHLER","ERROR","FEIER","CELEBRATION"
1410 DATA "FELD","FIELD","FENSTER","WINDOW","FERIEN","VACATION"
1420 DATA "FERTIG","FINISHED","FIEBER","FEVER","FLASCHE","BOTTLE"
1430 DATA "FLEISCH","MEAT","FLUG","FLIGHT","FLUGHAFEN","AIRPORT"
1440 DATA "FOTOGRAF","PHOTOGRAPHER","FOTOGRAFIEREN","TO PHOTOGRAPH"
1450 DATA "FRAGE","QUESTION","FREUND","FRIEND","FRISCH","FRESH","FROH","GLAD"
1460 DATA "FRUCHTEIS","FRUIT ICE","FRUCHTSAFT","FRUIT JUICE","FRUH","EARLY"
1470 DATA "FRUHSTUCK","BREAKFAST","FUSSBALL","SOCCER","GANZ","WHOLE"
1480 DATA "GARTEN","GARDEN","GEBEN","TO GIVE","GEFAHR","DANGER"
1490 DATA "GEGEN","AGAINST","GEKOCHT EIER","BOILED EGGS","GELD","MONEY"
1500 DATA "GEMUSE","VEGETABLE","GENUG","ENOUGH","GESTERN","YESTERDAY"
1510 DATA "GESUND","HEALTHY","GETRANK","BEVERAGE","GLAUBE","BELIEF"
1520 DATA "GLEICH","IMMEDIATELY","GLUCK","LUCK","GOTT","GOD"
1530 DATA "GRENZE","BORDER","GROSS","BIG","GRUN","GREEN","GURKE","CUCUMBER"
1540 DATA "GUT","GOOD","HAUS","HOUSE","HEIMWEH","HOMESICKNESS"
1550 DATA "HEISS","HOT","HERBST","AUTUMN","HEUTE","TODAY","HILFE","HELP"
1560 DATA "HIMBEERE","RASPBERRY","HOCH","HIGH","HOFFEN","TO HOPE"
1570 DATA "HOSE","PANTS","HUHN","CHICKEN","HUND","DOG","HUT","HAT"
1580 DATA "IMMER","ALWAYS","JA","YES","JETZT","NOW","KAFFEE","COFFEE"
1590 DATA "KALT","COLD","KAMERA","CAMERA","KARTE","MAP","KARTOFFEL","POTATO"
1600 DATA "KASE","CHEESE","KAUFEN","TO BUY","KELLNER","WAITER"
1610 DATA "KENNEN","TO KNOW","KIRCHE","CHURCH","KIRSCHE","CHERRY"
1620 DATA "KLAR","CLEAR","KLEID","DRESS","KLEIN","SMALL","KLUG","SMART"
1630 DATA "KOLONIALWARENGESCHAFT","GROCERY STORE","KOMMEN","TO COME"
1640 DATA "KONDITOREI","PASTRY SHOP","KOPF","HEAD","KOSTEN","TO COST"
1650 DATA "KOSTENLOS","FREE","KUCHEN","CAKE","KUH","COW","KUNST","ART"
1660 DATA "KURZ","SHORT","KUSS","KISS","LACHEN","TO LAUGH","LADEN","SHOP"
1670 DATA "LANGSAM","SLOW","LASSEN","TO LET","LEICHT","EASY"
1680 DATA "LETZT","LAST","LICHT","LIGHT","LIEBEN","TO LOVE","LINKS","LEFT"
1690 DATA "LIED","SONG","LIMONADE","LEMONADE","LOFFEL","SPOON"
1700 DATA "MACHEN","TO DO","MANTEL","OVERCOAT","MEER","SEA","MEHR","MORE"
1710 DATA "MESSER","KNIFE","MILCH","MILK","MITTAG","NOON"
1720 DATA "MITTERNACHT","MIDNIGHT","MORGEN","MORNING","MUDE","TIRED"
1730 DATA "NACH","AFTER","NACHST","NEXT","NACHT","NIGHT","NACHTISCH","DESSERT"
1740 DATA "NASS","WET","NEIN","NO","NIE","NEVER","NICHT","NOT"
1750 DATA "NOCH","STILL","NUN","NOW","NUR","ONLY","OBST","FRUIT"
1760 DATA "OBSTSALAT","FRUIT SALAD","PASS","PASSPORT","PFIRSICH","PEACH"
1770 DATA "ODOR","OR","OFFEN","OPEN","PLATZ","SEAT","POLITZEI","POLICE"
1780 DATA "POSTAMT","POST OFFICE","RECHNUNG","BILL","RECHT","RIGHT"
1790 DATA "REDEN","TO TALK","REIN","PURE","REISEN","TO TRAVEL","REISE","TRIP"
1800 FOR X=1 TO 368
1810 READ T$(X),H$(X)
1820 NEXT X
1830 GOTO 170
1900 FOR X=1 TO 368
1910 READ H$(X),T$(X)
1920 NEXT X
1930 GOTO 170
2000 PRINT CHR$(26)
2003 PRINT:PRINT
2005 PRINT:PRINT:PRINT "THIS PROGRAM DRILLS YOU IN GERMAN VOCABULARY, EITHER IN"
2010 PRINT "TRANSLATING INTO GERMAN OR IN TRANSLATING BACK INTO ENGLISH."
2020 PRINT:PRINT "THE COMPUTER PICKS THE WORD AT RANDOM OUT OF THE VOCABULARY"
2030 PRINT "BUILT INTO IT.  IGNORE UMLAUTS AND OTHER DIACRITICAL MARKS."
2040 PRINT "IF YOU MISS, YOU GET TWO MORE GUESSES.  IF YOU HAVE NO IDEA WHAT"
2042 PRINT "THE WORD IS, TYPE 'I GIVE UP' TO MINIMIZE ITS EFFECT ON YOUR SCORE."
2050 PRINT:PRINT "TO END THE SESSION, TYPE 'QUIT' WHEN THE COMPUTER ASKS FOR"
2060 PRINT "YOUR TRANSLATION.  IT WILL THEN TELL YOU HOW MANY YOU GOT"
2070 PRINT "RIGHT AND THE PERCENTAGE RIGHT."
2080 PRINT:PRINT "VIELE GLUCK!"
2082 PRINT:PRINT "PRESS ANY KEY TO BEGIN."
2084 P=P+1:IF INKEY$="" THEN 2084
2086 RANDOMIZE P
2090 RETURN
3000 PRINT:PRINT "IN THIS SESSION, YOU MADE";T;"GUESSES, AND GOT";C;"RIGHT ANSWERS."
3010 P=C/T*100
3020 PRINT "YOUR PERCENTAGE CORRECT WAS";P
3030 IF P>90 THEN PRINT "SEHR GUT! AN EXPERT!":GOTO 3099
3040 IF P>80 THEN PRINT "GOOD WORK -- KEEP STUDYING.":GOTO 3099
3050 IF P>70 THEN PRINT "YOU'RE DOING OK BUT NEED TO IMPROVE.":GOTO 3099
3060 IF P>60 THEN PRINT "YOU DIDN'T DO SO HOT.  STUDY A LOT MORE.":GOTO 3099
3070 IF P>30 THEN PRINT "ACH DU LIEBER!  YOU BETTER NOT TRY TO TALK TO A KRAUT!":GOTO 3099
3080 PRINT "DUMBKOPF!  ARE YOU SURE YOU'VE BEEN STUDYING THE RIGHT LANGUAGE?"
3099 PRINT:PRINT:SYSTEM
O A KRAUT!":GOTO 3099
3080 PR