10 DEPTH=0
20 GOSUB 1000
30 PRINT "Maximum depth reached:", DEPTH
40 END
1000 DEPTH=DEPTH+1
1001 PRINT "Depth:", DEPTH
1002 GOSUB 1010
1003 RETURN
1010 DEPTH=DEPTH+1
1011 PRINT "Depth:", DEPTH
1012 GOSUB 1020
1013 RETURN
1020 DEPTH=DEPTH+1
1021 PRINT "Depth:", DEPTH
1022 GOSUB 1030
1023 RETURN
1030 DEPTH=DEPTH+1
1031 PRINT "Depth:", DEPTH
1032 GOSUB 1040
1033 RETURN
1040 DEPTH=DEPTH+1
1041 PRINT "Depth:", DEPTH
1042 GOSUB 1050
1043 RETURN
1050 DEPTH=DEPTH+1
1051 PRINT "Depth:", DEPTH
1052 GOSUB 1060
1053 RETURN
1060 DEPTH=DEPTH+1
1061 PRINT "Depth:", DEPTH
1062 GOSUB 1070
1063 RETURN
1070 DEPTH=DEPTH+1
1071 PRINT "Depth:", DEPTH
1072 GOSUB 1080
1073 RETURN
1080 DEPTH=DEPTH+1
1081 PRINT "Depth:", DEPTH
1082 GOSUB 1090
1083 RETURN
1090 DEPTH=DEPTH+1
1091 PRINT "Depth:", DEPTH
1093 RETURN