100 DEFINT A-Z
110 PRINT
120 PRINT "TEST OF DISK SPACE ROUTINE"
130 PRINT
140 INPUT "IDENTIFIER OF DRIVE TO REPORT ON (A/B/C/D) :";DRIVE$
150 PRINT 
160 PRINT "DRIVE TO BE REPORTED ON WILL BE ";DRIVE$
170 PRINT
180 A=0
190 B=ASC(DRIVE$)
200 CALL MAP(A,B)
210 PRINT "THE NUMBER OF KBYTES REMAINING ON DRIVE ";DRIVE$;" IS ";A;"K"
220 END
