1 2  ASICO  2 RO2"14
72EHENK WEVER30(HEM NADERE INLICHT:T N BAS
4
A3 RE=:IE>ROBBYSCOOP HIVERSUM 
5 PRINT CHR$(26);:WIDTH(5I1Z
 <O
20050<(10
10
HIECHR$(2E;:RETU =E9HEM
4e=8 HO51 THEN HO=51
10T
OVE>23 THEN VE

Q113"T3
=T3-OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO=DN
CHR$(t2);CH=0HO+3 ;
)3E5D"3P$5
43Gw3 
JIZ+VET1n
.
SJ
5B)-&HFA12VE=V6oBM"*RO>127HEN0PHO-12:VE=VE+1

00E;0E1
)E(& F6 :0,1 <0 THEN VH E:VE
124 RETURN
200 IN5R6= Y$k"N
210  SU=
+OD0M$r" THEN 21A21RETURN4 T:
INT CHR$(E;:RETU =O3ORV= U01):RET3E=,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,5=FRE(2):RET3E=$A+r3BIDSAT4)
<7=LEN(SR$):0=+9R")RETURN Q M"*3eTTT4R VS:1"1IREN 304
=4
nUEFT$(Qp
7-1)
 s23n04 IF LEF=0SR$, <>" " THORETURQ30r-0TT2-4RQp
7-1:F TO01
3G
4=SR:IF CN>IREN 316 QR0r33=eSR+.5):GOSUB 300: T330
.0R=SGN(SR4RLAB0SR):Q8=IN4RI 
T"TA8
"/+2E 
 TCN:Q3A9*10:2 =+R=$EAG
9=INO
9+5):SR=Q: "
EA,=$EEM:$=M"R
T43 0N0184RQp E NEIF 
:D 1
NO2OTHEN Q5=1
10Q33A:GO=B 30 D0=,EI 1IREN SR$="-"+SCA328 S$m3B:6D06  P$U+T
OEN(QT <=CTHEN34

10r3B5C=
T4
O(N018C
S+GOTO40
334 SR$RM"R
T4
(N014RQpCU$9r33A4:RETU = T

I5R 2IRQ
 TD"3PO3OLPRI9RETURN
10000 A=10O*2YD$2  9GM5II=




















































































Es5),A05)G
$(12)
1020 FOR I=0 TO 15:READ    0VEXT I
1030:H I=2Y T1
D ZE:NEXT I
1( FOR I=0 TO 5W A20-O0VEXT I
105
OR I=1 TO 12:21
2 Q$(I):NEXT I
2  GOSUB ,=,AZOPR I=S$0N0T"ogramma bereI0nt de feestdagen."4*
G=RI9PRIDA2030 PR =)N)(lk jaar ";:INPUT J
2040 IF J>1582 ANS$N2300 THEN 30000
 T=RINT"Alleen T3 153 /m 2299!