OPEN "A:X.COM" AS 1
B9$="0123456789ABCDEF"

DEF FN.HEX$(X)=MID$(B9$,INT(X/16)+1,1)+MID$(B9$,(X AND 15)+1,1)

FOR X=1 TO 300
R%=GET(1)
PRINT X;R%;FN.HEX$(R%);
IF R%>31 AND R%<128 THEN PRINT CHR$(R%) ELSE PRINT
NEXT X

CLOSE 1

