10	REM *************** WINDC..BAS ***************
(NCIITT IN MII$O IPISIC BY JL LOZANO
30	REM CHIEF MEOROLOGIST WHO TELE0 
Y H R 
N OS RKW
4E:R  1801 GRAND AVTIS 5NES, IORIPC=HW15)-242-3635
A0CR  RELE NH  THE PUB: DOMAIN F N	IT AL & NON-PROFIT USE.
0	REM DON'THANGE MA NSATICALNE GNSHIP OF LINES
(8E:EVN0 &=0 OR >>LL GET FALSE RESULTS!
8E:R IN NGR0 & 200 ARE THE FR ULAI3IIIND CHILFACPF
0	PRINT CHR$(12):PNT) (A S:RIT R
8&C FEARTHE SCREEN
100	PRINT" WINDHILL CALCULAT NA URINT:
5
T)(NSHTMMPE	PRROSA CR"R
RIN(1(R) (LMR
E) or  8<3:PRINT
13EAS=INKEY$ - TCE8E0 )=0T LC2OT130
VT0- E0 ="F" THE2OTO 170 
150	IF T$=IRHEN GIR 28I2OTOON0
10	PRINT CHR$(7):GOTO 130
V
8ERPNET
 A RRR1STEENA* URINT:
VN0	I0o $THEG160
V"8IGT.686*&PNG
F447*V+10.45
200	WCGR1.; 80TVT538*T-4.14
2(T- 0r!SLSTICI=TESE SWC3SETHGOTO 300
220- E0 ="CENHWCI=((5/9)*ACI-32))ESE EO0WCI:
230	PRINT RRHEIT .L = ";:PNTR ING "#####.#";WCI;:C
LRO0AS: PRINT " PBS": PRINT:C
A8N0	C
LINN ER RUN? Y/N ":
250	C$=KEY$: ITCE8TR200 THEN GOCO50
20	IF  R8A:R  EN GOTO 20 E T OE C$="N" TLST1L1
QN(R)  EITI02N);:GOTO 250
280	T=
9/5)*(T))+32
290	TURN
300) (LMTWO  -CO OND FORMULLIMITS! ":PRINT:GOTO 240
310	REM ** FOR FREE WIEIFL BROCHU WHIC 2!RFAS CIT )HEIT .L
RNVNE:R  ** AC".LY I- HR RSO TO BE - AND WHEN IT'S DANGEBM
38E:R O  LE .A.S.E (BUSINESSIZE ENVELOPE)YADDSS ABOVE.
R0C(NCRC* ENJOY!!!
Y $4(E NMT:ESRA.OT 1-IHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHROIRW"EP UU E$ O=S=O=E )TOINSLSH(P 4EW"R
NEI  :D
EMTMI  FTI
LNOE0TRIHNANE T
 N 4EF" *N NNRS"CS"LLMTFI  FTET