10 REM Test statement highlighting during stepping
20 X = 5 : Y = 10 : PRINT "X="; X; " Y="; Y
30 A = X + Y : B = X * Y : PRINT "Sum="; A; " Product="; B
40 FOR I = 1 TO 3 : PRINT "I="; I : NEXT I
50 PRINT "Done"
60 END
